<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

use Joomla\CMS\Access\Access;
use Joomla\CMS\Component\ComponentHelper;

defined('_JEXEC') or die;

class JoomschoolHelperAttachment
{

    /*
     * For saving attachments
     */
    public static function save($id, $type)
    {

        $attachment = new JoomschoolAttachment($id, $type);
        $params = JComponentHelper::getParams('com_joomschool');
        $maxNumbers = $params->get('upload_number', 5);
        $attachmentsCount = count(self::getItemAttachments($id,$type));

        // before uploading check first if this item already reached maximum attachments
        if($attachmentsCount == $maxNumbers){
            return false;
        }

        if($attachmentsCount > $maxNumbers){
            JFactory::getApplication()->enqueueMessage('Maximum allowed attachments number exceeded','warning');
            return false;
        }

        // if not upload
        self::uploadFiles($attachment, $maxNumbers, 'attachment');


        return true;


    }

    /*
     * For saving single image
     */
    public static function saveImage($id, $existingImage, $type, $table, $column)
    {

        $attachment = new JoomschoolAttachment(
            $id,
            $type,
            $table,
            $column
        );

        // update allowed extensions
        $attachment->allowedExtensions = "jpg,png,jpeg,webp,svg,avif,gif";
        $image = JFactory::getApplication()->input->files->get('jform', array(), 'array')['image'];

        // delete old image
        if (!empty($existingImage) &&  !empty($image['size']))
            $attachment->delete($existingImage);

        // upload new image
        self::uploadFiles($attachment, 1, 'image');

        return true;


    }

    public static function getItemAttachments($type_id,$type)
    {

        // get attachment from type id
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);

        $query->select('*')->from('#__joomschool_attachments')->where('type = ' . $db->quote($type))->where('type_id =' . (int)$type_id);

        $db->setQuery($query);

        $files = $db->loadObjectList();

        return is_null($files) ? [] : $files;

    }

    public static function uploadFiles($attachment, $maxNumber, $fieldName)
    {


        $files = JFactory::getApplication()->input->files->get($fieldName, array(), 'array'); // if not using jform

        if (empty($files))
            $files = JFactory::getApplication()->input->files->get('jform', array(), 'array')[$fieldName]; // if using jform

        if(isset($files['size'])) // for one file only
            $files[] = $files;

        $files = (array) $files; // cast

        // no file uploaded
        if (count($files) == 0)
            return false;

        $i = 0;

        foreach ($files as $file) {

            if ($i == $maxNumber)
                break;

            // if file not uploaded don't continue
            if (!$attachment->fileUploaded($file))
                continue;

            // save
            if (!$attachment->save())
                continue;


            $i++;
        }

        return true;
    }

    public static function getItemAttachment($type, $type_id,$allowDelete = false)
    {

        // get attachment from type id
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);

        $query->select('*')->from('#__joomschool_attachments')->where('type = ' . $db->quote($type))->where('type_id =' . (int)$type_id);

        $db->setQuery($query);

        $files = $db->loadObjectList();

        if (!is_null($files)) {

            return JLayoutHelper::render('common.attachment', ['type_id' => $type_id, 'files' => $files, 'type' => $type,'allowDelete' => $allowDelete], '', ['client' => 0]);
        }

        return false;

    }


    public static function deleteAttachment($data){

        extract($data);


        $filePath = JPATH_ROOT . '/media/com_joomschool/attachments/' . $type . '/' . $filename;

        // A file with this name already exists
        if (JFile::exists($filePath)) {
            JFile::delete($filePath);
        }


        // remove from database;
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);

        $query->delete()->from('#__joomschool_attachments')->where('type = ' . $db->quote($type))->where('type_id =' . (int) $id)->where('filename =' .  $db->quote($filename));

        $db->setQuery($query);

        $result = $db->execute();

        if($result)
            return true;

        return false;

    }

}


class JoomschoolAttachment extends \Joomla\CMS\Helper\MediaHelper
{

    public $id;
    public $type; // can be also used as table column
    public $file;
    public $table;
    public $tableColumn;
    public $allowedExtensions;
    public $checkFileAlreadyExists;

    public function __construct($id, $type, $table = 'attachments', $tableColumn = '')
    {

        $params = JComponentHelper::getParams('com_joomschool');

        $this->id = $id;
        $this->type = $type;
        $this->table = $table;
        $this->allowedExtensions = $params->get('upload_extensions', 'zip,pdf,jpg,png,jpeg,doc,docx,xls');
        $this->checkFileAlreadyExists = false;
        $this->tableColumn = $tableColumn;

    }   /*
     * $this->type: mreply => message reply, m => message, pannounce => picture announce
     *
     *
     *
     */

    public function save()
    {

        // upload attachment
        $upload = $this->upload();

        if (!$upload) {
            return false;
        }


        // update in database
        if ($this->table == 'attachments') { // for attachments table

            $file = new stdClass();
            $file->type_id = $this->id;
            $file->type = $this->type;
            $file->filename = $upload;
            $file->created = JFactory::getDate()->toSql();
            JFactory::getDbo()->insertObject('#__joomschool_' . $this->table, $file, 'id');

        } else { // for custom table and column


            $file = new stdClass();
            $file->id = $this->id;
            $file->{$this->tableColumn} = $upload;

            JFactory::getDbo()->updateObject('#__joomschool_' . $this->table, $file, 'id');

        }


        return true;


    }

    public function delete($fileName)
    {

        $filePath = JPATH_ROOT . '/media/com_joomschool/attachments/' . $this->type . '/' . $fileName;

        // A file with this name already exists
        if (!JFile::exists($filePath)) {
            return false;
        }

        if (JFile::delete($filePath))
            return true;

        return false;
    }


    public function fileUploaded($file)
    {

        if (empty($file['name']) || $file['size'] == 0 || empty($file['tmp_name']))
            return false;


        $this->file = $file;


        return true;

    }


    public function upload()
    {

        // inits
        $params = JComponentHelper::getParams('com_joomschool'); // Component config
        $mediaHelper = new JHelperMedia; // Instantiate the media helper


        // set upload maxsize
        $uploadMaxSize = $params->get('upload_maxsize', 0) * 1024 * 1024;
        $uploadMaxFileSize = $mediaHelper->toBytes(ini_get('upload_max_filesize'));

        // Perform basic checks on file info before attempting anythings
        // Make the filename safe
        $this->file['name'] = JFile::makeSafe($this->file['name']);

        // We need a url safe name
        $fileparts = pathinfo(JPATH_ROOT . '/media/com_joomschool/attachments/' . $this->type . '/' . $this->file['name']);

        // Transform filename to punycode, check extension and transform it to lowercase
        $fileparts['filename'] = JStringPunycode::toPunycode($fileparts['filename']);
        $tempExt = !empty($fileparts['extension']) ? strtolower($fileparts['extension']) : '';


        // Neglect other than non-alphanumeric characters, hyphens & underscores.
        $safeFileName = preg_replace(array("/[\\s]/", '/[^a-zA-Z0-9_\-]/'), array('_', ''), $fileparts['filename']) . '.' . $tempExt;

        $this->file['name'] = $this->type . '-' . $this->id . '-' . $safeFileName;


        $this->file['filepath'] = JPath::clean(implode(DIRECTORY_SEPARATOR, array(JPATH_ROOT, 'media', 'com_joomschool', 'attachments', $this->type, $this->file['name'])));

        if (($this->file['error'] == 1)
            || ($uploadMaxSize > 0 && $this->file['size'] > $uploadMaxSize)
            || ($uploadMaxFileSize > 0 && $this->file['size'] > $uploadMaxFileSize)) {

            JFactory::getApplication()->enqueueMessage(JText::_('COM_MEDIA_ERROR_WARNFILETOOLARGE'), 'warning');

            return false;
        }

        // A file with this name already exists
        if (JFile::exists($this->file['filepath']) && $this->checkFileAlreadyExists) {
            JFactory::getApplication()->enqueueMessage(JText::_('COM_JOOMMEDIA_ERROR_FILE_EXISTS'), 'warning');

            return false;
        }

        // No filename (after the name was cleaned by JFile::makeSafe)
        if (!isset($this->file['name'])) {

            JFactory::getApplication()->enqueueMessage(JText::_('COM_JOOMMEDIA_ATTACHMENT_INVALID_FILE_NAME'), 'warning');

            return false;
        }


        if (!$this->canUploadAttachment()) {
            // The file can't be uploaded
            return false;
        }


        if (!\Joomla\Filesystem\File::upload($this->file['tmp_name'], $this->file['filepath'])) {
            // Error in upload
            JFactory::getApplication()->enqueueMessage(JText::_('COM_JOOMMEDIA_ERROR_UNABLE_TO_UPLOAD_FILE'), 'warning');

            return false;
        }

        return $this->file['name'];


    }

    public function canUploadAttachment()
    {
        $app = \Joomla\CMS\Factory::getApplication();
        $params = ComponentHelper::getParams('com_joomschool');

        if (empty($this->file['name'])) {
            $app->enqueueMessage(\JText::_('JLIB_MEDIA_ERROR_UPLOAD_INPUT'), 'error');

            return false;
        }

        jimport('joomla.filesystem.file');

        if (str_replace(' ', '', $this->file['name']) !== $this->file['name'] || $this->file['name'] !== \JFile::makeSafe($this->file['name'])) {
            $app->enqueueMessage(\JText::_('JLIB_MEDIA_ERROR_WARNFILENAME'), 'error');

            return false;
        }

        $filetypes = explode('.', $this->file['name']);

        if (count($filetypes) < 2) {
            // There seems to be no extension
            $app->enqueueMessage(\JText::_('JLIB_MEDIA_ERROR_WARNFILETYPE'), 'error');

            return false;
        }

        array_shift($filetypes);

        // Media file names should never have executable extensions buried in them.
        $executable = array(
            'php', 'js', 'exe', 'phtml', 'java', 'perl', 'py', 'asp', 'dll', 'go', 'ade', 'adp', 'bat', 'chm', 'cmd', 'com', 'cpl', 'hta', 'ins', 'isp',
            'jse', 'lib', 'mde', 'msc', 'msp', 'mst', 'pif', 'scr', 'sct', 'shb', 'sys', 'vb', 'vbe', 'vbs', 'vxd', 'wsc', 'wsf', 'wsh',
        );

        $check = array_intersect($filetypes, $executable);

        if (!empty($check)) {
            $app->enqueueMessage(\JText::_('JLIB_MEDIA_ERROR_WARNFILETYPE'), 'error');

            return false;
        }

        $filetype = array_pop($filetypes);
        $allowable = array_map('trim', explode(',', $this->allowedExtensions));
        $ignored = array_map('trim', explode(',', $params->get('ignore_extensions', '')));

        if ($filetype == '' || $filetype == false || (!in_array($filetype, $allowable) && !in_array($filetype, $ignored))) {
            $app->enqueueMessage(\JText::_('JLIB_MEDIA_ERROR_WARNFILETYPE'), 'error');

            return false;
        }

        $maxSize = (int)($params->get('upload_maxsize', 10) * 1024 * 1024);

        if ($maxSize > 0 && (int)$this->file['size'] > $maxSize) {
            $app->enqueueMessage(\JText::_('JLIB_MEDIA_ERROR_WARNFILETOOLARGE'), 'error');

            return false;
        }

        $xss_check = file_get_contents($this->file['tmp_name'], false, null, -1, 256);

        $html_tags = array(
            'abbr', 'acronym', 'address', 'applet', 'area', 'audioscope', 'base', 'basefont', 'bdo', 'bgsound', 'big', 'blackface', 'blink',
            'blockquote', 'body', 'bq', 'br', 'button', 'caption', 'center', 'cite', 'code', 'col', 'colgroup', 'comment', 'custom', 'dd', 'del',
            'dfn', 'dir', 'div', 'dl', 'dt', 'em', 'embed', 'fieldset', 'fn', 'font', 'form', 'frame', 'frameset', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6',
            'head', 'hr', 'html', 'iframe', 'ilayer', 'img', 'input', 'ins', 'isindex', 'keygen', 'kbd', 'label', 'layer', 'legend', 'li', 'limittext',
            'link', 'listing', 'map', 'marquee', 'menu', 'meta', 'multicol', 'nobr', 'noembed', 'noframes', 'noscript', 'nosmartquotes', 'object',
            'ol', 'optgroup', 'option', 'param', 'plaintext', 'pre', 'rt', 'ruby', 's', 'samp', 'script', 'select', 'server', 'shadow', 'sidebar',
            'small', 'spacer', 'span', 'strike', 'strong', 'style', 'sub', 'sup', 'table', 'tbody', 'td', 'textarea', 'tfoot', 'th', 'thead', 'title',
            'tr', 'tt', 'ul', 'var', 'wbr', 'xml', 'xmp', '!DOCTYPE', '!--',
        );

        foreach ($html_tags as $tag) {
            // A tag is '<tagname ', so we need to add < and a space or '<tagname>'
            if (stripos($xss_check, '<' . $tag . ' ') !== false || stripos($xss_check, '<' . $tag . '>') !== false) {
                $app->enqueueMessage(\JText::_('JLIB_MEDIA_ERROR_WARNIEXSS'), 'error');

                return false;
            }
        }

        return true;
    }


}

