<?php
/**
 * @package	JoomSchool !
 * @version	1.0.0
 * @author	joomboost.com
 * @copyright	(C) 2013-2019 JoomBoost. All rights reserved.
 * @license	GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;

class JoomschoolHelperPayment
{

    /*
     * Check if at least one payment plugin is enabled
     */
    public static function isEnabledPlugins(){

        if(!JPluginHelper::isEnabled('joomschool_payment')){
            JFactory::getApplication()->enqueueMessage(JText::_('COM_JOOMSCHOOL_NO_PAYMENT_PLUGIN_ENABLED'),'error');
            return false;
        }

        return true;
    }


    public static function processPayment($payment){

        // inits
        $input = JFactory::getApplication()->input;
        $post = $input->post->getArray();
        $dispatcher = JDispatcher::getInstance();

        // add post field exception
        if (!count($post)) $post = @file_get_contents('php://input');

        // get global joomschool config
        $config = JComponentHelper::getParams('com_joomschool');

        // get selected payment
        //$selectedPayment = !empty($payment->payment_method) ? $payment->payment_method : $config->get('default_payment', 'offline');
        $selectedPayment = $config->get('default_payment', 'offline');

        // import payment plugin
        JPluginHelper::importPlugin('joomschool_payment', $selectedPayment);

        // trigger payment
        $html = $dispatcher->trigger('onJOOMSCHOOL_PaymentProcesspayment', array($post, $selectedPayment));

        // return payment result
        return $html[0];


    }

    public static function getPaymentHtml($payment){

        $config = JComponentHelper::getParams('com_joomschool');

        $id = !empty($payment->id) ? $payment->id : '';
        $pay_for_id = !empty($payment->pay_for_id) ? $payment->pay_for_id : '';
        $paid_ammount = !empty($payment->paid_ammount) ? $payment->paid_ammount : '';
        $total_bill = !empty($payment->total_bill) ? $payment->total_bill : '';
        $due_ammount = !empty($payment->due_ammount) ? $payment->due_ammount : '';
        $invID = str_pad($id, 10, '0', STR_PAD_LEFT);

        // get selected payment
        //$selectedPayment = !empty($payment->payment_method) ? $payment->payment_method : $config->get('default_payment', 'offline');
        $selectedPayment = $config->get('default_payment', 'offline');

        $actual_link = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";

        $cancel_link = $actual_link;
        $url = $actual_link . '?method=processPayment&processor=' . $selectedPayment;

        $vars = new stdClass();
        $vars->order_id = $id;
        $vars->user_id = JFactory::getUser()->id;
        $vars->item_name = '';

        $items = explode(',', $pay_for_id);
        foreach ($items as $key => $value) {

            $vars->item_name .= JoomschoolHelper::selectSingleData('name', 'joomschool_pay_type', 'id', $value) . ', ';
        }

        $vars->item_name = substr($vars->item_name, 0, strlen($vars->item_name) - 2);

        $vars->cancel_return = $cancel_link;

        //processPayment
        $vars->return = $vars->notify_url = $vars->url = $url;
        $vars->currency_code = $config->get('currency', 'USD');
        $vars->amount = $paid_ammount;


        JPluginHelper::importPlugin('joomschool_payment', $selectedPayment);
        $dispatcher = JDispatcher::getInstance();

        $html = $dispatcher->trigger('onJOOMSCHOOL_PaymentGetHTML', array($vars, $selectedPayment));

        if (!isset($html[0])) {
            $html[0] = '';
        }

        return $html[0];
    }

    /**
     ** Pay Ammount
     **/
    public static function getPayammount($id,$field){
        $db = JFactory::getDBO();
        $query_result = $db->getQuery(true);
        $query_result
            ->select($db->quoteName(array($field)))
            ->from($db->quoteName('#__joomschool_pay_type'))
            ->where($db->quoteName('id') . ' = '. $db->quote($id));

        $db->setQuery($query_result);
        $data = $db->loadResult();
        return $data;
    }


    public static function getStatusText($id){

        $st = '';

        if ($id == "0") {
            $st = '<span style="color: orange;font-weight: bold;" >' . JText::_('COM_JOOMSCHOOL_LABEL_STATUS_PENDING') . '</span>';
        }
        if ($id == "1") {
            $st = '<span style="color: green;font-weight: bold;" >' . JText::_('COM_JOOMSCHOOL_LABEL_STATUS_PAID') . '</span>';
        }
        if ($id == "2") {
            $st = '<span style="color: red;font-weight: bold;" >' . JText::_('COM_JOOMSCHOOL_LABEL_STATUS_UN_PAID') . '</span>';
        }
        if ($id == "3") {
            $st = '<span style="color: magenta;font-weight: bold;" >' . JText::_('COM_JOOMSCHOOL_LABEL_STATUS_CANCEL') . '</span>';
        }
        if ($id == "4") {
            $st = '<span style="color: mediumblue;font-weight: bold;" >' . JText::_('COM_JOOMSCHOOL_LABEL_STATUS_UNDER_REVIEW') . '</span>';
        }

        return $st;

    }

}