<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;

class JoomschoolHelperUser
{

    static $errors = [];

    public static function processUser(&$data, $role)
    {

        // if new user assigned as student
        if ($data['user_id'] && $data['id'] == 0) {

            $user = JFactory::getUser($data['user_id']);

            $alreadyExist = self::userAlreadyExist($user->email);

            if ($alreadyExist) {
                static::$errors = [$alreadyExist];

                return false;
            }

            $user->groups = self::updateUserGroups($role, $data['user_id']);

            $user->name = $data['name'];

            $user->save(true);

            return true;

        }

        // new user registration
        if (!$data['id']) {

            $result = self::register($data, 'student');

            $data['user_id'] = (int)$result['id'];

            if (count($result['errors']) > 0 && !$result['id']) {

                static::$errors = $result['errors'];
                return false;

            }

            return true;
        }

        // update user email name with validation

        $result = self::updateUserDetails($data, $role);

        if (count($result['errors']) > 0 && !$result['success']) {

            static::$errors = $result['errors'];
            return false;
        }

        return true;

    }

    public static function register($data, $role = '')
    {

        // check first if user already exist
        $alreadyExist = JoomschoolHelperUser::userAlreadyExist($data['email']);
        if ($alreadyExist) {
            return ['id' => false, 'errors' => [$alreadyExist]];
        }

        // inits
        JLoader::register('UsersModelRegistration', JPATH_SITE . '/components/com_users/models/registration.php');
        $lang = JFactory::getLanguage();
        $config_u = JComponentHelper::getParams('com_users');
        $config = JComponentHelper::getParams('com_joomschool');

        // get user group of new registration
        $new_usertype = self::getUserGroupFromRole($role);

        // user data for registration
        $user_data = array();
        $user_data['name'] = $data['name'];
        $user_data['email'] = $data['email'];
        $user_data['email1'] = $data['email'];

        $user_data['groups'] = array($new_usertype);
        $user_data['username'] = $data['email'];
        $user_data['password1'] = $data['password'];
        $user_data['password2'] = $data['password'];
        $user_data['block'] = 0;

        $params = JComponentHelper::getParams('com_users');
        $params->set('useractivation', 0);


        // load joomla users component language file
        $lang->load('com_users', JPATH_SITE, $lang->getTag(), true);

        // user modal object
        $userModel = new UsersModelRegistration();

        // register user
        $registered = $userModel->register($user_data);

        // check register result
        if (in_array($registered, ['useractivate', 'adminactivate'])) {
            $registered = JFactory::getDbo()->insertid();
        }


        // register user
        return ['id' => $registered, 'errors' => $userModel->getErrors()];

    }

    /*
     * Update email and name if changed
     */
    public static function updateUserDetails($data, $role)
    {


        // inits
        JLoader::register('UsersModelUser', JPATH_ADMINISTRATOR . '/components/com_users/models/user.php');
        $lang = JFactory::getLanguage();
        $userGroup = self::getUserGroupFromRole($role);

        // map fields
        $user_data['name'] = $data['name'];
        $user_data['email'] = $data['email'];
        $user_data['id'] = $data['user_id'];
        $user_data['block'] = 0;

        $user_data['groups'] = self::updateUserGroups($role, $data['user_id']);


        // load joomla users component language file
        $lang->load('com_users', JPATH_ADMINISTRATOR, $lang->getTag(), true);

        // user modal object
        $userModel = new UsersModelUser();

        // save user
        $saved = $userModel->save($user_data);

        // update user
        return ['success' => $saved, 'errors' => $userModel->getErrors()];

    }

    /*
     * usefull method to check if user already exist in joomschool, to prevent duplicate users.
     */
    public static function userAlreadyExist($email)
    {

        $roles = ['student', 'teacher', 'parent'];

        foreach ($roles as $role) {

            $alreadyExist = self::alreadyExistAs($role, $email);

            if ($alreadyExist)
                return JText::_('COM_JOOMSCHOOL_USER_ALREADY_EXIST_AS_' . strtoupper($role));


        }

        return false;


    }


    public static function alreadyExistAs($role, $email)
    {


        $db = JFactory::getDbo();
        $query = $db->getQuery(true);

        $query->select('COUNT(s.id)')
            ->from("#__joomschool_{$role}s s")
            ->innerJoin('#__users u on u.id = s.user_id')
            ->where("u.email = " . $db->quote($email));

        $db->setQuery($query);

        $result = $db->loadResult();

        return $result > 0 ? true : false;

    }

    /*
     * Get user group from role name
     */
    public static function getUserGroupFromRole($role)
    {

        $config = JComponentHelper::getParams('com_joomschool');

        if ($role == 'student') // if student user
        {
            return $config->get('students_group', 140001);
        } elseif ($role == 'teacher') // if teacher user
        {
            return $config->get('teachers_group', 140002);
        } elseif ($role == 'parent') // if parent user
        {
            return $config->get('parents_group', 140003);
        }


        return false;

    }


    public static function updateUserGroups($role, $userId)
    {

        $config = JComponentHelper::getParams('com_joomschool'); // component config
        $userGroups = JFactory::getUser($userId)->groups; // user groups

        // main joomschool groups
        $mainGroups = [
            'student' => $config->get('students_group', 140001),
            'teacher' => $config->get('teachers_group', 140002),
            'parent' => $config->get('parents_group', 140003)
        ];

        $userRoleGroup = $mainGroups[$role];

        // remove current role
        unset($mainGroups[$role]);

        // remove other roles group from user groups
        // example if user role is student and we found has teacher group then we need to remove this group from it.
        foreach ($userGroups as $userGroupKey => $userGroupValue) {

            if (in_array($userGroupValue, $mainGroups))
                unset($userGroups[$userGroupKey]);

        }

        // if user role group doesn't exist then we add it.
        if (!in_array($userRoleGroup, $userGroups))
            $userGroups[$userRoleGroup] = $userRoleGroup;

        return $userGroups;
    }

    public static function hasRole($role, $id = null)
    {

        $userGroup = self::getUserGroupFromRole($role);

        if (in_array($userGroup, JFactory::getUser($id)->groups))
            return true;

        return false;
    }


    public static function isMyProfile($profileId, $profileRole)
    {

        $db = JFactory::getDbo();
        $query = $db->getQuery(true);

        $query->select('COUNT(s.id)')
            ->from("#__joomschool_{$profileRole}s s")
            ->innerJoin('#__users u on u.id = s.user_id')
            ->where("u.email = " . $db->quote(JFactory::getUser()->email))
            ->where("s.id = " . $profileId);

        $db->setQuery($query);

        $result = $db->loadResult();

        return $result > 0 ? true : false;

    }

    /**
     ** USER GROUP
     **/
    public static function checkGroup($id)
    {

        // component config
        $config = JComponentHelper::getParams('com_joomschool');

        // get user groups
        $userGroups = JFactory::getUser($id)->groups;

        // map predefined users group with titles
        $predefinedUserGroups = [
            'Parents' => $config->get('parents_group', 140003),
            'Students' => $config->get('students_group', 140001),
            'Teachers' => $config->get('teachers_group', 140002),
        ];


        foreach ($predefinedUserGroups as $groupName => $groupValue) {

            if (in_array($groupValue, $userGroups)) {
                return $groupName; // return group name
            }


        }

        return false;


    }

    public static function getUserId($id, $type = 'teachers')
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('user_id')))
            ->from($db->quoteName('#__joomschool_' . $type))
            ->where($db->quoteName('id') . ' = ' . $db->quote($id));
        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }

    public static function getStudentsInClasses($classes)
    {

        if(is_array($classes))
            $classes = implode(',', $classes);

        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select('*')
            ->from($db->quoteName('#__joomschool_students'))
            ->where( 'class_id IN (' . $classes . ')');

        $db->setQuery($query);
        $students = $db->loadObjectList();
        return is_null($students) ? [] : $students;


    }

}