<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;


class JoomschoolModelAttendance extends JModelAdmin
{

    /**
     * Prepare and sanitise the table data prior to saving.
     *
     * @param JTable $table A JTable object.
     *
     * @return  void
     *
     * @since   1.6
     */
    protected function prepareTable($table)
    {
        // Set the publish date to now
        if ($table->state == 1 && (int)$table->publish_up == 0) {
            $table->publish_up = JFactory::getDate()->toSql();
        }

        if ($table->state == 1 && intval($table->publish_down) == 0) {
            $table->publish_down = $this->getDbo()->getNullDate();
        }

    }

    /**
     * Returns a Table object, always creating it.
     *
     * @param string $type The table type to instantiate
     * @param string $prefix A prefix for the table class name. Optional.
     * @param array $config Configuration array for model. Optional.
     *
     * @return  JTable    A database object
     */
    public function getTable($type = 'Attendance', $prefix = 'Table', $config = array())
    {

        return JTable::getInstance($type, $prefix, $config);
    }

    /**
     * Method to get a single record.
     *
     * @param integer $pk The id of the primary key.
     *
     * @return  mixed  Object on success, false on failure.
     */
    public function getItem($pk = null)
    {
        $item = parent::getItem($pk);

        if(isset($item->class_subjects) && !empty($item->class_subjects)){
            $item->class_subjects = explode(',',$item->class_subjects);
        }

        return $item;
    }

    /**
     * Method to get the record form.
     *
     * @param array $data Data for the form.
     * @param boolean $loadData True if the form is to load its own data (default case), false if not.
     *
     * @return  JForm|boolean  A JForm object on success, false on failure
     *
     * @since   1.6
     */
    public function getForm($data = array(), $loadData = true)
    {


        $app = JFactory::getApplication();
        $user = JFactory::getUser();

        // Get the form.
        $form = $this->loadForm('com_joomschool.attendance', 'attendance', array('control' => 'jform', 'load_data' => $loadData));


        if (empty($form)) {
            return false;
        }

        $jinput = JFactory::getApplication()->input;

        /*
         * The front end calls this model and uses a_id to avoid id clashes so we need to check for that first.
         * The back end uses id so we use that the rest of the time and set it to 0 by default.
         */
        $id = $jinput->get('a_id', $jinput->get('id', 0));

        // Determine correct permissions to check.

        // Check for existing article.
        // Modify the form based on Edit State access controls.
        if ($id != 0 && (!$user->authorise('core.edit.state', 'com_joomschool.attendance.' . (int)$id))
            || ($id == 0 && !$user->authorise('core.edit.state', 'com_joomschool'))) {
            // Disable fields for display.
            $form->setFieldAttribute('ordering', 'disabled', 'true');
            $form->setFieldAttribute('published', 'disabled', 'true');

            // Disable fields while saving.
            // The controller has already verified this is an article you can edit.
            $form->setFieldAttribute('ordering', 'filter', 'unset');
            $form->setFieldAttribute('published', 'filter', 'unset');
        }

        // Prevent messing with article language and category when editing existing article with associations

        return $form;
    }

    /**
     * Method to get the data that should be injected in the form.
     *
     * @return  mixed  The data for the form.
     *
     * @since   1.6
     */
    protected function loadFormData()
    {
        // Check the session for previously entered form data.
        $app = JFactory::getApplication();
        $input = $app->input;
        $data = $app->getUserState('com_joomschool.edit.attendance.data', array());


        if (empty($data)) {


            $data = $this->getItem();


            // Pre-select some filters (Status, Category, Language, Access) in edit form if those have been selected in Article Manager: Articles
            if ($this->getState('a.section') == 0) {
                $filters = (array)$app->getUserState('com_joomschool.attendance.filter');
                $data->set(
                    'state',
                    $app->input->getInt(
                        'state',
                        ((isset($filters['published']) && $filters['published'] !== '') ? $filters['published'] : null)
                    )
                );

                $data->set('language', $app->input->getString('language', (!empty($filters['language']) ? $filters['language'] : null)));
                $data->set('access',
                    $app->input->getInt('access', (!empty($filters['access']) ? $filters['access'] : JFactory::getConfig()->get('access')))
                );
            }
        }

        // If there are params fieldsets in the form it will fail with a registry object
        if (isset($data->params) && $data->params instanceof Registry) {
            $data->params = $data->params->toArray();
        }

        $this->preprocessData('com_joomschool.attendance', $data);

        return $data;
    }

    /**
     * Method to validate the form data.
     *
     * @param JForm $form The form to validate against.
     * @param array $data The data to validate.
     * @param string $group The name of the field group to validate.
     *
     * @return  array|boolean  Array of filtered data if valid, false otherwise.
     *
     * @see     JFormRule
     * @see     JFilterInput
     * @since   3.7.0
     */
    public function validate($form, $data, $group = null)
    {

        return parent::validate($form, $data, $group);
    }

    /**
     * Method to save the form data.
     *
     * @param array $data The form data.
     *
     * @return  boolean  True on success.
     *
     * @since   1.6
     */
    public function save($data)
    {
        // if attendance date or class or section changed means a new attendance
        if($data['id'] > 0){

            $existingItem = $this->getItem($data['id']);

            if(
                $existingItem->class != $data['class'] ||
                $existingItem->attendance_date != $data['attendance_date'] ||
                $existingItem->section != $data['section']
            ){
                $data['id'] = 0; // set as a new attendance
            }

        }

        if(isset($data['class_subjects']) && count($data['class_subjects']) > 0){
            $data['class_subjects'] = implode(',',$data['class_subjects']);
        }

        $isNew = $data['id'] > 0 ? false : true;

        $result = $this->saveattend($data['id'],JFactory::getUser()->id,$data['attendance_date'],$data['class'],$data['section'],$data['class_subjects']);

        if ($result > 0)
        {
            $this->setState($this->getName() . '.id', $result);
        }

        $this->setState($this->getName() . '.new', $isNew);

        if($result > 0)
            return true;
        else
            return false;
    }
    /**
     ** Get Student  List
     **/
    public function getStudentList($class, $section)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select('*')
            ->from($db->quoteName('#__joomschool_students'))
            ->where($db->quoteName('class_id') . ' = ' . $db->quote($class))
            ->where($db->quoteName('section_id') . ' = ' . $db->quote($section))
            ->group('user_id')
            ->order('roll ASC');
        $db->setQuery($query);
        $rows = $db->loadObjectList();
        return $rows;
    }

    /**
     ** Get Teacher Name
     **/
    function getTeachername($id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('name')))
            ->from($db->quoteName('#__users'))
            ->where($db->quoteName('id') . ' = ' . $db->quote($id));
        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }

    /**
     ** Get Old Attendance Info Data
     **/
    function getOldatt($aid, $student_id, $field)
    {
        $db = JFactory::getDBO();
        $query_result = $db->getQuery(true);
        $query_result
            ->select($db->quoteName(array($field)))
            ->from($db->quoteName('#__joomschool_attendance_info'))
            ->where($db->quoteName('attendance_id') . ' = ' . $db->quote($aid))
            ->where($db->quoteName('student_id') . ' = ' . $db->quote($student_id));
        $db->setQuery($query_result);
        $data = $db->loadResult();
        return $data;
    }


    /**
     ** Save Attendance
     **/
    function saveattend($aid, $user_id, $date, $class, $section,$class_subjects, $data = null)
    {
        $db = JFactory::getDbo();

        $aid = empty($aid) ? 0 : (int) $aid;

        $user = JFactory::getUser();
        $user_id = $user->id;

        // Student List
        $query_students = $db->getQuery(true);
        $query_students
            ->select('*')
            ->from($db->quoteName('#__joomschool_students'))
            ->where($db->quoteName('class_id') . ' = ' . $db->quote($class))
            ->where($db->quoteName('section_id') . ' = ' . $db->quote($section))
            ->order('roll ASC');
        $db->setQuery($query_students);
        $student_rows = $this->getStudentList($class,$section);
        $total_student = count($student_rows);


        $table = $this->getTable('attendance');
        $data = is_null($data) ? JRequest::get('post') : $data;

        // Bind the data.
        if (!$table->bind($data)) {
            $this->setError($user->getError());
            return false;
        }

        // Store the data.
        if ($aid) { // if existing item
            $table->id = $aid;
            $table->update_date = JFactory::getDate()->toSql();
        }else{ // if new item
            $table->create_date = JFactory::getDate()->toSql();
        }

        $table->teacher = $user_id;
        $table->attendance_date = $date;
        $table->class = $class;
        $table->section = $section;
        $table->class_subjects = $class_subjects;
        $table->total_student = $total_student;


        if (!$table->store()) {
            $this->setError($user->getError());
            return false;
        }

        $id = $table->id;


        //Save to attendance info
        if (!empty($total_student) && $aid == 0) {
            foreach ($student_rows as $student) {
                $table_info = $this->getTable('attendanceinfo');
                $table_info->attendance_id = $id;
                $table_info->student_id = $student->id;
                $table_info->attend = 2; // means has no present status yet
                $table_info->entry_by = $user_id;
                $table_info->create_date = JFactory::getDate()->toSql();
                if (!$table_info->store()) {
                    $this->setError($user->getError());
                    return false;
                }
            }//end foreach
        }

        return $id;
    }

    /**
     ** Save Attendance info
     **/
    function savestatus($aid, $sid, $status)
    {


        $user = JFactory::getUser();
        $user_id = $user->id;


        $table = $this->getTable('attendanceinfo');

        $db = JFactory::getDBO();
        $query_result = $db->getQuery(true);
        $query_result
            ->select($db->quoteName(array('id')))
            ->from($db->quoteName('#__joomschool_attendance_info'))
            ->where($db->quoteName('attendance_id') . ' = ' . $db->quote($aid))
            ->where($db->quoteName('student_id') . ' = ' . $db->quote($sid));
        $db->setQuery($query_result);
        $id = $db->loadResult();

        $data = JRequest::get('post');
        // Bind the data.
        if (!$table->bind($data)) {
            $this->setError($user->getError());
            return false;
        }
        // Store the data.
        if (!empty($id)) {
            $table->id = $id;
        }

        $table->attendance_id = $aid;
        $table->student_id = $sid;
        $table->attend = $status;
        $table->update_date = JFactory::getDate()->toSql();
        $table->entry_by = $user_id;
        if (!$table->store()) {
            $this->setError($user->getError());
            return false;
        }
        $id = $table->id;
        return $id;
    }


}
