<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;


class JoomschoolModelAttendances extends JModelList
{

    public function __construct($config = array())
    {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                'id','a.id',
                'attendance_date', 'a.attendance_date',
                'class', 'a.class',
                'section',' a.section',
                'total_student',' a.total_student',
                'teacher', 'a.teacher',
                'create_date', 'a.create_date',
                'update_date', 'a.update_date'

            );
        }

        parent::__construct($config);
    }



    protected function populateState($ordering = 'a.id', $direction = 'asc')
    {
        $app = JFactory::getApplication('administrator');

        // Adjust the context to support modal layouts.
        if ($layout = $app->input->get('layout', 'default', 'cmd')) {
            $this->context .= '.' . $layout;
        }

        // Load the filter state.
        $this->setState('filter.section', $this->getUserStateFromRequest($this->context . '.filter.section', 'filter_section', '', 'string'));
        $this->setState('filter.class', $this->getUserStateFromRequest($this->context . '.filter.class', 'filter_class', '', 'string'));

        $this->setState('filter.search', $this->getUserStateFromRequest($this->context . '.filter.search', 'filter_search', '', 'string'));
        $this->setState('filter.active', $this->getUserStateFromRequest($this->context . '.filter.active', 'filter_active', '', 'cmd'));
        $this->setState('filter.state', $this->getUserStateFromRequest($this->context . '.filter.state', 'filter_state', '', 'cmd'));
        $this->setState('filter.group_id', $this->getUserStateFromRequest($this->context . '.filter.group_id', 'filter_group_id', null, 'int'));
        $this->setState('filter.range', $this->getUserStateFromRequest($this->context . '.filter.range', 'filter_range', '', 'cmd'));
        $this->setState(
            'filter.lastvisitrange', $this->getUserStateFromRequest($this->context . '.filter.lastvisitrange', 'filter_lastvisitrange', '', 'cmd')
        );

        $groups = json_decode(base64_decode($app->input->get('groups', '', 'BASE64')));

        if (isset($groups)) {
            $groups = ArrayHelper::toInteger($groups);
        }

        $this->setState('filter.groups', $groups);

        $excluded = json_decode(base64_decode($app->input->get('excluded', '', 'BASE64')));

        if (isset($excluded)) {
            $excluded = ArrayHelper::toInteger($excluded);
        }

        $this->setState('filter.excluded', $excluded);

        // Load the parameters.
        $params = JComponentHelper::getParams('com_joomschool');
        $this->setState('params', $params);

        // List state information.
        parent::populateState($ordering, $direction);
    }

    /**
     ** Attantdance List
     **/

    protected function getListQuery()
    {
        // Create a new query object.
        $db = $this->getDbo();
        $query = $db->getQuery(true);
        $input = JFactory::getApplication()->input;
        // Select the required fields from the table.
        $query->select(
            $this->getState(
                'list.select',
                'DISTINCT a.id, a.attendance_date, a.class, a.section, a.total_student, a.teacher, a.create_date, a.update_date'
            )
        );
        $query->from('#__joomschool_attendance AS a');


        // Filter by Class.
        $classId = $this->getState('filter.class_id');
        if (is_numeric($classId)) {
            $query->where('a.class = ' . $db->quote($classId));
        }

        // Filter by Section.
        $sectionId = $this->getState('filter.section_id');
        if (is_numeric($sectionId)) {
            $query->where('a.section = ' . $db->quote($sectionId));
        }

        // Filter by search in title.
        $search = $this->getState('filter.search');

        if (!empty($search)) {

            $search = $db->quote('%' . str_replace(' ', '%', $db->escape(trim($search), true) . '%'));
            $query->where('(a.attendance_date LIKE ' . $search . ' )');

        }



        // Add the list ordering clause.
        $query->order($db->qn($db->escape($this->getState('list.ordering', 'a.id'))) . ' ' . $db->escape($this->getState('list.direction', 'ASC')));

        return $query;

    }



    /**
     ** Get Total Present
     **/
    function totalPresent($aid)
    {
        $db = JFactory::getDBO();
        $query_result = $db->getQuery(true);
        $query_result
            ->select('*')
            ->from($db->quoteName('#__joomschool_attendance_info'))
            ->where($db->quoteName('attendance_id') . ' = ' . $db->quote($aid))
            ->where($db->quoteName('attend') . ' = ' . $db->quote('1'));
        $db->setQuery($query_result);
        $rows = $db->loadObjectList();
        return $rows;
    }

    /**
     ** Get Total Absent
     **/
    function totalAbsent($aid)
    {
        $db = JFactory::getDBO();
        $query_result = $db->getQuery(true);
        $query_result
            ->select('*')
            ->from($db->quoteName('#__joomschool_attendance_info'))
            ->where($db->quoteName('attendance_id') . ' = ' . $db->quote($aid))
            ->where($db->quoteName('attend') . ' = ' . $db->quote('0'));
        $db->setQuery($query_result);
        $rows = $db->loadObjectList();
        return $rows;
    }


    /**
     ** Get Attendance
     **/
    function getAttendance($id)
    {
        if ($id) {
            $this->_id = $id;
        }
        if (empty($this->_data)) {
            $this->_data = $this->getTable('attendance');
            $this->_data->load($this->_id);
        }
        return $this->_data;
    }






}
