<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;


class JoomschoolModelBmember extends JModelAdmin
{

    /**
     * Prepare and sanitise the table data prior to saving.
     *
     * @param JTable $table A JTable object.
     *
     * @return  void
     *
     * @since   1.6
     */
    protected function prepareTable($table)
    {
        // Set the publish date to now
        if ($table->state == 1 && (int)$table->publish_up == 0) {
            $table->publish_up = JFactory::getDate()->toSql();
        }

        if ($table->state == 1 && intval($table->publish_down) == 0) {
            $table->publish_down = $this->getDbo()->getNullDate();
        }

    }

    /**
     * Returns a Table object, always creating it.
     *
     * @param string $type The table type to instantiate
     * @param string $prefix A prefix for the table class name. Optional.
     * @param array $config Configuration array for model. Optional.
     *
     * @return  JTable    A database object
     */
    public function getTable($type = 'Bmember', $prefix = 'Table', $config = array())
    {


        return JTable::getInstance($type, $prefix, $config);
    }

    /**
     * Method to get a single record.
     *
     * @param integer $pk The id of the primary key.
     *
     * @return  mixed  Object on success, false on failure.
     */
    public function getItem($pk = null)
    {
        $item = parent::getItem($pk);

        return $item;
    }

    /**
     * Method to get the record form.
     *
     * @param array $data Data for the form.
     * @param boolean $loadData True if the form is to load its own data (default case), false if not.
     *
     * @return  JForm|boolean  A JForm object on success, false on failure
     *
     * @since   1.6
     */
    public function getForm($data = array(), $loadData = true)
    {


        $app = JFactory::getApplication();
        $user = JFactory::getUser();

        // Get the form.
        $form = $this->loadForm('com_joomschool.bmember', 'bmember', array('control' => 'jform', 'load_data' => $loadData));


        if (empty($form)) {
            return false;
        }

        $jinput = JFactory::getApplication()->input;

        /*
         * The front end calls this model and uses a_id to avoid id clashes so we need to check for that first.
         * The back end uses id so we use that the rest of the time and set it to 0 by default.
         */
        $id = $jinput->get('a_id', $jinput->get('id', 0));

        // Determine correct permissions to check.

        // Check for existing article.
        // Modify the form based on Edit State access controls.
        if ($id != 0 && (!$user->authorise('core.edit.state', 'com_joomschool.section.' . (int)$id))
            || ($id == 0 && !$user->authorise('core.edit.state', 'com_joomschool'))) {
            // Disable fields for display.
            $form->setFieldAttribute('ordering', 'disabled', 'true');
            $form->setFieldAttribute('published', 'disabled', 'true');

            // Disable fields while saving.
            // The controller has already verified this is an article you can edit.
            $form->setFieldAttribute('ordering', 'filter', 'unset');
            $form->setFieldAttribute('published', 'filter', 'unset');
        }

        // Prevent messing with article language and category when editing existing article with associations


        return $form;
    }

    /**
     * Method to get the data that should be injected in the form.
     *
     * @return  mixed  The data for the form.
     *
     * @since   1.6
     */
    protected function loadFormData()
    {
        // Check the session for previously entered form data.
        $app = JFactory::getApplication();
        $input = $app->input;
        $data = $app->getUserState('com_joomschool.edit.book.data', array());


        if (empty($data)) {


            $data = $this->getItem();


            // Pre-select some filters (Status, Category, Language, Access) in edit form if those have been selected in Article Manager: Articles
            if ($this->getState('a.section') == 0) {
                $filters = (array)$app->getUserState('com_joomschool.book.filter');
                $data->set(
                    'state',
                    $app->input->getInt(
                        'state',
                        ((isset($filters['published']) && $filters['published'] !== '') ? $filters['published'] : null)
                    )
                );

                $data->set('language', $app->input->getString('language', (!empty($filters['language']) ? $filters['language'] : null)));
                $data->set('access',
                    $app->input->getInt('access', (!empty($filters['access']) ? $filters['access'] : JFactory::getConfig()->get('access')))
                );
            }
        }

        // If there are params fieldsets in the form it will fail with a registry object
        if (isset($data->params) && $data->params instanceof Registry) {
            $data->params = $data->params->toArray();
        }

        $this->preprocessData('com_joomschool.book', $data);

        return $data;
    }

    /**
     * Method to validate the form data.
     *
     * @param JForm $form The form to validate against.
     * @param array $data The data to validate.
     * @param string $group The name of the field group to validate.
     *
     * @return  array|boolean  Array of filtered data if valid, false otherwise.
     *
     * @see     JFormRule
     * @see     JFilterInput
     * @since   3.7.0
     */
    public function validate($form, $data, $group = null)
    {


        return parent::validate($form, $data, $group);
    }

    /**
     * Method to save the form data.
     *
     * @param array $data The form data.
     *
     * @return  boolean  True on success.
     *
     * @since   1.6
     */
    public function save($data)
    {

        // get year id
        $data['year'] = JoomschoolHelper::getAcademicIdByYear($data['year']);

        $student = $this->getuserID($data['class'], $data['section'], $data['division'], $data['year'], $data['roll']);
        $data['student_id'] = $student->id;


        if (!$student->id) {
            JFactory::getApplication()->enqueueMessage('The roll number not store our database ! please try again ', 'error');
            return false;
        }

        parent::save($data);


        return true;


    }


    function __construct()
    {
        parent::__construct();


    }


    /**
     ** Get User ID
     **/
    public function getuserID($class, $section, $division, $year, $roll)
    {

        $db = JFactory::getDBO();
        $query_result = $db->getQuery(true);
        $query_result
            ->select(array('id', 'user_id'))
            ->from($db->quoteName('#__joomschool_students'))
            ->where($db->quoteName('class_id') . ' = ' . $db->quote($class))
            ->where($db->quoteName('section_id') . ' = ' . $db->quote($section))
            ->where($db->quoteName('division_id') . ' = ' . $db->quote($division))
            ->where($db->quoteName('year') . ' = ' . $db->quote($year))
            ->where($db->quoteName('roll') . ' = ' . $db->quote($roll));

        $db->setQuery($query_result);
        $data = $db->loadObject();

        return $data;
    }

    /**
     ** Check exiting student
     **/
    public function checkOldstudent($uid)
    {
        $db = JFactory::getDBO();
        $query_result = $db->getQuery(true);
        $query_result
            ->select($db->quoteName(array('id')))
            ->from($db->quoteName('#__joomschool_book_member'))
            ->where($db->quoteName('student_id') . ' = ' . $db->quote($uid));
        $db->setQuery($query_result);
        $data = $db->loadResult();
        return $data;
    }

    function getStudentname($roll)
    {
        $db = JFactory::getDBO();
        //$query_result = "SELECT name FROM `#__joomschool_students` WHERE roll = '".$roll."'";

        $query_result = $db->getQuery(true);
        $query_result
            ->select($db->quoteName(array('user_id')))
            ->from($db->quoteName('#__joomschool_students'))
            ->where($db->quoteName('roll') . ' = ' . $db->quote($roll));

        $db->setQuery($query_result);
        $data = $db->loadResult();
        return $data;
    }


}
