<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;


class JoomschoolModelBmembers extends JModelList
{

    public function __construct($config = array())
    {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                'id', 'a.id',
                'class', 'a.class',
                'section', 'a.section',
                'division', 'a.division',
                'year', 'a.year',
                'roll', 'a.roll',
                'student_id', 'a.student_id',
                'createdate', 'a.createdate',


            );
        }

        parent::__construct($config);
    }


    protected function populateState($ordering = 'a.id', $direction = 'asc')
    {
        $app = JFactory::getApplication('administrator');

        // Adjust the context to support modal layouts.
        if ($layout = $app->input->get('layout', 'default', 'cmd')) {
            $this->context .= '.' . $layout;
        }

        // Load the filter state.
        $this->setState('filter.search', $this->getUserStateFromRequest($this->context . '.filter.search', 'filter_search', '', 'string'));
        $this->setState('filter.active', $this->getUserStateFromRequest($this->context . '.filter.active', 'filter_active', '', 'cmd'));
        $this->setState('filter.published', $this->getUserStateFromRequest($this->context . '.filter.published', 'filter_published', '', 'cmd'));

        $this->setState('filter.range', $this->getUserStateFromRequest($this->context . '.filter.range', 'filter_range', '', 'cmd'));


        $groups = json_decode(base64_decode($app->input->get('groups', '', 'BASE64')));

        if (isset($groups)) {
            $groups = ArrayHelper::toInteger($groups);
        }

        $this->setState('filter.groups', $groups);

        $excluded = json_decode(base64_decode($app->input->get('excluded', '', 'BASE64')));

        if (isset($excluded)) {
            $excluded = ArrayHelper::toInteger($excluded);
        }

        $this->setState('filter.excluded', $excluded);

        // Load the parameters.
        $params = JComponentHelper::getParams('com_joomschool');
        $this->setState('params', $params);

        // List state information.
        parent::populateState($ordering, $direction);
    }


    protected function getListQuery()
    {
        // Create a new query object.
        $db = $this->getDbo();
        $query = $db->getQuery(true);
        $input = JFactory::getApplication()->input;

        // Select the required fields from the table.
        $query->select(
            $this->getState(
                'list.select',
                'DISTINCT a.id, a.class, a.section, a.division, a.year, a.roll, a.createdate, a.student_id,c.class_name, s.section_name, d.division_name, st.user_id'
            )
        );
        $query->from('#__joomschool_book_member AS a');
        $query->join('LEFT', '#__joomschool_students AS st ON st.id = a.student_id');
        $query->join('LEFT', '#__joomschool_class AS c ON c.id = a.class');
        $query->join('LEFT', '#__joomschool_sections AS s ON s.id = a.section');
        $query->join('LEFT', '#__joomschool_division AS d ON d.id = a.division');


        // Filter by Class.
        $classId = $this->getState('filter.class_id');
        if (is_numeric($classId))
        {
            $query->where('a.class = ' . $db->quote($classId));
        }


        // Filter by year.
        $year_id = $this->getState('filter.year_id');
        if (is_numeric($year_id))
        {
            $query->where('a.year = ' . $db->quote($year_id));
        }

        // Filter by Section.
        $sectionId = $this->getState('filter.section_id');
        if (is_numeric($sectionId))
        {
            $query->where('a.section = ' . $db->quote($sectionId));
        }

        // Filter by Division.
        $divisionId = $this->getState('filter.division_id');
        if (is_numeric($divisionId))
        {
            $query->where('a.division = ' . $db->quote($divisionId));
        }


        // Filter by search in title.
        $search = $this->getState('a.filter.search');

        if (!empty($search))
        {
            if (is_numeric($search))
            {
                $query->where('a.id = ' . (int) $search);
            }

        }
        // Add the list ordering clause.
        $query->order($db->qn($db->escape($this->getState('list.ordering', 'b.book_name'))) . ' ' . $db->escape($this->getState('list.direction', 'ASC')));

        return $query;

    }


}
