<?php
/**
 * @package		JoomSchool
 * @copyright	Copyright (c) 2013-2018 JoomBoost (https://www.joomboost.com). All rights reserved.
 * @license		GNU/GPL http://www.gnu.org/copyleft/gpl.html
 */

// No direct access.
defined('_JEXEC') or die;

/**
 * Model of dashboard view.
 *
 * @package		Joomla.Administrator
 * @subpakage	JoomBoost.Dashboard
 */
class JoomschoolModelDashboard extends JModelLegacy{
	
	private $_stats = array();


	/**
	 * Method to count the number of media added each day for the past 30 days.
	 *
	 * @access  public
	 * @return  mixed   An array of data items on success, false on failure.
	 */
	/**
	 * Get Stats array
	 *
	 * @return array
	 * @since 1.0
	 */
	public function getNewVersion(){
		
		$nversion = '?.?.?';
		$cache = JFactory::getCache('com_joomschool', 'output');
		$cache->setCaching(1);
		$nvcached = $cache->get('joomschool_nversion', 'com_joomschool');
		
		if (!$nvcached) {
			
			$jburl 	= 'https://www.joomboost.com/index.php?option=com_mediastore&task=pluginTask&plugin=joomla&subtask=server&id=177';
			$data 	= JoomschoolHelper::getRemoteData($jburl);
			
			if (!strstr($data , '<?xml version="1.0"?>')) {
				return $nversion ;
			}
			
			$manifest = simplexml_load_string($data, 'SimpleXMLElement');
			
			if (is_null($manifest)) {
				return $nversion ;
			}
			
			$nversion = (string) $manifest ->update->version;
			$cache->store($nversion, 'joomschool_nversion', 'com_joomschool');
			
		}else{
			
			$nversion = $nvcached;
			
		}
		
		return $nversion;
		
	}


    public function getQueryResult($query)
    {

        $db = JFactory::getDbo();

        $db->setQuery($query);
        $db->execute();

        $count = $db->loadResult();

        return $count;
    }

    public function getStats() {
        $count = array();
        $count['students']  = $this->getQueryResult("SELECT COUNT(*) FROM #__joomschool_students s LEFT JOIN #__users u on u.id = s.user_id where username IS NOT NULL");
        $count['teachers']  = $this->getQueryResult("SELECT COUNT(*) FROM #__joomschool_teachers t LEFT JOIN #__users u on u.id = t.user_id where username IS NOT NULL");
        $count['parents']  = $this->getQueryResult("SELECT COUNT(*) FROM #__joomschool_parents p LEFT JOIN #__users u on u.id = p.user_id where username IS NOT NULL");
        $count['attendances']  =  $this->getQueryResult("SELECT COUNT(*) FROM #__joomschool_attendance");
        $count['messages']  = $this->getQueryResult("SELECT COUNT(*) FROM #__joomschool_message");
        $count['exams']  = $this->getQueryResult("SELECT COUNT(*) FROM #__joomschool_exams");
        $count['classes']  = $this->getQueryResult("SELECT COUNT(*) FROM #__joomschool_class");

        foreach ($count as &$stat){

            $stat = $this->bd_nice_number($stat);

        }

        return $count;
    }


    public function getRStats(){

        // get dates
        $currentDate 	= JFactory::getDate()->format('Y-m-d');
        $currentYear 	= JFactory::getDate()->format('Y');
        $now 			= JFactory::getDate()->toSql();
        $lastmonth		= JFactory::getDate('now -1 month')->toSql();
        $lastyear		= JFactory::getDate('now -1 year')->format('Y');

        // build wheres
        $todayWhere 	= "DATE_FORMAT(attendance_date, '%Y-%m-%d') = '$currentDate'";
        $yesterdayWhere = "attendance_date BETWEEN DATE_ADD('$currentDate', INTERVAL -1 day) AND '$currentDate'";
        $thismonthWhere = "attendance_date BETWEEN DATE_SUB('$currentDate',INTERVAL (DAY('$currentDate')-1) DAY) AND LAST_DAY('$now');";
        $lastmonthWhere = "attendance_date BETWEEN DATE_SUB('$lastmonth',INTERVAL (DAY('$lastmonth')-1) DAY) AND LAST_DAY('$lastmonth');";
        $thisyearWhere	= "DATE_FORMAT(attendance_date, '%Y') = '$currentYear'";
        $lastyearWhere	= "DATE_FORMAT(attendance_date, '%Y') = '$lastyear'";
        $tcatsWhere		= "extension = 'com_joomschool'";

        // get counts
        $_stats['total'] 		= $this->getCount();
        $_stats['today'] 		= $this->getCount($todayWhere);
        $_stats['yesterday'] 	= $this->getCount($yesterdayWhere);
        $_stats['thismonth'] 	= $this->getCount($thismonthWhere);
        $_stats['lastmonth'] 	= $this->getCount($lastmonthWhere);
        $_stats['thisyear'] 	= $this->getCount($thisyearWhere);
        $_stats['lastyear'] 	= $this->getCount($lastyearWhere);
        $_stats['categories'] 	= $this->getCount($tcatsWhere,'categories');
        $_stats['attendance']      = $this->getCount(null, 'joomschool_attendance');



        // return all stats
        return $_stats;
    }

    /**
     * method return counts for a given where and table
     *
     * @return int
     * @since 1.0
     */
    public function getCount($where = null, $table = 'joomschool_attendance'){

        $db 		= $this->getDbo();
        $query 		= $db->getQuery(true);

        if(is_null($where))
            $query->select('*')->from("#__$table");
        else
            $query->select('*')->from("#__$table")->where($where);

        $db->setQuery($query)->execute();

        $result 	= $db->getNumRows();

        return $result;
    }




    public function getRecent($type,$column='created')
    {
        // if user connected from frontend or admin
        $user_id = JFactory::getApplication()->isClient('site') ? (int) JFactory::getUser()->id : null;

        $db    = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select("$column created,DATE_FORMAT($column,{$db->quote('%Y-%m-%d')}) AS date, COUNT(*) AS total");
        $query->from("#__joomschool_{$type}");
        $query->where("$column > (NOW() - INTERVAL 30 DAY)");
        if ($user_id > 0 && !is_null($user_id))
        {
            $query->andWhere("user_id ={$user_id}");
        }

        $query->group("DATE_FORMAT($column, {$db->quote('%Y-%m-%d')})");
        $query->order("$column DESC");
        $db->setQuery($query);
        try
        {
            $rows = $db->loadAssocList();
        }
        catch (RuntimeException $e)
        {
            $this->setError($e->getMessage());

            return false;
        }


        return $rows;
    }

    private function bd_nice_number($n) {
        // first strip any formatting;
        $n = (0+str_replace(",","",$n));

        // is this a number?
        if(!is_numeric($n)) return false;

        // now filter it;
        if($n>1000000000000) return round(($n/1000000000000),1).'T';
        else if($n>1000000000) return round(($n/1000000000),1).'G';
        else if($n>1000000) return round(($n/1000000),1).'M';
        else if($n>1000) return round(($n/1000),1).'K';

        return number_format($n);
    }

	
}