<?php
/**
 * @package	JoomSchool !
 * @version	1.0.0
 * @author	joomboost.com
 * @copyright	(C) 2013-2019 JoomBoost. All rights reserved.
 * @license	GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;


class JoomschoolModelExpenseCategories extends JModelList
{


    public function __construct($config = array())
    {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                'id','a.id',
                'name','a.name'
            );
        }

        parent::__construct($config);
    }


    /**
     ** Income populate state
     **/
    protected function populateState($ordering = 'a.id', $direction = 'asc')
    {
        $app = JFactory::getApplication('administrator');

        // Adjust the context to support modal layouts.
        if ($layout = $app->input->get('layout', 'default', 'cmd')) {
            $this->context .= '.' . $layout;
        }

        // Load the filter state.
        $this->setState('filter.name', $this->getUserStateFromRequest($this->context . '.filter.name', 'name', '', 'string'));


        $this->setState('filter.search', $this->getUserStateFromRequest($this->context . '.filter.search', 'filter_search', '', 'string'));


        $excluded = json_decode(base64_decode($app->input->get('excluded', '', 'BASE64')));

        if (isset($excluded)) {
            $excluded = ArrayHelper::toInteger($excluded);
        }

        $this->setState('filter.excluded', $excluded);

        // Load the parameters.
        $params = JComponentHelper::getParams('com_joomschool');
        $this->setState('params', $params);

        // List state information.
        parent::populateState($ordering, $direction);
    }


    protected function getListQuery()
    {
        $db    = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select(
            $this->getState(
                'list.select',
                'a.*'
            )
        );
        $query->from('#__joomschool_expense_category AS a');


        // Filter by id.
        $pId = $this->getState('filter.search');
        if (is_numeric($pId))
        {
            $query->where('a.id = ' . $db->quote($pId));
        }

        // Filter by Name.
        $name = $this->getState('filter.name');
        if (is_numeric($name))
        {
            $query->where('MONTH(a.name) = ' . $db->quote($name));
        }


        // Add the list ordering clause.
        $query->order($db->qn($db->escape($this->getState('list.ordering', 'a.id'))) . ' ' . $db->escape($this->getState('list.direction', 'ASC')));

        return $query;
    }


	
}
