<?php
/**
 * @package	JoomSchool !
 * @version	1.0.0
 * @author	joomboost.com
 * @copyright	(C) 2013-2019 JoomBoost. All rights reserved.
 * @license	GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;


class JoomschoolModelExpenses extends JModelList
{
    public function __construct($config = array())
    {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                'id','a.id',
                'title','a.title',
                'cat','a.title',
                'description','a.description',
                'ammount','a.ammount',
                'method','a.method',
                'expense_date','a.expense_date',
                'uid','a.uid'

            );
        }

        parent::__construct($config);
    }


    /**
     ** Income populate state
     **/
    protected function populateState($ordering = 'a.id', $direction = 'asc')
    {
        $app = JFactory::getApplication('administrator');

        // Adjust the context to support modal layouts.
        if ($layout = $app->input->get('layout', 'default', 'cmd')) {
            $this->context .= '.' . $layout;
        }

        // Load the filter state.
        $this->setState('filter.month_id', $this->getUserStateFromRequest($this->context . '.filter.month_id', 'filter_month_id', '', 'INT'));
        $this->setState('filter.category', $this->getUserStateFromRequest($this->context . '.filter.category', 'filter_category', '', 'INT'));

        $this->setState('filter.search', $this->getUserStateFromRequest($this->context . '.filter.search', 'filter_search', '', 'string'));


        $excluded = json_decode(base64_decode($app->input->get('excluded', '', 'BASE64')));

        if (isset($excluded)) {
            $excluded = ArrayHelper::toInteger($excluded);
        }

        $this->setState('filter.excluded', $excluded);

        // Load the parameters.
        $params = JComponentHelper::getParams('com_joomschool');
        $this->setState('params', $params);

        // List state information.
        parent::populateState($ordering, $direction);
    }


	 protected function getListQuery()
	{
		$db    = JFactory::getDbo();
		$query = $db->getQuery(true);
        $query->select(
            $this->getState(
                'list.select',
                'a.id, a.title, a.cat, a.description, a.ammount, a.method ,a.expense_date ,a.uid, ec.name'
            )
        );
        $query->from('#__joomschool_expenses AS a');
        $query->join('LEFT', '#__joomschool_expense_category AS ec ON ec.id = a.cat');



		// Filter by id.
		$pId = $this->getState('filter.search');
		if (is_numeric($pId))
		{
			$query->where('a.id = ' . $db->quote($pId));
		}

		// Filter by Month.
		$monthId = $this->getState('filter.month_id');
		if (is_numeric($monthId))
		{
			$query->where('MONTH(a.expense_date) = ' . $db->quote($monthId));
		}

		// Filter by category.
		$category = $this->getState('filter.category');
		if (is_numeric($category))
		{
			$query->where('a.cat = ' . $db->quote($category));
		}

		// Filter by Year.
		$yearId = $this->getState('filter.year_id');
		if (is_numeric($yearId))
		{
			$query->where('YEAR(a.expense_date) = ' . $db->quote($yearId));
		}

        // Add the list ordering clause.
        $query->order($db->qn($db->escape($this->getState('list.ordering', 'a.id'))) . ' ' . $db->escape($this->getState('list.direction', 'ASC')));

        return $query;
	}





    /**------------------------------------------------------------------------------------------------------------------
     ** ------------------------------- Expense Category Row Data -------------------------------------------------------
     **-----------------------------------------------------------------------------------------------------------------*/
    function getExpenseCat($id)
    {
        if ($id) {
            $this->_id = $id;
        }
        if (empty($this->_data)) {
            $this->_data = $this->getTable ('expenses');
            $this->_data->load ($this->_id);
        }
        return $this->_data;
    }




    /**------------------------------------------------------------------------------------------------------------------
     ** ------------------------------- Yearly Expense List -------------------------------------------------------------
     **-----------------------------------------------------------------------------------------------------------------*/

    function yearlyList(){
        $db    = JFactory::getDbo();
        $sql = "SELECT year(p.expense_date) as year,  p.id, sum(p.ammount) as Total ".
            "FROM #__joomschool_expenses as p ".
            "GROUP BY year(p.expense_date) ".
            "ORDER BY year(p.expense_date) ASC";
        $db->setQuery($sql);
        $result = $db->loadObjectList();
        return $result;
    }


    /**------------------------------------------------------------------------------------------------------------------
     ** ------------------------------- Expense Category List -----------------------------------------------------------
     **-----------------------------------------------------------------------------------------------------------------*/
	function getCatName($id){
	      $db = JFactory::getDBO();
			  $query = $db->getQuery(true);
				$query
             ->select($db->quoteName(array('name')))
             ->from($db->quoteName('#__joomschool_expense_category'))
             ->where($db->quoteName('id') . ' = '. $db->quote($id));
				$db->setQuery($query);
				$data = $db->loadResult();
				return $data;
	}
	
	function getEntryName($id){
	      $db = JFactory::getDBO();
			  $query = $db->getQuery(true);
				$query
             ->select($db->quoteName(array('name')))
             ->from($db->quoteName('#__users'))
             ->where($db->quoteName('id') . ' = '. $db->quote($id));
				$db->setQuery($query);
				$data = $db->loadResult();
				return $data;
	}
	

	
	/**------------------------------------------------------------------------------------------------------------------
	 ** ------------------------------- Expense Category List -----------------------------------------------------------
	 **-----------------------------------------------------------------------------------------------------------------*/
	function getcatList($id){
	     $db = JFactory::getDBO();
        $query = "SELECT id,name FROM `#__joomschool_expense_category`";
        $query.=" ORDER BY id asc ";
        $db->setQuery($query);
        $rows = $db->loadObjectList();
        if ($db->getErrorNum()) {
            echo $db->stderr();
            return false;
        }
        $expense_cat = array();
				$expense_cat[] = array('value' => '', 'text' => JText::_(' -- Select Category -- '));
        foreach ($rows as $row) {
            $expense_cat[] = array('value' => $row->id, 'text' => JText::_(' '.$row->name));
        }
			 $category =  JHTML::_('select.genericList', $expense_cat, 'cat', 'class="required  inputbox  " required="required" ', 'value', 'text',$id);
       return $category;
	}

	
}
