<?php
/**
 * @package	JoomSchool !
 * @version	1.0.0
 * @author	joomboost.com
 * @copyright	(C) 2013-2019 JoomBoost. All rights reserved.
 * @license	GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;


class JoomschoolModelFields extends JModelList
{

    public function __construct($config = array())
    {
        if (empty($config['filter_fields'])) {

            $config['filter_fields'] = array(
                'id', 'a.id',
                'field_name', 'a.field_name',
                'published', 'a.published',
                'required','a.required',
                'section','a.section',
                'type','a.type',
                'field_order','a.field_order',

            );
        }

        parent::__construct($config);
    }



    protected function populateState($ordering = 'a.field_order', $direction = 'asc')
    {
        $app = JFactory::getApplication('administrator');

        // Adjust the context to support modal layouts.
        if ($layout = $app->input->get('layout', 'default', 'cmd')) {
            $this->context .= '.' . $layout;
        }

        // Load the filter state.
        $this->setState('filter.section_id', $this->getUserStateFromRequest($this->context . '.filter.section_id', 'filter_section_id', '', 'INT'));
        $this->setState('filter.type_id', $this->getUserStateFromRequest($this->context . '.filter.type_id', 'filter_type_id', '', 'INT'));
        $this->setState('filter.search', $this->getUserStateFromRequest($this->context . '.filter.search', 'filter_search', '', 'string'));
        $this->setState('filter.active', $this->getUserStateFromRequest($this->context . '.filter.active', 'filter_active', '', 'cmd'));
        $this->setState('filter.published', $this->getUserStateFromRequest($this->context . '.filter.published', 'filter_published', '', 'cmd'));

        $this->setState('filter.range', $this->getUserStateFromRequest($this->context . '.filter.range', 'filter_range', '', 'cmd'));


        $groups = json_decode(base64_decode($app->input->get('groups', '', 'BASE64')));

        if (isset($groups)) {
            $groups = ArrayHelper::toInteger($groups);
        }

        $this->setState('filter.groups', $groups);

        $excluded = json_decode(base64_decode($app->input->get('excluded', '', 'BASE64')));

        if (isset($excluded)) {
            $excluded = ArrayHelper::toInteger($excluded);
        }

        $this->setState('filter.excluded', $excluded);

        // Load the parameters.
        $params = JComponentHelper::getParams('com_joomschool');
        $this->setState('params', $params);

        // List state information.
        parent::populateState($ordering, $direction);
    }




    protected function getListQuery()
	{
		$db    = JFactory::getDbo();
		$query = $db->getQuery(true);
        $query->select(
            $this->getState(
                'list.select',
                'DISTINCT a.*,t.type as type_name,s.name'
            )
        );
        $query->from('#__joomschool_fields AS a');
        $query->join('LEFT', '#__joomschool_fields_section AS s ON s.id = a.section');
        $query->join('LEFT', '#__joomschool_fields_type AS t ON t.id = a.type');




        // Filter by section
		$sectionId = $this->getState('list.section_id');
		if (is_numeric($sectionId))
		{
			$query->where('a.section = ' . $db->quote($sectionId));
		}
		
		// Filter by type
		$type_id = $this->getState('list.type_id');
		if (is_numeric($type_id))
		{
			$query->where('a.type = ' . $db->quote($type_id));
		}
		
		// Filter by search in title.
		$search = $this->getState('filter.search');

		if (!empty($search))
		{
			if (is_numeric($search))
			{
				$query->where('a.id = ' . (int) $search);
			}
			else
			{
				$search = $db->quote('%' . str_replace(' ', '%', $db->escape(trim($search), true) . '%'));
				$query->where('(a.field_name LIKE ' . $search . ' OR id LIKE ' . $search . ')');
			}
		}

        $orderCol	= $this->state->get('list.ordering', 'field_order');
        $orderDirn 	= $this->state->get('list.direction', 'asc');
        $query->order($db->escape($orderCol) . ' ' . $db->escape($orderDirn));
		return $query;
	}
	


}
