<?php
/**
 * @package     Joomla.Administrator
 * @subpackage  com_joomschool
 *
 * @copyright   Copyright (C) 2005 - 2019 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('JPATH_BASE') or die;

use Joomla\CMS\Language\LanguageHelper;

/**
 * Supports a modal course picker.
 *
 * @since  1.6
 */
class JFormFieldModal_Student extends JFormField
{
	/**
	 * The form field type.
	 *
	 * @var    string
	 * @since  1.6
	 */
	protected $type = 'Modal_Student';

	/**
	 * Method to get the field input markup.
	 *
	 * @return  string  The field input markup.
	 *
	 * @since   1.6
	 */
    /**
     * Method to get the field input markup
     */


    protected function getInput()
    {
        // Load language
        JFactory::getLanguage()->load('com_joomschool', JPATH_ADMINISTRATOR);

        // $this->value is set if there's a default id specified in the xml file
        $value = (int) $this->value > 0 ? (int) $this->value : '';

        // $this->id will be jform_request_xxx where xxx is the name of the field in the xml file
        $modalId = 'Student_' . $this->id;

        // Add the modal field script to the document head.
        JHtml::_('jquery.framework');
        JHtml::_('script', 'system/modal-fields.js', array('version' => 'auto', 'relative' => true));

        // our callback function from the modal to the main window:
        JFactory::getDocument()->addScriptDeclaration("
			function jSelectStudent_" . $this->id . "(id, name, username,object) {
				window.processModalSelect('Student', '" . $this->id . "', id, name, username, object);
			}
			");

        // if a default id is set, then get the corresponding greeting to display it
        if ($value)
        {
            $db = JFactory::getDbo();
            $query = $db->getQuery(true);
            $query->select('a.name');
            $query->from('#__users AS a');
            $query->join('INNER', '#__joomschool_students AS st ON st.user_id = a.id');
            $query->join('LEFT', '#__user_usergroup_map AS m ON m.user_id = a.id');
            $query->join('LEFT', '#__usergroups AS ug ON ug.id = m.group_id');
            $query->where("st.user_id = ".(int)$this->value);
            $db->setQuery($query);

            try
            {
                $title = $db->loadResult();
            }
            catch (RuntimeException $e)
            {
                JError::raiseWarning(500, $e->getMessage());
            }
        }

        // display the default greeting or "Select" if no default specified
        $title = empty($title) ? JText::_('COM_JOOMSCHOOL_MENUITEM_SELECT_STUDENT') : htmlspecialchars($title, ENT_QUOTES, 'UTF-8');
        $html  = '<span class="input-append">';
        $html .= '<input class="input-medium" id="' . $this->id . '_name" type="text" value="' . $title . '" disabled="disabled" size="35" />';

        // html for the Select button
        $html .= '<a'
            . ' class="btn hasTooltip' . ($value ? ' hidden' : '') . '"'
            . ' id="' . $this->id . '_select"'
            . ' data-toggle="modal"'
            . ' role="button"'
            . ' href="#ModalSelect' . $modalId . '"'
            . ' title="' . JHtml::tooltipText('COM_JOOMSCHOOL_MENUITEM_SELECT_STUDENT') . '">'
            . '<span class="icon-file" aria-hidden="true"></span> ' . JText::_('JSELECT')
            . '</a>';

        // html for the Clear button
        $html .= '<a'
            . ' class="btn' . ($value ? '' : ' hidden') . '"'
            . ' id="' . $this->id . '_clear"'
            . ' href="#"'
            . ' onclick="window.processModalParent(\'' . $this->id . '\'); return false;">'
            . '<span class="icon-remove" aria-hidden="true"></span>' . JText::_('JCLEAR')
            . '</a>';

        $html .= '</span>';

        // url for the iframe
        $linkStudents = 'index.php?option=com_joomschool&amp;view=students&amp;layout=modal&amp;tmpl=component&amp;' . JSession::getFormToken() . '=1';
        $urlSelect = $linkStudents . '&amp;function=jSelectStudent_' . $this->id;

        // title to go in the modal header
        $modalTitle    = JText::_('COM_JOOMSCHOOL_MENUITEM_SELECT_MODAL_TITLE');

        // html to set up the modal iframe
        $html .= JHtml::_(
            'bootstrap.renderModal',
            'ModalSelect' . $modalId,
            array(
                'title'       => $modalTitle,
                'url'         => $urlSelect,
                'height'      => '400px',
                'width'       => '800px',
                'bodyHeight'  => '70',
                'modalWidth'  => '80',
                'footer'      => '<a role="button" class="btn" data-dismiss="modal" aria-hidden="true">' . JText::_('JLIB_HTML_BEHAVIOR_CLOSE') . '</a>',
            )
        );

        // class='required' for client side validation.
        $class = $this->required ? ' class="required modal-value"' : '';

        // hidden input field to store the helloworld record id
        $html .= '<input type="hidden" id="' . $this->id . '_id" ' . $class
            . ' data-required="' . (int) $this->required . '" name="' . $this->name
            . '" data-text="' . htmlspecialchars(JText::_('COM_JOOMSCHOOL_MENUITEM_SELECT_STUDENT', true), ENT_COMPAT, 'UTF-8')
            . '" value="' . $value . '" />';

        return $html;
    }

    /**
     * Method to get the html for the label field.
     *
     * @return  string  The field label html.
     */
    protected function getLabel()
    {
        return str_replace($this->id, $this->id . '_id', parent::getLabel());
    }
}
