<?php
/**
 * @package	JoomSchool !
 * @version	1.0.0
 * @author	joomboost.com
 * @copyright	(C) 2013-2019 JoomBoost. All rights reserved.
 * @license	GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
 
// No direct access.
defined('_JEXEC') or die();
 
JFormHelper::loadFieldClass('list');
 
/**
 * Supports an HTML select list of categories
 */
class JFormFieldSection extends JFormFieldList
{
    /**
     * The form field type.
     *
     * @var     string
     * @since   1.6
     */
    protected $type = 'section';
 
    /**
     * Fiedd to decide if options are being loaded externally and from xml
     *
     * @var     integer
     * @since   2.2
     */
    protected $loadExternally = 0;
 
    /**
     * Method to get a list of options for a list input.
     *
     * @return  array       An array of JHtml options.
     *
     * @since   11.4
     */
    protected function getOptions()
    {

        $user = JFactory::getUser();

        // check if teacher then display only teacher sections in frontend only
        if (
            JoomschoolHelper::checkGroup($user->id) == "Teachers" &&
            \Joomla\CMS\Factory::getApplication()->isClient('site')
        ) {

            $sections= JoomschoolHelper::getTeacherSections();

        }else{ // for backend nad other cases
            $sections = $this->getAllSections();
        }



 
        $options = array();
 
        // Load lang file for countries
        //$lang = JFactory::getLanguage();
     //   $lang->load('tjgeo.countries', JPATH_SITE, null, false, true);
 
        foreach ($sections as $c)
        {
            $options[] = JHtml::_('select.option', $c->id, $c->section_name);
        }

        if (!$this->loadExternally)
        {
            // Merge any additional options in the XML definition.
            $options = array_merge(parent::getOptions(), $options);
        }
 
        return $options;
    }

    public function getAllSections(){
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);

        // Select the required fields from the table.
        $query->select('c.id, c.	section_name');
        $query->from('`#__joomschool_sections` AS c');


        $query->order($db->escape('c.id ASC'));

        $db->setQuery($query);

        // Get all countries.
        return $db->loadObjectList();
    }
 
    /**
     * Method to get a list of options for a list input externally and not from xml.
     *
     * @return  array       An array of JHtml options.
     *
     * @since   2.2
     */
    public function getOptionsExternally()
    {
        $this->loadExternally = 1;
 
        return $this->getOptions();
    }
}
