<?php
/**
 * @package	JoomSchool !
 * @version	1.0.0
 * @author	joomboost.com
 * @copyright	(C) 2013-2019 JoomBoost. All rights reserved.
 * @license	GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
 
// No direct access.
defined('_JEXEC') or die();
 
JFormHelper::loadFieldType('list');
 
/**
 * Supports an HTML select list of categories
 */
class JFormFieldSubject extends JFormFieldList
{
    /**
     * The form field type.
     *
     * @var     string
     * @since   1.6
     */
    protected $type = 'subject';
 
    /**
     * Fiedd to decide if options are being loaded externally and from xml
     *
     * @var     integer
     * @since   2.2
     */
    protected $loadExternally = 0;
 
    /**
     * Method to get a list of options for a list input.
     *
     * @return  array       An array of JHtml options.
     *
     * @since   11.4
     */
    protected function getOptions()
    {

        $subjectsOptions = [];

        $mode = $this->getAttribute('mode',0);

        // get all subjects

        if($mode == 2 ){ // mode 2 : get subjects by classes

            $formData = $this->form->getData(); // get all form data
            $classId = $formData->get('class',0); // get class id from form data
            $subjectsOptions = self::getSubjectsByClass($classId); // get subjects by class

            // load extra js code for updating options
            $this->loadUpdateOptionsByClassJS();


        }else{ // default get all subjects

            $subjectsOptions = $this->getAllSubjects();

        }

 
        $options = array();

        foreach ($subjectsOptions as $c)
        {
            $options[] = JHtml::_('select.option', $c->id, "$c->subject_name ($c->subject_code)");
        }
 
        if (!$this->loadExternally)
        {
            // Merge any additional options in the XML definition.
            $options = array_merge(parent::getOptions(), $options);
        }
 
        return $options;
    }
 
    /**
     * Method to get a list of options for a list input externally and not from xml.
     *
     * @return  array       An array of JHtml options.
     *
     * @since   2.2
     */
    public function getOptionsExternally()
    {
        $this->loadExternally = 1;
 
        return $this->getOptions();
    }

    public static function getSubjectsByClass($classId){

            // inits
            $db = JFactory::getDBO();
            $subjects = [];

            // get subjects

            $query = $db->getQuery(true);
            $query
                ->select('subject_id')
                ->from($db->quoteName('#__joomschool_class'))
                ->where($db->quoteName('id') . ' = ' . (int) $classId);

            $db->setQuery($query);
            $result = $db->loadResult();

            if(is_null($result))
                return $subjects;

            // if subjects found explode to array

            $subjectsList = explode(',',$result);

            // get subjects name and ids
            foreach ($subjectsList as $subject){

                $query = $db->getQuery(true);
                $query
                    ->select('*')
                    ->from($db->quoteName('#__joomschool_subjects'))
                    ->where($db->quoteName('id') . ' = ' . (int) $subject)
                    ->where("published = 1");

                $db->setQuery($query);
                $result = $db->loadObject();

                if(is_null($result))
                    continue;

                $subjects[] = $result;
            }

            return $subjects;


    }

    public function getAllSubjects(){

        $db = JFactory::getDbo();
        $query = $db->getQuery(true);

        // Select the required fields from the table.
        $query->select('*');
        $query->from('#__joomschool_subjects');


        $query->order($db->escape('id ASC'));

        $db->setQuery($query);

        // Get all countries.
        return $db->loadObjectList();

    }


    public function loadUpdateOptionsByClassJS(){

        $controllerName = $this->getAttribute('controller','attendance');


        $js = <<<js
jQuery(document).ready(function($){

        $('form').on('change','#jform_class', function() {

           let classId =  $(this).find('option:selected').val();

           $('#jform_class_subjects').empty();

            $.post(
                Joomla.getOptions('system.paths').base+'/index.php?option=com_joomschool&task=$controllerName.getClassSubjects',
                {classId: classId},
                function (data) {
                    $(data).appendTo('select#jform_class_subjects');
                    $("#jform_class_subjects").trigger("liszt:updated");
                    $("#jform_class_subjects").trigger("chosen:updated");
                });

        });


    });
js;

        JFactory::getApplication()->getDocument()->addScriptDeclaration($js);



    }

}
