<?php
/**
 * @package	JoomSchool !
 * @version	1.0.0
 * @author	joomboost.com
 * @copyright	(C) 2013-2019 JoomBoost. All rights reserved.
 * @license	GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
 
// No direct access.
defined('_JEXEC') or die();
 
JFormHelper::loadFieldClass('list');
 
/**
 * Supports an HTML select list of categories
 */
class JFormFieldTeacher extends JFormFieldList
{
    /**
     * The form field type.
     *
     * @var     string
     * @since   1.6
     */
    protected $type = 'Teacher';
 
    /**
     * Fiedd to decide if options are being loaded externally and from xml
     *
     * @var     integer
     * @since   2.2
     */
    protected $loadExternally = 0;
 
    /**
     * Method to get a list of options for a list input.
     *
     * @return  array       An array of JHtml options.
     *
     * @since   11.4
     */
    protected function getOptions()
    {
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
       
        // Select the required fields from the table.
        $query->select('s.id,s.user_id');
        $query->from('`#__joomschool_teachers` AS s');
        $query->order($db->escape('s.id ASC'));
        $query->where('s.state = 1');
 
        $db->setQuery($query);
 
        // Get all countries.
        $teachers = $db->loadObjectList();

 
        $options = array();

        foreach ($teachers as $teacher)
        {

            $teacherUser = JFactory::getUser($teacher->user_id);
            $options[] = JHtml::_('select.option', $teacher->id, $teacherUser->name);
        }

        if (!$this->loadExternally)
        {
            // Merge any additional options in the XML definition.
            $options = array_merge(parent::getOptions(), $options);
        }
 
        return $options;
    }
 
    /**
     * Method to get a list of options for a list input externally and not from xml.
     *
     * @return  array       An array of JHtml options.
     *
     * @since   2.2
     */
    public function getOptionsExternally()
    {
        $this->loadExternally = 1;
 
        return $this->getOptions();
    }
}
