<?php
/**
 * @package	JoomSchool !
 * @version	1.0.0
 * @author	joomboost.com
 * @copyright	(C) 2013-2019 JoomBoost. All rights reserved.
 * @license	GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;


class JoomschoolModelLibraries extends JModelList
{

    public function __construct($config = array())
    {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                'id', 'a.id',
                'student_id','a.student_id',
                'roll','a.roll',
                'issue_date','a.issue_date',
                'priod','a.priod',
                'return_date','a.return_date',
                'book_category','a.book_category',
                'book_id','a.book_id',
                'class','a.class',
                'add_date','a.add_date',
                'accept','a.accept',

            );
        }

        parent::__construct($config);
    }



    protected function populateState($ordering = 'a.id', $direction = 'asc')
    {
        $app = JFactory::getApplication('administrator');

        // Adjust the context to support modal layouts.
        if ($layout = $app->input->get('layout', 'default', 'cmd')) {
            $this->context .= '.' . $layout;
        }

        // Load the filter state.
        $this->setState('filter.search', $this->getUserStateFromRequest($this->context . '.filter.search', 'filter_search', '', 'string'));
        $this->setState('filter.active', $this->getUserStateFromRequest($this->context . '.filter.active', 'filter_active', '', 'cmd'));
        $this->setState('filter.published', $this->getUserStateFromRequest($this->context . '.filter.published', 'filter_published', '', 'cmd'));

        $this->setState('filter.range', $this->getUserStateFromRequest($this->context . '.filter.range', 'filter_range', '', 'cmd'));


        $groups = json_decode(base64_decode($app->input->get('groups', '', 'BASE64')));

        if (isset($groups)) {
            $groups = ArrayHelper::toInteger($groups);
        }

        $this->setState('filter.groups', $groups);

        $excluded = json_decode(base64_decode($app->input->get('excluded', '', 'BASE64')));

        if (isset($excluded)) {
            $excluded = ArrayHelper::toInteger($excluded);
        }

        $this->setState('filter.excluded', $excluded);

        // Load the parameters.
        $params = JComponentHelper::getParams('com_joomschool');
        $this->setState('params', $params);

        // List state information.
        parent::populateState($ordering, $direction);
    }






    protected function getListQuery()
    {
        // Create a new query object.
        $db = $this->getDbo();
        $query = $db->getQuery(true);
        $user = JFactory::getUser();
        $input = JFactory::getApplication()->input;

        // Select the required fields from the table.
        $query->select(
            $this->getState(
                'list.select',
                'a.id,a.student_id,a.roll,a.issue_date,a.priod,a.return_date,a.book_category,a.book_id,a.class,	a.add_date,a.accept,st.user_id,b.book_name'
            )
        );
        $query->from('#__joomschool_book_issue AS a');
        $query->join('LEFT', '#__joomschool_book AS b ON b.id = a.book_id');
        $query->join('LEFT', '#__joomschool_students AS st ON st.id = a.student_id');

        // Filter by published state

        // Filter by Class.
        $classId = $this->getState('filter.class_id');
        if (is_numeric($classId))
        {
            $query->where('a.class = ' . $db->quote($classId));
        }

        // Filter by book.
        $book_id = $this->getState('filter.book_id');
        if (is_numeric($book_id))
        {
            $query->where('a.book_id = ' . $db->quote($book_id));
        }

        // Filter by accept.
        $accept = $this->getState('list.accept');
        if (is_numeric($accept))
        {
            $query->where('a.accept = ' . $db->quote($accept));
        }

        // Filter by search by student roll.
        $search = $this->getState('filter.search');
        if (!empty($search))
        {
            if (is_numeric($search))
            {
                $query->where('a.roll = ' . (int) $search);
            }

        }
        // Add the list ordering clause.
        $query->order($db->qn($db->escape($this->getState('list.ordering', 'a.id'))) . ' ' . $db->escape($this->getState('list.direction', 'ASC')));


        return $query;

    }



}
