<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;


class JoomschoolModelLibrary extends JModelAdmin
{
    /**
     * Prepare and sanitise the table data prior to saving.
     *
     * @param JTable $table A JTable object.
     *
     * @return  void
     *
     * @since   1.6
     */
    protected function prepareTable($table)
    {
        // Set the publish date to now
        if ($table->state == 1 && (int)$table->publish_up == 0) {
            $table->publish_up = JFactory::getDate()->toSql();
        }

        if ($table->state == 1 && intval($table->publish_down) == 0) {
            $table->publish_down = $this->getDbo()->getNullDate();
        }

    }

    /**
     * Returns a Table object, always creating it.
     *
     * @param string $type The table type to instantiate
     * @param string $prefix A prefix for the table class name. Optional.
     * @param array $config Configuration array for model. Optional.
     *
     * @return  JTable    A database object
     */
    public function getTable($type = 'Library', $prefix = 'Table', $config = array())
    {


        return JTable::getInstance($type, $prefix, $config);
    }

    /**
     * Method to get a single record.
     *
     * @param integer $pk The id of the primary key.
     *
     * @return  mixed  Object on success, false on failure.
     */
    public function getItem($pk = null)
    {
        $item = parent::getItem($pk);

        return $item;
    }

    /**
     * Method to get the record form.
     *
     * @param array $data Data for the form.
     * @param boolean $loadData True if the form is to load its own data (default case), false if not.
     *
     * @return  JForm|boolean  A JForm object on success, false on failure
     *
     * @since   1.6
     */
    public function getForm($data = array(), $loadData = true)
    {


        $app = JFactory::getApplication();
        $user = JFactory::getUser();

        // Get the form.
        $form = $this->loadForm('com_joomschool.library', 'library', array('control' => 'jform', 'load_data' => $loadData));


        if (empty($form)) {
            return false;
        }

        $jinput = JFactory::getApplication()->input;

        /*
         * The front end calls this model and uses a_id to avoid id clashes so we need to check for that first.
         * The back end uses id so we use that the rest of the time and set it to 0 by default.
         */
        $id = $jinput->get('a_id', $jinput->get('id', 0));

        // Determine correct permissions to check.

        // Check for existing article.
        // Modify the form based on Edit State access controls.
        if ($id != 0 && (!$user->authorise('core.edit.state', 'com_joomschool.library.' . (int)$id))
            || ($id == 0 && !$user->authorise('core.edit.state', 'com_joomschool'))) {
            // Disable fields for display.
            $form->setFieldAttribute('ordering', 'disabled', 'true');
            $form->setFieldAttribute('published', 'disabled', 'true');

            // Disable fields while saving.
            // The controller has already verified this is an article you can edit.
            $form->setFieldAttribute('ordering', 'filter', 'unset');
            $form->setFieldAttribute('published', 'filter', 'unset');
        }

        // Prevent messing with article language and category when editing existing article with associations


        return $form;
    }

    /**
     * Method to get the data that should be injected in the form.
     *
     * @return  mixed  The data for the form.
     *
     * @since   1.6
     */
    protected function loadFormData()
    {
        // Check the session for previously entered form data.
        $app = JFactory::getApplication();
        $input = $app->input;
        $data = $app->getUserState('com_joomschool.edit.library.data', array());


        if (empty($data)) {


            $data = $this->getItem();


            // Pre-select some filters (Status, Category, Language, Access) in edit form if those have been selected in Article Manager: Articles
            if ($this->getState('a.library') == 0) {
                $filters = (array)$app->getUserState('com_joomschool.section.filter');
                $data->set(
                    'state',
                    $app->input->getInt(
                        'state',
                        ((isset($filters['published']) && $filters['published'] !== '') ? $filters['published'] : null)
                    )
                );

                $data->set('language', $app->input->getString('language', (!empty($filters['language']) ? $filters['language'] : null)));
                $data->set('access',
                    $app->input->getInt('access', (!empty($filters['access']) ? $filters['access'] : JFactory::getConfig()->get('access')))
                );
            }
        }

        // If there are params fieldsets in the form it will fail with a registry object
        if (isset($data->params) && $data->params instanceof Registry) {
            $data->params = $data->params->toArray();
        }

        $this->preprocessData('com_joomschool.library', $data);

        return $data;
    }

    /**
     * Method to validate the form data.
     *
     * @param JForm $form The form to validate against.
     * @param array $data The data to validate.
     * @param string $group The name of the field group to validate.
     *
     * @return  array|boolean  Array of filtered data if valid, false otherwise.
     *
     * @see     JFormRule
     * @see     JFilterInput
     * @since   3.7.0
     */
    public function validate($form, $data, $group = null)
    {

        return parent::validate($form, $data, $group);
    }

    /**
     * Method to save the form data.
     *
     * @param array $data The form data.
     *
     * @return  boolean  True on success.
     *
     * @since   1.6
     */
    public function save($data)
    {

        if (!$data['id']) {
            $student = $this->getMemberID($data['roll'], $data['class']);
            $data['student_id'] = $student->student_id;


            if (!$student->student_id) {
                JFactory::getApplication()->enqueueMessage('The roll number not match with library member ! please try again ', 'error');
                return false;
            }


        }


        // continue saving library data ...
        if (parent::save($data)) {

            return true;
        }

        return false;
    }


    /**
     ** Category List
     **/
    function getcategoryList($value)
    {

        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('id', 'catname')))
            ->from($db->quoteName('#__joomschool_book_category'))
            ->order('id ASC');
        $db->setQuery($query);
        $rows = $db->loadObjectList();
        if ($db->getErrorNum()) {
            echo $db->stderr();
            return false;
        }
        $category_array = array();

        $category_array[] = array('value' => '', 'text' => JText::_(' -- Select Book Category -- '));
        foreach ($rows as $row) {
            $category_array[] = array('value' => $row->id, 'text' => JText::_(' ' . $row->catname));
        }

        $category = JHTML::_('select.genericList', $category_array, 'book_category', ' class="required  inputbox  " required="required"  ', 'value', 'text', $value);
        return $category;
    }

    /**
     ** Book List
     **/
    function getbookList($cat_id, $value)
    {

        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('id', 'book_name')))
            ->from($db->quoteName('#__joomschool_book'))
            ->where($db->quoteName('id') . ' = ' . $db->quote($cat_id))
            ->order('id ASC');
        $db->setQuery($query);
        $rows = $db->loadObjectList();
        if ($db->getErrorNum()) {
            echo $db->stderr();
            return false;
        }
        $book_array = array();

        $book_array[] = array('value' => '', 'text' => JText::_(' -- Select Book  -- '));
        foreach ($rows as $row) {
            $book_array[] = array('value' => $row->id, 'text' => JText::_(' ' . $row->book_name));
        }

        $books = JHTML::_('select.genericList', $book_array, 'book_id', ' class="required  inputbox  " required="required"  ', 'value', 'text', $value);
        return $books;
    }

    /**
     ** Get Member ID
     **/
    function getMemberID($roll, $student_class)
    {
        $db = JFactory::getDBO();
        $query_result = $db->getQuery(true);
        $query_result
            ->select(array('a.student_id', 'st.user_id'))
            ->from('#__joomschool_book_member AS a')
            ->join('LEFT', '#__joomschool_students AS st ON st.id = a.student_id')
            ->where('a.class = ' . (int) $student_class)
            ->where('a.roll = ' . $db->quote($roll));

        $db->setQuery($query_result);
        $data = $db->loadObject();
        return $data;
    }

    public function preprocessForm(\JForm $form, $data, $group = 'content')
    {

        if (JFactory::getApplication()->input->getInt('id', 0)) {
            $form->removeField('class');
            $form->removeField('roll');
            $form->removeField('issue_date');
            $form->removeField('book_category');
            $form->removeField('book_id');
        }


        parent::preprocessForm($form, $data, $group); // TODO: Change the autogenerated stub
    }

    /**
     ** Get Student Name by Roll
     **/
    function getStudentname($roll)
    {
        $db = JFactory::getDBO();
        $query_result = $db->getQuery(true);
        $query_result
            ->select($db->quoteName(array('user_id')))
            ->from($db->quoteName('#__joomschool_students'))
            ->where($db->quoteName('roll') . ' = ' . $db->quote($roll));
        $db->setQuery($query_result);
        $data = $db->loadResult();
        return $data;
    }

    /**
     ** Get book name
     **/
    function getbookname($id)
    {
        $db = JFactory::getDBO();
        $query_result = $db->getQuery(true);
        $query_result
            ->select($db->quoteName(array('book_name')))
            ->from($db->quoteName('#__joomschool_book'))
            ->where($db->quoteName('id') . ' = ' . $db->quote($id));
        $db->setQuery($query_result);
        $data = $db->loadResult();
        return $data;
    }

    /**
     ** issue row data
     ***/
    function getLibrary($id)
    {
        if ($id) {
            $this->_id = $id;
        }
        if (empty($this->_data)) {
            $this->_data = $this->getTable('library');
            $this->_data->load($this->_id);
        }
        return $this->_data;
    }


}
