<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;

use Joomla\Registry\Registry;

class JoomschoolModelMessage extends JModelAdmin
{


    /**
     * Prepare and sanitise the table data prior to saving.
     *
     * @param JTable $table A JTable object.
     *
     * @return  void
     *
     * @since   1.6
     */
    protected function prepareTable($table)
    {
        // Set the publish date to now
        if ($table->state == 1 && (int)$table->publish_up == 0) {
            $table->publish_up = JFactory::getDate()->toSql();
        }

        if ($table->state == 1 && intval($table->publish_down) == 0) {
            $table->publish_down = $this->getDbo()->getNullDate();
        }

    }

    /**
     * Returns a Table object, always creating it.
     *
     * @param string $type The table type to instantiate
     * @param string $prefix A prefix for the table class name. Optional.
     * @param array $config Configuration array for model. Optional.
     *
     * @return  JTable    A database object
     */
    public function getTable($type = 'Message', $prefix = 'Table', $config = array())
    {

        return JTable::getInstance($type, $prefix, $config);
    }

    /**
     * Method to get a single record.
     *
     * @param integer $pk The id of the primary key.
     *
     * @return  mixed  Object on success, false on failure.
     */
    public function getItem($pk = null)
    {
        $item = parent::getItem($pk);
        return $item;
    }


    public function getReplyForm(){

        $form = \Joomla\CMS\Form\Form::getInstance("messagereply", __DIR__ . "/forms/messagereply.xml");

        return $form;

    }

    /**
     * Method to get the record form.
     *
     * @param array $data Data for the form.
     * @param boolean $loadData True if the form is to load its own data (default case), false if not.
     *
     * @return  JForm|boolean  A JForm object on success, false on failure
     *
     * @since   1.6
     */
    public function getForm($data = array(), $loadData = true)
    {

        $app = JFactory::getApplication();
        $user = JFactory::getUser();

        // Get the form.
        $form = $this->loadForm('com_joomschool.message', 'message', array('load_data' => $loadData));


        if (empty($form)) {
            return false;
        }



        $jinput = JFactory::getApplication()->input;

        /*
         * The front end calls this model and uses a_id to avoid id clashes so we need to check for that first.
         * The back end uses id so we use that the rest of the time and set it to 0 by default.
         */
        $id = $jinput->get('a_id', $jinput->get('id', 0));

        // Determine correct permissions to check.

        // Check for existing article.
        // Modify the form based on Edit State access controls.
        if ($id != 0 && (!$user->authorise('core.edit.state', 'com_joomschool.parent.' . (int)$id))
            || ($id == 0 && !$user->authorise('core.edit.state', 'com_joomschool'))) {
            // Disable fields for display.
            $form->setFieldAttribute('ordering', 'disabled', 'true');
            $form->setFieldAttribute('state', 'disabled', 'true');

            // Disable fields while saving.
            // The controller has already verified this is an article you can edit.
            $form->setFieldAttribute('ordering', 'filter', 'unset');
            $form->setFieldAttribute('state', 'filter', 'unset');
        }

        // Prevent messing with article language and category when editing existing article with associations


        return $form;
    }

    /**
     * Method to get the data that should be injected in the form.
     *
     * @return  mixed  The data for the form.
     *
     * @since   1.6
     */
    protected function loadFormData()
    {
        // Check the session for previously entered form data.
        $app = JFactory::getApplication();
        $input = $app->input;
        $data = $app->getUserState('com_joomschool.edit.message.data', array());
        
        if (empty($data)) {

            $student_id = $input->getInt('id', 0);
            $data = $this->getItem();



            // Pre-select some filters (Status, Category, Language, Access) in edit form if those have been selected in Article Manager: Articles
            if ($this->getState('message.id') == 0) {
                $filters = (array)$app->getUserState('com_joomschool.messages.filter');
                $data->set(
                    'state',
                    $app->input->getInt(
                        'state',
                        ((isset($filters['published']) && $filters['published'] !== '') ? $filters['published'] : null)
                    )
                );

                $data->set('language', $app->input->getString('language', (!empty($filters['language']) ? $filters['language'] : null)));
                $data->set('access',
                    $app->input->getInt('access', (!empty($filters['access']) ? $filters['access'] : JFactory::getConfig()->get('access')))
                );
            }
        }

        // If there are params fieldsets in the form it will fail with a registry object
        if (isset($data->params) && $data->params instanceof Registry) {
            $data->params = $data->params->toArray();
        }

        $this->preprocessData('com_joomschool.message', $data);

        return $data;
    }

    /**
     * Method to validate the form data.
     *
     * @param JForm $form The form to validate against.
     * @param array $data The data to validate.
     * @param string $group The name of the field group to validate.
     *
     * @return  array|boolean  Array of filtered data if valid, false otherwise.
     *
     * @see     JFormRule
     * @see     JFilterInput
     * @since   3.7.0
     */
    public function validate($form, $data, $group = null)
    {
        // Don't allow to change the users if not allowed to access com_users.
        if (JFactory::getApplication()->isClient('administrator') && !JFactory::getUser()->authorise('core.manage', 'com_users')) {
            if (isset($data['created_by'])) {
                unset($data['created_by']);
            }

            if (isset($data['modified_by'])) {
                unset($data['modified_by']);
            }
        }

        return parent::validate($form, $data, $group);
    }

    /**
     * Method to save the form data.
     *
     * @param array $data The form data.
     *
     * @return  boolean  True on success.
     *
     * @since   1.6
     */
    public function save($data)
    {

        $type = $data['to_selector'];

        $data['recever_name'] = JFactory::getUser($this->getUserid($type))->name;
        $data['recever_id'] = $this->getUserid($type);

        if (!$data['id'] || empty($data['created'])) {
            $data['date_time'] = JFactory::getDate()->toSql();
            $data['sender_id'] = JFactory::getUser()->id;
        }

        unset($data['to_selector'],$data['student_name'],$data['teacher_name']);

        //
        if (parent::save($data)) {

            $id = $this->getState($this->getName() . '.id', 'id');

            // upload attachment if message successfully sent and save
            JoomschoolHelperAttachment::save($id,'m'); // 'm' means message , 'mreply' means message reply

            JFactory::getApplication()->redirect(JRoute::_('index.php?option=com_joomschool&view=message&layout=details&id=' . $id, false));
            return true;
        }

        return false;
    }



    public function getUserid($value){

        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select("user_id");
        $query->from($db->quoteName("#__joomschool_{$value}s"));
        $query->order('id ASC');

        $db->setQuery($query);

        return $db->loadResult();
    }
//Message list
    public function getMessageList($message_id){
        // Get a db connection.
        $db = JFactory::getDbo();

        $query = $db->getQuery(true);

        $query->select("*");
        $query->from($db->quoteName('#__joomschool_message_reply'));
        $query->where("message_id = $message_id");
        $query->order('id ASC');

        $db->setQuery($query);

        $results = $db->loadObjectList();

        return $results;
    }
    public function avator($id){
        $db = JFactory::getDBO();
        //Get group id
        $query_group = $db->getQuery(true);
        $query_group
            ->select(array('group_id'))
            ->from($db->quoteName('#__user_usergroup_map'))
            ->where($db->quoteName('user_id') . ' = '. $db->quote($id));

        $db->setQuery($query_group);
        $group = $db->loadResult();

        //Get group name
        $query_group_name = $db->getQuery(true);
        $query_group_name
            ->select(array('title'))
            ->from($db->quoteName('#__usergroups'))
            ->where($db->quoteName('id') . ' = '. $db->quote($group));

        $db->setQuery($query_group_name);
        $group_name = $db->loadResult();

        if($group_name=='Students'){
            $query_student = $db->getQuery(true);
            $query_student
                ->select(array('photo'))
                ->from($db->quoteName('#__joomschool_students'))
                ->where($db->quoteName('user_id') . ' = '. $db->quote($id));
            $db->setQuery($query_student);
            $student_photo = $db->loadResult();
            $path = JUri::root(false).'administrator/components/com_joomschool/photo/students/'.$student_photo;
        }else if($group_name=='Teachers'){
            $query_teacher = $db->getQuery(true);
            $query_teacher
                ->select(array('photo'))
                ->from($db->quoteName('#__joomschool_teachers'))
                ->where($db->quoteName('user_id') . ' = '. $db->quote($id));
            $db->setQuery($query_teacher);
            $teacher_photo = $db->loadResult();
            $path = JUri::root(false).'administrator/components/com_joomschool/photo/teachers/'.$teacher_photo;
        }else if($group_name=='Parents'){
            $query_parent = $db->getQuery(true);
            $query_parent
                ->select(array('photo'))
                ->from($db->quoteName('#__joomschool_parents'))
                ->where($db->quoteName('user_id') . ' = '. $db->quote($id));
            $db->setQuery($query_parent);
            $parent_photo = $db->loadResult();
            $path =JUri::root(false).'administrator/components/com_joomschool/photo/parents/'.$parent_photo;
        }else{
            $path = JUri::root(false).'administrator/components/com_joomschool/photo/photo.png';
        }

        return $path;
    }


   public function messagereply($message){

       $reply = new stdClass();
       $reply->message_id = $message['message_id'];
       $reply->sender_id=   $message['sender_id'];
       $reply->recever_id=  $message['recever_id'];
       $reply->message=     $message['message'];
       $reply->status=1;
       $reply->date_time= JFactory::getDate()->toSql();

// Insert the object into the user reply table.
       $result = JFactory::getDbo()->insertObject('#__joomschool_message_reply', $reply);

       return JFactory::getDbo()->insertid();
    }


}
