<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;

use Joomla\Registry\Registry;

class JoomschoolModelParent extends JModelAdmin
{


    /**
     * Prepare and sanitise the table data prior to saving.
     *
     * @param JTable $table A JTable object.
     *
     * @return  void
     *
     * @since   1.6
     */
    protected function prepareTable($table)
    {
        // Set the publish date to now
        if ($table->state == 1 && (int)$table->publish_up == 0) {
            $table->publish_up = JFactory::getDate()->toSql();
        }

        if ($table->state == 1 && intval($table->publish_down) == 0) {
            $table->publish_down = $this->getDbo()->getNullDate();
        }

    }

    /**
     * Returns a Table object, always creating it.
     *
     * @param string $type The table type to instantiate
     * @param string $prefix A prefix for the table class name. Optional.
     * @param array $config Configuration array for model. Optional.
     *
     * @return  JTable    A database object
     */
    public function getTable($type = 'Parents', $prefix = 'Table', $config = array())
    {

        return JTable::getInstance($type, $prefix, $config);
    }

    /**
     * Method to get a single record.
     *
     * @param integer $pk The id of the primary key.
     *
     * @return  mixed  Object on success, false on failure.
     */
    public function getItem($pk = null)
    {
        $item = parent::getItem($pk);
        $item->student_id = explode(',',$item->student_id);
        $item->photo =  !empty($item->photo) ?  JUri::root(false).'administrator/components/com_joomschool/photo/parents/'.$item->photo : JUri::root(false).'administrator/components/com_joomschool/photo/photo.png';
        $parent_id = JFactory::getApplication()->input->getInt('id', 0);

        if ($parent_id > 0) {
            $item->name = JFactory::getUser(JoomSchoolHelper::getProfileInfoByID($parent_id,'parents')->user_id)->name;

            $sid = JoomschoolHelper::getFieldSectionID('parent');
            $fields = JoomschoolHelper::getFieldList($sid);
            $f = 0;
            foreach ($fields as $field) {
                $f++;
                $fid = $field->id;
                $sid = $sid;
                $field_input_name = 'field_' . $fid;
                $student_id = $item->id;
                $item->$field_input_name = $this->getFiledData($fid, $sid, $student_id);

            }
        }
        return $item;
    }

    /**
     * Method to get the record form.
     *
     * @param array $data Data for the form.
     * @param boolean $loadData True if the form is to load its own data (default case), false if not.
     *
     * @return  JForm|boolean  A JForm object on success, false on failure
     *
     * @since   1.6
     */
    public function getForm($data = array(), $loadData = true)
    {

        $app = JFactory::getApplication();
        $user = JFactory::getUser();

        // Get the form.
        $form = $this->loadForm('com_joomschool.parent', 'parent', array('control' => 'jform', 'load_data' => $loadData));


        if (empty($form)) {
            return false;
        }

        $jinput = JFactory::getApplication()->input;

        /*
         * The front end calls this model and uses a_id to avoid id clashes so we need to check for that first.
         * The back end uses id so we use that the rest of the time and set it to 0 by default.
         */
        $id = $jinput->get('a_id', $jinput->get('id', 0));

        // Determine correct permissions to check.

        // Check for existing article.
        // Modify the form based on Edit State access controls.
        if ($id != 0 && (!$user->authorise('core.edit.state', 'com_joomschool.parent.' . (int)$id))
            || ($id == 0 && !$user->authorise('core.edit.state', 'com_joomschool'))) {
            // Disable fields for display.
            $form->setFieldAttribute('ordering', 'disabled', 'true');
            $form->setFieldAttribute('state', 'disabled', 'true');

            // Disable fields while saving.
            // The controller has already verified this is an article you can edit.
            $form->setFieldAttribute('ordering', 'filter', 'unset');
            $form->setFieldAttribute('state', 'filter', 'unset');
        }

        // if student already exist, remove some fields, and force display some fields that use showon attr
        if($id > 0){
            $form->removeField('create_user');
            //$form->removeField('user_id');
            $form->removeField('password');
            $form->setFieldAttribute('email','showon','');
        }


        return $form;
    }

    /**
     * Method to get the data that should be injected in the form.
     *
     * @return  mixed  The data for the form.
     *
     * @since   1.6
     */
    protected function loadFormData()
    {
        // Check the session for previously entered form data.
        $app = JFactory::getApplication();
        $input = $app->input;
        $data = $app->getUserState('com_joomschool.edit.parent.data', array());
        
        if (empty($data)) {

            $student_id = $input->getInt('id', 0);
            $data = $this->getItem();

            if ($data->user_id > 0) {
                $user = JFactory::getUser($data->user_id);
                $data->username = $user->username;
                $data->email = $user->email;
                $data->name = $user->name;
                $data->password = $user->password;
            }

            // Pre-select some filters (Status, Category, Language, Access) in edit form if those have been selected in Article Manager: Articles
            if ($this->getState('parent.id') == 0) {
                $filters = (array)$app->getUserState('com_joomschool.parents.filter');
                $data->set(
                    'state',
                    $app->input->getInt(
                        'state',
                        ((isset($filters['published']) && $filters['published'] !== '') ? $filters['published'] : null)
                    )
                );

                $data->set('language', $app->input->getString('language', (!empty($filters['language']) ? $filters['language'] : null)));
                $data->set('access',
                    $app->input->getInt('access', (!empty($filters['access']) ? $filters['access'] : JFactory::getConfig()->get('access')))
                );
            }
        }

        // If there are params fieldsets in the form it will fail with a registry object
        if (isset($data->params) && $data->params instanceof Registry) {
            $data->params = $data->params->toArray();
        }

        $this->preprocessData('com_joomschool.parent', $data);

        return $data;
    }

    /**
     * Method to validate the form data.
     *
     * @param JForm $form The form to validate against.
     * @param array $data The data to validate.
     * @param string $group The name of the field group to validate.
     *
     * @return  array|boolean  Array of filtered data if valid, false otherwise.
     *
     * @see     JFormRule
     * @see     JFilterInput
     * @since   3.7.0
     */
    public function validate($form, $data, $group = null)
    {
        // Don't allow to change the users if not allowed to access com_users.
        if (JFactory::getApplication()->isClient('administrator') && !JFactory::getUser()->authorise('core.manage', 'com_users')) {
            if (isset($data['created_by'])) {
                unset($data['created_by']);
            }

            if (isset($data['modified_by'])) {
                unset($data['modified_by']);
            }
        }
        if($data['create_user']){
            unset($data['email']);
            unset($data['password']);
            $form->removeField('email');
            $form->removeField('password');
        }
        return parent::validate($form, $data, $group);
    }

    /**
     * Method to save the form data.
     *
     * @param array $data The form data.
     *
     * @return  boolean  True on success.
     *
     * @since   1.6
     */
    public function save($data)
    {
        JLoader::register('JoomschoolHelperUser', JPATH_COMPONENT_ADMINISTRATOR . '/helpers/user.php');
        $app = JFactory::getApplication();
        $post = JFactory::getApplication()->input->getArray();

        $data['name'] = $post['name'];

        unset($post['jform']);

        $data['student_id'] = implode(',',$data['student_id']);
        $filter = JFilterInput::getInstance();
        if (isset($data['created_by_alias'])) {
            $data['created_by_alias'] = $filter->clean($data['created_by_alias'], 'TRIM');
        }
        if (!$data['id'] || empty($data['created'])) {
            $data['created'] = JFactory::getDate()->toSql();
            $data['created_by'] = JFactory::getUser()->id;
        }
        if (!empty($data['created'])) {
            $data['modified'] = JFactory::getDate()->toSql();
            $data['modified_by'] = JFactory::getUser()->id;
        }

        // update user data, and register/update him in joomla users table
        if(!$this->updateWithJoomlaUsers($data))
            return false;

        // upload photo and add filename to data
        if(!$this->uploadPhoto($data))
            return false;


        // continue saving student data ...
        if (parent::save($data)) {
            //$this->saveStudentHistory($data);
            $this->saveCustomField($post);
            return true;
        }

        return false;
    }

    public function uploadPhoto(&$data){

        $files = JFactory::getApplication()->input->files->get('jform');


        if(empty($files['photo']['name'])) // means no file uploaded
            return true;

        $data =  array_merge($files,$data);
        $result = JoomschoolHelper::uploadFile($data['photo'],'parents');

        if(is_array($result) && $result['success'] == false)
        {
            $this->setError($result['message']);
            return false;
        }

        $data['photo'] = $result;

        return true;

    }

    /*
     * Parent save of joomla
     */
    public function parentSave($data){
        return parent::save($data);

    }

    public function updateWithJoomlaUsers(&$data){
        // update user data, and register/update him in joomla users table
        $result = JoomschoolHelperUser::processUser($data,'parent');

        if(!$result){

            $errors = JoomschoolHelperUser::$errors;

            if(count($errors) > 0){
                foreach ($errors as $error){
                    $this->setError('<br>'.$error);
                }
            }

            return false;

        }

        return true;

    }

    public function saveCustomField($data){
        $id = $data['id'] > 0 ? $data['id'] : $this->getState($this->getName() . '.id');
        $db= JFactory::getDbo();
        //Setting Custom Field Data
        $sid = JoomschoolHelper::getFieldSectionID('parent');
        $fields = JoomschoolHelper::getFieldList($sid);
        $total_field = count($fields);

        $f=0;
        foreach($fields as $field){
            $f++;
            $fid = $field->id;
            $sid = $sid;
            $field_input_name ='field_'.$fid;
            $field_data = $data[$field_input_name];
            $student_id = $id;
            $type = $field->type;

            $query_check_id = "SELECT id FROM `#__joomschool_fields_data` WHERE fid = '".$fid."' AND sid = '".$sid."' AND panel_id = '".$student_id."'";
            $db->setQuery($query_check_id);
            $old_id = $db->loadResult();
            JoomschoolHelper::saveFields($fid, $type, $sid, $field_data, $student_id,$old_id);
        }
    }

    protected function getUserId()
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select('id')
            ->from($db->quoteName('#__users'))
            ->order('id DESC');
        $db->setQuery($query);
        return $db->loadObject();
    }

    public function getFiledData($fid,$sid,$student_id){

        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select('data');
        $query->from($db->quoteName('#__joomschool_fields_data'));
        $query->where($db->quoteName('fid') . ' = ' .$fid);
        $query->where($db->quoteName('sid') . ' = ' .$sid);
        $query->where($db->quoteName('panel_id') . ' = ' .$student_id);

        $db->setQuery($query);

        return  $db->loadResult();
    }
    
    
    public function delete(&$pks)
    {

        return parent::delete($pks); // TODO: Change the autogenerated stub
    }
}
