<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;


class JoomschoolModelPayment extends JModelAdmin
{

    /**
     * Prepare and sanitise the table data prior to saving.
     *
     * @param JTable $table A JTable object.
     *
     * @return  void
     *
     * @since   1.6
     */
    protected function prepareTable($table)
    {
        // Set the publish date to now
        if ($table->state == 1 && (int)$table->publish_up == 0) {
            $table->publish_up = JFactory::getDate()->toSql();
        }

        if ($table->state == 1 && intval($table->publish_down) == 0) {
            $table->publish_down = $this->getDbo()->getNullDate();
        }

    }

    /**
     * Returns a Table object, always creating it.
     *
     * @param string $type The table type to instantiate
     * @param string $prefix A prefix for the table class name. Optional.
     * @param array $config Configuration array for model. Optional.
     *
     * @return  JTable    A database object
     */
    public function getTable($type = 'Payments', $prefix = 'Table', $config = array())
    {

       
        return JTable::getInstance($type, $prefix, $config);
    }

    /**
     * Method to get a single record.
     *
     * @param integer $pk The id of the primary key.
     *
     * @return  mixed  Object on success, false on failure.
     */
    public function getItem($pk = null)
    {
        $item = parent::getItem($pk);
       
        $item->pay_for_id = explode(',',$item->pay_for_id);
        $item->year = JoomschoolHelper::getYearId($item->year);

        return $item;
    }

    /**
     * Method to get the record form.
     *
     * @param array $data Data for the form.
     * @param boolean $loadData True if the form is to load its own data (default case), false if not.
     *
     * @return  JForm|boolean  A JForm object on success, false on failure
     *
     * @since   1.6
     */
    public function getForm($data = array(), $loadData = true)
    {

      
        $app = JFactory::getApplication();
        $user = JFactory::getUser();

        // Get the form.
        $form = $this->loadForm('com_joomschool.payment', 'payment', array('control' => 'jform', 'load_data' => $loadData));


        if (empty($form)) {
            return false;
        }

        $jinput = JFactory::getApplication()->input;

        /*
         * The front end calls this model and uses a_id to avoid id clashes so we need to check for that first.
         * The back end uses id so we use that the rest of the time and set it to 0 by default.
         */
        $id = $jinput->get('a_id', $jinput->get('id', 0));

        // Determine correct permissions to check.

        // Check for existing article.
        // Modify the form based on Edit State access controls.
        if ($id != 0 && (!$user->authorise('core.edit.state', 'com_joomschool.payment.' . (int)$id))
            || ($id == 0 && !$user->authorise('core.edit.state', 'com_joomschool'))) {
            // Disable fields for display.
            $form->setFieldAttribute('ordering', 'disabled', 'true');
            $form->setFieldAttribute('published', 'disabled', 'true');

            // Disable fields while saving.
            // The controller has already verified this is an article you can edit.
            $form->setFieldAttribute('ordering', 'filter', 'unset');
            $form->setFieldAttribute('published', 'filter', 'unset');
        }

        // Prevent messing with article language and category when editing existing article with associations


        return $form;
    }

    /**
     * Method to get the data that should be injected in the form.
     *
     * @return  mixed  The data for the form.
     *
     * @since   1.6
     */
    protected function loadFormData()
    {
        $context = JFactory::getApplication()->isClient('administrator') ? "payment" : "paymentedit";
        // Check the session for previously entered form data.
        $app = JFactory::getApplication();
        $input = $app->input;
        $data = $app->getUserState("com_joomschool.edit.$context.data", array());


        if (empty($data)) {


            $data = $this->getItem();


            // Pre-select some filters (Status, Category, Language, Access) in edit form if those have been selected in Article Manager: Articles
            if ($this->getState('a.section') == 0) {
                $filters = (array)$app->getUserState('com_joomschool.section.filter');
                $data->set(
                    'state',
                    $app->input->getInt(
                        'state',
                        ((isset($filters['published']) && $filters['published'] !== '') ? $filters['published'] : null)
                    )
                );

                $data->set('language', $app->input->getString('language', (!empty($filters['language']) ? $filters['language'] : null)));
                $data->set('access',
                    $app->input->getInt('access', (!empty($filters['access']) ? $filters['access'] : JFactory::getConfig()->get('access')))
                );
            }
        }

        // If there are params fieldsets in the form it will fail with a registry object
        if (isset($data->params) && $data->params instanceof Registry) {
            $data->params = $data->params->toArray();
        }

        $this->preprocessData("com_joomschool.$context", $data);

        return $data;
    }

    /**
     * Method to validate the form data.
     *
     * @param JForm $form The form to validate against.
     * @param array $data The data to validate.
     * @param string $group The name of the field group to validate.
     *
     * @return  array|boolean  Array of filtered data if valid, false otherwise.
     *
     * @see     JFormRule
     * @see     JFilterInput
     * @since   3.7.0
     */
    public function validate($form, $data, $group = null)
    {
        return parent::validate($form, $data, $group);
    }

    /**
     * Method to save the form data.
     *
     * @param array $data The form data.
     *
     * @return  boolean  True on success.
     *
     * @since   1.6
     */
    public function save($data)
    {

        if((float) $data['paid_ammount'] <= (float) $data['total_bill'])
            $data['due_ammount'] = (float) $data['total_bill'] - (float) $data['paid_ammount'];
        else
            $data['due_ammount'] = 0;

        $user = JFactory::getUser();
        $data['pay_for_id'] = implode(",", $data['pay_for_id']);
        $data['year'] = JoomschoolHelper::getYearById($data['year']);

        if(JFactory::getApplication()->isClient('site')){
            if(JoomschoolHelperFrontend::checkGroup($user->id) == 'Students'){
             $data['student_id'] = JoomschoolHelper::getStudentInfoByKey('user_id',$user->id)->id;
                $data['student_roll'] = JoomschoolHelper::getStudentInfoByKey('user_id',$user->id)->roll;
                $data['student_class'] = JoomschoolHelper::getStudentInfoByKey('user_id',$user->id)->class_id;
                $data['student_section'] = JoomschoolHelper::getStudentInfoByKey('user_id',$user->id)->section_id;

            }

            if(JoomschoolHelperFrontend::checkGroup($user->id) == 'Teachers'){
                $data['student_id'] = JoomschoolHelper::getStudentInfoByKey("roll",$data['student_roll'])->id;
                $data['student_class'] = JoomschoolHelper::getStudentInfoByKey("roll",$data['student_roll'])->class_id;
                $data['student_section'] = JoomschoolHelper::getStudentInfoByKey("roll",$data['student_roll'])->section_id;

            }
        }


        if(!$data['id']){
            $data['create_date'] = JFactory::getDate()->toSql();
         }
        
        // continue saving student data ...
        if (parent::save($data)) {

            return true;
        }

        return false;
    }

    /**
     ** Pay Ammount
     **/
    public function getPayammount($id,$field){
        $db = JFactory::getDBO();
        $query_result = $db->getQuery(true);
        $query_result
            ->select($db->quoteName(array($field)))
            ->from($db->quoteName('#__joomschool_pay_type'))
            ->where($db->quoteName('id') . ' = '. $db->quote($id));

        $db->setQuery($query_result);
        $data = $db->loadResult();
        return $data;
    }

    /**
     ** Get Student
     ***/
    function getStudent($id){
        $student = $this->getTable('students');
        $student->load($id);
        return $student;
    }

    /**
     ** Get Details of history
     **/
    function history($details,$student,$year){


        //Collect Student data
        $name = JFactory::getUser($student->user_id)->name;
        $userProfile = 'index.php?option=com_joomschool&view=student&layout=details';

        $classes = [];
        $sections = [];
        $subjects = [];

        $class = '<span>'.JoomschoolHelper::getClassNameByID($student->class_id)->class_name.'</span>';
        $section = '<span>'.JoomschoolHelper::getSectionname($student->section_id).'</span>';
        $division = '<span>'.JoomschoolHelper::getDivisionNameByID($student->division_id)->division_name.'</span>';


        if(!empty($student->roll)){ $roll = $student->roll; }else { $roll="";}

        // GET SCHOOLS DATA
        $app = JFactory::getApplication();
        $params = JComponentHelper::getParams('com_joomschool');
        $schools_name = $params->get('schools_name','Schools/Collage Name');
        $schools_address = $params->get('schools_address','12345 Vincent Place');
        $schools_phone = $params->get('schools_phone',123456789);
        $schools_email = $params->get('schools_email','support@joomboost.com');
        $schools_website = $params->get('schools_web','www.joomboost.com');

        $details_show = $schools_name;

        //Display Header Information
        $onclick_link ="'printableArea'";
        $header_con ='<p style="text-align: center;"><input type="button" id="print" onclick="printDiv('.$onclick_link.')" class="btn btn-small btn-sm btn-primary"  style="border: none;margin-left: 10px;" value="Print" /> </p>';
        $details_show  = '<h4 class="" style="text-align: center;margin-bottom: 3px;" >'.$schools_name.'</h4>';
        $details_show .='<p style="text-align: center;"><b>'.JText::_('LABEL_PAYMENT_HISTORY_TITLE').' - '.$year.'</b></p>';
        $details_show .= $header_con;

        //Display Student info
        $details_show .='<table  align="center"   class="" id="admin-table" style="margin-bottom: 0px;margin-top: 10px;width: 95%;border: none;" >';
        $details_show .='<tr>';
        $details_show .='<td align="left" style="border: 0px;"><b> '.JText::_('LABEL_STUDENT_NAME').': </b><span class="jb-template"><a href="'.$userProfile.'"><i class="fas fa-link"></i> '.$name.'</a></span></td>';
        $details_show .='<td align="left" style="border: 0px;"><b> '.JText::_('LABEL_STUDENT_ROLL').':</b> '.$roll.'</td>';
        $details_show .='<td align="center" style="border: 0px;"><b> '.JText::_('LABEL_STUDENT_CLASS').': </b>'.$class.'</td>';
        $details_show .='<td align="right" style="border: 0px;"><b> '.JText::_('LABEL_STUDENT_SECTION').':</b> '.$section.'</td>';
        $details_show .='<td align="right" style="border: 0px;" ><b>'.JText::_('LABEL_STUDENT_DIVISION').':</b> '.$division.'</td>';
        $details_show .='</tr>';
        $details_show .='</table>';

        $details_show .= '<table class="admin-table" align="center"  id="admin-table" style="width: 95%;margin-top: 10px;" align="center">';
        $details_show .= '<tr>';
        $details_show .='<th>#</th>';
        $details_show .='<th>'.JText::_('LABEL_PAYMENT_HISTORY_MONTH').'</th>';
        $details_show .='<th>'.JText::_('LABEL_PAYMENT_HISTORY_PAYMENT_TYPE').'</th>';
        $details_show .='<th>'.JText::_('LABEL_PAYMENT_HISTORY_TOTAL_PAYMENT').'</th>';
        $details_show .='<th>'.JText::_('LABEL_PAYMENT_HISTORY_PAID_AMMOUNT').'</th>';
        $details_show .='<th>'.JText::_('LABEL_PAYMENT_HISTORY_DUE_AMMOUNT').'</th>';
        $details_show .='<th>'.JText::_('LABEL_PAYMENT_HISTORY_PAID_BY').'</th>';
        $details_show .='<th>'.JText::_('LABEL_PAYMENT_STATUS').'</th>';
        $details_show .='<th>'.JText::_('LABEL_PAYMENT_HISTORY_SUBMIT_DATE').'</th>';
        $details_show .='<th>#</th>';
        $details_show .='</tr>';
        //$details_show .='</table>';
        $i=0;
        if(!empty($details)){
            //$details_show .= '<table class="admin-table" align="center"  id="admin-table" style="width: 95%;margin-top: 0px;" align="center">';
            foreach ($details as $item){
                $i++;
                $monthName = date("F", mktime(null, null, null, $item->month));
                $year = $item->year;
                $payment_type = $this->getPayammount($item->pay_for_id,'name');

                $paidby = $this->getPaidBy($item->payment_method);
                $link_invoice 		= JRoute::_( 'index.php?option=com_joomschool&view=payment&layout=invoice&pdf=1&id='. $item->id );
                $status = $item->status;
                if($status=="0"){$st = '<span style="color: orange;font-weight: bold;" >'.JText::_('COM_JOOMSCHOOL_LABEL_STATUS_PENDING').'</span>';}
                if($status=="1"){$st = '<span style="color: green;font-weight: bold;" >'.JText::_('COM_JOOMSCHOOL_LABEL_STATUS_PAID').'</span>';}
                if($status=="2"){$st = '<span style="color: red;font-weight: bold;" >'.JText::_('COM_JOOMSCHOOL_LABEL_STATUS_UN_PAID').'</span>';}
                if($status=="3"){$st = '<span style="color: magenta;font-weight: bold;" >'.JText::_('COM_JOOMSCHOOL_LABEL_STATUS_CANCEL').'</span>';}
                if($status=="4"){$st = '<span style="color: mediumblue;font-weight: bold;" >'.JText::_('COM_JOOMSCHOOL_LABEL_STATUS_UNDER_REVIEW').'</span>';}

                $submit_date = date( 'Y-m-d g:i A', strtotime($item->create_date));

                $item->due_ammount = empty($item->due_ammount) ? 0 : $item->due_ammount;

                $details_show .='<tr>';
                $details_show .='<td align="center">'.$i.'</td>';
                $details_show .='<td style="text-align: left;" >'.$monthName.' - '.$year.'</td>';
                $details_show .='<td style="text-align: left;" >'.$payment_type.'</td>';
                $details_show .='<td align="right">'.number_format($item->total_bill, 2).'</td>';
                $details_show .='<td align="right">'.number_format($item->paid_ammount, 2).'</td>';
                $details_show .='<td align="right">'.number_format($item->due_ammount, 2).'</td>';
                $details_show .='<td align="center">'.$paidby.'</td>';
                $details_show .='<td align="center">'.$st.'</td>';
                $details_show .='<td align="center">'.$submit_date.'</td>';
                $details_show .='<td align="center"><a href="'.$link_invoice.'" class="btn">'.JText::_('BTN_PAYMENT_VIEW_INVOICE').'</a></td>';
                $details_show .='</tr>';
            }
        }
        $details_show .='</table>';
        if(empty($details)){
            $details_show .="<p style='color: red;text-align: center;padding: 10px;'>No record found. </p>";
        }

        return  $details_show;
    }

    /**
     ** Payment Details
     ***/
    function getPaymentDetails($id,$year)
    {


        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select('*')
            ->from($db->quoteName('#__joomschool_payments'))
            ->where($db->quoteName('student_id') . ' = '. $db->quote($id))
            ->where(' year = '. $db->quote($year))
            ->order('month ASC');

        $db->setQuery($query);
        $rows = $db->loadObjectList();

        return  $rows;
    }

    /**
     ** Paid By
     **/
    function getPaidBy($id){
        $db = JFactory::getDBO();
        $query_result = $db->getQuery(true);
        $query_result
            ->select($db->quoteName(array('name')))
            ->from($db->quoteName('#__joomschool_pay_method'))
            ->where($db->quoteName('id') . ' = '. $db->quote($id));

        $db->setQuery($query_result);
        $data = $db->loadResult();
        return $data;
    }

}
