<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;


class JoomschoolModelPayments extends JModelList
{


    function __construct()
    {
        parent::__construct();

        $mainframe = JFactory::getApplication();

        // Get pagination request variables
        $limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
        $limitstart = JRequest::getVar('limitstart', 0, '', 'int');

        // In case limit has been changed, adjust it
        $limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);

        $this->setState('limit', $limit);
        $this->setState('limitstart', $limitstart);
    }


    function getuserID($roll, $student_class, $student_section)
    {
        $db = JFactory::getDBO();

        $query_result = $db->getQuery(true);
        $query_result
            ->select($db->quoteName(array('id')))
            ->from($db->quoteName('#__joomschool_students'))
            ->where($db->quoteName('class_id') . ' = ' . $student_class)
            ->where($db->quoteName('section_id') . ' = ' . $student_section)
            ->where($db->quoteName('roll') . ' = ' . $db->quote($roll));

        $db->setQuery($query_result);
        $data = $db->loadResult();
        return $data;
    }


    function getStudentname($roll)
    {
        $db = JFactory::getDBO();
        //$query_result = "SELECT name FROM `#__joomschool_students` WHERE roll = '".$roll."'";

        $query_result = $db->getQuery(true);
        $query_result
            ->select($db->quoteName(array('user_id')))
            ->from($db->quoteName('#__joomschool_students'))
            ->where($db->quoteName('roll') . ' = ' . $db->quote($roll));

        $db->setQuery($query_result);
        $data = $db->loadResult();
        return $data;
    }


    /**
     ** Pay Ammount
     **/
    function getPayammount($id, $field)
    {
        $db = JFactory::getDBO();
        $query_result = $db->getQuery(true);
        $query_result
            ->select($db->quoteName(array($field)))
            ->from($db->quoteName('#__joomschool_pay_type'))
            ->where($db->quoteName('id') . ' = ' . $db->quote($id));

        $db->setQuery($query_result);
        $data = $db->loadResult();
        return $data;
    }

    /**
     ** Total Pending
     **/
    function totalPending()
    {
        $db = JFactory::getDBO();

        $query = $db->getQuery(true);
        $query
            ->select('*')
            ->from($db->quoteName('#__joomschool_payments'))
            ->where($db->quoteName('status') . ' = ' . $db->quote('0'));

        $db->setQuery($query);
        $rows = count($db->loadObjectList());
        return $rows;
    }


    /**
     ** Get Bill
     ***/
    function getBill($bill_arry)
    {
        $db = JFactory::getDBO();

        $total_fee = 0;
        if ($bill_arry) {
            foreach ($bill_arry as $bills) {
                $bill_id = $bills;
                $query_result = $db->getQuery(true);
                $query_result
                    ->select($db->quoteName(array('fee')))
                    ->from($db->quoteName('#__joomschool_pay_type'))
                    ->where($db->quoteName('id') . ' = ' . $db->quote($bill_id));
                $db->setQuery($query_result);
                $fee = $db->loadResult();
                $total_fee += $fee;
            }
        }

        return $total_fee;
    }


    /*
    ** Get Payments
    **/
    function getPayments($id)
    {
        if ($id) {
            $this->_id = $id;
        }
        if (empty($this->_data)) {
            $this->_data = $this->getTable('payments');
            $this->_data->load($this->_id);
        }
        return $this->_data;
    }

    /**
     ** Payment List
     ***/
    protected function getListQuery()
    {
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select(
            $this->getState(
                'list.select',
                'DISTINCT a.id,a.student_id,a.student_roll, u.name,c.class_name,s.section_name,a.month, a.year, p.name as payment_method,a.pay_for_id,a.total_bill,a.paid_ammount,a.due_ammount,a.status,a.create_date'
            )
        );
        $query->from('#__joomschool_payments AS a');
        $query->join('LEFT', '#__joomschool_students AS st ON st.id = a.student_id');

        $query->join('LEFT', '#__users AS u ON u.id = st.user_id');
        $query->join('LEFT', '#__joomschool_sections AS s ON s.id = a.student_section');
        $query->join('LEFT', '#__joomschool_class AS c ON c.id = a.student_class');

        $query->join('LEFT', '#__joomschool_pay_method AS p ON p.id = a.payment_method');


        $orderCol = $this->state->get('list.ordering', 'id');
        $orderDirn = $this->state->get('list.direction', 'desc');

        // Filter by Status.
        $status = $this->getState('list.status');
        if (is_numeric($status)) {
            $query->where('a.status = ' . $db->quote($status));
        }

        // Filter by Class.
        $classId = $this->getState('filter.class_id');
        if (is_numeric($classId)) {
            $query->where('a.student_class = ' . $db->quote($classId));
        }

        // Filter by Section.
        $sectionId = $this->getState('filter.section_id');
        if (is_numeric($sectionId)) {
            $query->where('a.student_section = ' . $db->quote($sectionId));
        }

        // Filter by Month.
        $monthId = $this->getState('filter.month_id');
        if (is_numeric($monthId)) {
            $query->where('a.month = ' . $db->quote($monthId));
        }


        // Filter by search in title.
        $search = $this->getState('filter.search');

        if (!empty($search)) {
            if (stripos($search, 'a.id:') === 0) {
                $query->where('a.id = ' . (int)substr($search, 3));
            } else {
                $search = $db->quote('%' . str_replace(' ', '%', $db->escape(trim($search), true) . '%'));
                $query->where('(a.month LIKE ' . $search . ' OR a.student_roll LIKE ' . $search . ')');
            }
        }


        $query->order($db->escape($orderCol) . ' ' . $db->escape($orderDirn));

        return $query;
    }

    protected function populateState($ordering = null, $direction = null)
    {
        // Initialise variables.
        $app = JFactory::getApplication('administrator');

        $search = $this->getUserStateFromRequest($this->context . '.filter.search', 'filter_search');
        $this->setState('filter.search', $search);

        //Takes care of states: list. limit / start / ordering / direction
        parent::populateState('id', 'asc');
    }

    /**
     ** Class List
     **/
    function getclassList($id)
    {
        $db = JFactory::getDBO();

        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('id', 'class_name')))
            ->from($db->quoteName('#__joomschool_class'))
            ->where($db->quoteName('published') . ' = ' . $db->quote('1'))
            ->order('id ASC');

        $db->setQuery($query);
        $rows = $db->loadObjectList();
        if ($db->getErrorNum()) {
            echo $db->stderr();
            return false;
        }
        $class_array = array();

        $onclick_manage_subject = "javascript: formget(this.form, 'index.php?option=com_joomschool&controller=payments&task=getsectionlist&format=raw');";

        $class_array[] = array('value' => '', 'text' => JText::_(' -- Select Class -- '));
        foreach ($rows as $row) {
            $class_array[] = array('value' => $row->id, 'text' => JText::_(' ' . $row->class_name));
        }
        $class = JHTML::_('select.genericList', $class_array, 'student_class', ' class="required  inputbox  "  required="required"   ', 'value', 'text', $id);
        return $class;
    }

    /**
     ** Section List
     **/

    function sectionList($class_id)
    {
        $db = JFactory::getDBO();

        $query_result = $db->getQuery(true);
        $query_result
            ->select($db->quoteName(array('section_id')))
            ->from($db->quoteName('#__joomschool_class'))
            ->where($db->quoteName('id') . ' = ' . $db->quote($class_id));
        $db->setQuery($query_result);
        $data = $db->loadResult();
        $section_value = explode(",", $data);
        return $section_value;
    }

    function getsectionList($id)
    {
        $db = JFactory::getDBO();

        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('id', 'section_name')))
            ->from($db->quoteName('#__joomschool_sections'))
            ->where($db->quoteName('published') . ' = ' . $db->quote('1'))
            ->order('id ASC');
        $db->setQuery($query);
        $rows = $db->loadObjectList();
        if ($db->getErrorNum()) {
            echo $db->stderr();
            return false;
        }
        $sections = array();


        $sections[] = array('value' => '', 'text' => JText::_(' -- Select Section -- '));
        foreach ($rows as $row) {
            $sections[] = array('value' => $row->id, 'text' => JText::_(' ' . $row->section_name));
        }
        $section = JHTML::_('select.genericList', $sections, 'student_section', 'class=" required inputbox  " required="required" ', 'value', 'text', $id);
        return $section;
    }


    /**
     ** Payment Method List
     **/
    function getPaymentMethodList($id)
    {
        $db = JFactory::getDBO();

        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('id', 'name')))
            ->from($db->quoteName('#__joomschool_pay_method'))
            ->where($db->quoteName('published') . ' = ' . $db->quote('1'))
            ->order('id ASC');
        $db->setQuery($query);
        $rows = $db->loadObjectList();
        if ($db->getErrorNum()) {
            echo $db->stderr();
            return false;
        }
        $class_array = array();

        $onclick_manage_subject = "javascript: formget(this.form, 'index.php?option=com_joomschool&controller=marks&task=getsubjectlist&format=raw');";

        $class_array[] = array('value' => '', 'text' => JText::_(' -- Select Pay method -- '));
        foreach ($rows as $row) {
            $class_array[] = array('value' => $row->id, 'text' => JText::_(' ' . $row->name));
        }
        $class = JHTML::_('select.genericList', $class_array, 'payment_method_id', ' class="required  inputbox  " required="required"   ', 'value', 'text', $id);
        return $class;
    }


    /**
     ** Pay For  List
     **/
    function getPayForList($id)
    {
        $db = JFactory::getDBO();
        $app = JFactory::getApplication();
        $params = JComponentHelper::getParams('com_joomschool');
        $currency = $params->get('currency', '$');

        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('id', 'name', 'fee')))
            ->from($db->quoteName('#__joomschool_pay_type'))
            ->order('id ASC');
        $db->setQuery($query);
        $rows = $db->loadObjectList();
        if ($db->getErrorNum()) {
            echo $db->stderr();
            return false;
        }
        $class_array = array();

        if ($id) {
            $query_result = $db->getQuery(true);
            $query_result
                ->select($db->quoteName(array('pay_for_id')))
                ->from($db->quoteName('#__joomschool_payments'))
                ->where($db->quoteName('id') . ' = ' . $db->quote($id));
            $db->setQuery($query_result);
            $select_data = $db->loadResult();

            $select_value = explode(",", $select_data);
        } else {
            $select_value = "";
        }

        //$onclick_manage_subject = "javascript: formget(this.form, 'index.php?option=com_joomschool&controller=marks&task=getsubjectlist&format=raw');";

        //$class_array[] = array('value' => '', 'text' => JText::_(' -- Select Pay Type -- '));
        foreach ($rows as $row) {
            $class_array[] = array('value' => $row->id, 'text' => JText::_(' ' . $row->name . ' (' . $currency . ':' . $row->fee . ')'));
        }
        $class = JHTML::_('select.genericList', $class_array, 'pay_for_id[]', 'multiple="multiple" class="payment_type required  inputbox  " required="required"   ', 'value', 'text', $select_value);
        return $class;
    }


}
