<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;

use Joomla\Registry\Registry;

class JoomschoolModelStudent extends JModelAdmin
{

    public function populateState()
    {
        $app = JFactory::getApplication();

        $this->setState('exam.filter', $app->getUserStateFromRequest('com_joomschool.student.filter', 'filter.exam', '', 'INT'));


        parent::populateState(); // TODO: Change the autogenerated stub
    }


    /**
     * Prepare and sanitise the table data prior to saving.
     *
     * @param JTable $table A JTable object.
     *
     * @return  void
     *
     * @since   1.6
     */
    protected function prepareTable($table)
    {
        // Set the publish date to now
        if ($table->state == 1 && (int)$table->publish_up == 0) {
            $table->publish_up = JFactory::getDate()->toSql();
        }

        if ($table->state == 1 && intval($table->publish_down) == 0) {
            $table->publish_down = $this->getDbo()->getNullDate();
        }
    }


    /**
     * Returns a Table object, always creating it.
     *
     * @param string $type The table type to instantiate
     * @param string $prefix A prefix for the table class name. Optional.
     * @param array $config Configuration array for model. Optional.
     *
     * @return  JTable    A database object
     */
    public function getTable($type = 'Students', $prefix = 'Table', $config = array())
    {

        return JTable::getInstance($type, $prefix, $config);
    }

    /**
     * Method to get a single record.
     *
     * @param integer $pk The id of the primary key.
     *
     * @return  mixed  Object on success, false on failure.
     */
    public function getItem($pk = null)
    {
        $db = JFactory::getDbo();
        $student_id = JFactory::getApplication()->input->getInt('id', 0);

        $item = parent::getItem($pk);
        $item->photo = !empty($item->photo) ? JUri::root(false) . 'administrator/components/com_joomschool/photo/students/' . $item->photo : JUri::root(false) . 'administrator/components/com_joomschool/photo/photo.png';
        if ($student_id > 0) {
            $item->name = JFactory::getUser(JoomSchoolHelper::getStudentNameByID($student_id)->user_id)->name;

            $sid = JoomschoolHelper::getFieldSectionID('student');
            $fields = JoomschoolHelper::getFieldList($sid);
            $f = 0;
            foreach ($fields as $field) {
                $f++;
                $fid = $field->id;
                $sid = $sid;
                $field_input_name = 'field_' . $fid;
                $student_id = $item->id;
                $item->$field_input_name = $this->getFiledData($fid, $sid, $student_id);


            }
        }

        // get student subjects
        if($item->class_id > 0){
            $item->subjects = $this->getStudentClassSubjects($item->class_id);
            $item->class_name = JoomschoolHelper::getClassname($item->class_id);
        }


        return $item;

    }

    public function getStudentClassSubjects($classId){

        // inits
        $db = JFactory::getDBO();
        $subjects = [];

        // get subjects

        $query = $db->getQuery(true);
        $query
            ->select('subject_id')
            ->from($db->quoteName('#__joomschool_class'))
            ->where($db->quoteName('id') . ' = ' . (int) $classId);

        $db->setQuery($query);
        $result = $db->loadResult();

        if(is_null($result))
            return $subjects;

        // if subjects found explode to array

        $subjectsList = explode(',',$result);

        // get subjects name and ids
        foreach ($subjectsList as $subject){

            $query = $db->getQuery(true);
            $query
                ->select('*')
                ->from($db->quoteName('#__joomschool_subjects'))
                ->where($db->quoteName('id') . ' = ' . (int) $subject)
                ->where("published = 1");

            $db->setQuery($query);
            $result = $db->loadObject();

            if(is_null($result))
                continue;

            $subjects[] = $result;



        }

        return $subjects;


    }


    /**
     * Method to get the record form.
     *
     * @param array $data Data for the form.
     * @param boolean $loadData True if the form is to load its own data (default case), false if not.
     *
     * @return  JForm|boolean  A JForm object on success, false on failure
     *
     * @since   1.6
     */
    public function getForm($data = array(), $loadData = true)
    {

        $app = JFactory::getApplication();
        $user = JFactory::getUser();

        // Get the form.
        $form = $this->loadForm('com_joomschool.student', 'student', array('control' => 'jform', 'load_data' => $loadData));


        if (empty($form)) {
            return false;
        }

        $jinput = JFactory::getApplication()->input;

        /*
         * The front end calls this model and uses a_id to avoid id clashes so we need to check for that first.
         * The back end uses id so we use that the rest of the time and set it to 0 by default.
         */
        $id = $jinput->get('a_id', $jinput->get('id', 0));

        // Determine correct permissions to check.

        // Check for existing article.
        // Modify the form based on Edit State access controls.
        if ($id != 0 && (!$user->authorise('core.edit.state', 'com_joomschool.student.' . (int)$id))
            || ($id == 0 && !$user->authorise('core.edit.state', 'com_joomschool'))) {
            // Disable fields for display.
            $form->setFieldAttribute('ordering', 'disabled', 'true');
            $form->setFieldAttribute('state', 'disabled', 'true');

            // Disable fields while saving.
            // The controller has already verified this is an article you can edit.
            $form->setFieldAttribute('ordering', 'filter', 'unset');
            $form->setFieldAttribute('state', 'filter', 'unset');
        }

        // if student already exist, remove some fields, and force display some fields that use showon attr
        if ($id > 0) {
            $form->removeField('create_user');
            //$form->removeField('user_id');
            $form->removeField('password');
            $form->setFieldAttribute('email', 'showon', '');
        }


        return $form;
    }

    /**
     * Method to get the data that should be injected in the form.
     *
     * @return  mixed  The data for the form.
     *
     * @since   1.6
     */
    protected function loadFormData()
    {
        // Check the session for previously entered form data.
        $app = JFactory::getApplication();
        $input = $app->input;
        $data = $app->getUserState('com_joomschool.edit.student.data', array());


        if (empty($data)) {

            $student_id = $input->getInt('id', 0);
            $data = $this->getItem();


            if ($data->user_id > 0) {

                if ($input->getString('layout', '') == 'result') {
                    $exam_id = $this->getState('filter.exam') ? $this->getState('filter.exam') : $this->getExamId($student_id);
                }


                $user = JFactory::getUser($data->user_id);
                $data->username = $user->username;
                $data->email = $user->email;
                $data->name = $user->name;
                $data->password = $user->password;
                if ($input->getString('layout', '') == 'result') {
                    $data->comment = $this->getComment($data->class_id, $data->roll, $exam_id);
                }


            }

            // Pre-select some filters (Status, Category, Language, Access) in edit form if those have been selected in Article Manager: Articles
            if ($this->getState('student.id') == 0) {
                $filters = (array)$app->getUserState('com_joomschool.students.filter');
                $data->set(
                    'state',
                    $app->input->getInt(
                        'state',
                        ((isset($filters['published']) && $filters['published'] !== '') ? $filters['published'] : null)
                    )
                );

                $data->set('language', $app->input->getString('language', (!empty($filters['language']) ? $filters['language'] : null)));
                $data->set('access',
                    $app->input->getInt('access', (!empty($filters['access']) ? $filters['access'] : JFactory::getConfig()->get('access')))
                );
            }
        }

        // If there are params fieldsets in the form it will fail with a registry object
        if (isset($data->params) && $data->params instanceof Registry) {
            $data->params = $data->params->toArray();
        }

        $this->preprocessData('com_joomschool.student', $data);

        return $data;
    }

    /**
     * Method to validate the form data.
     *
     * @param JForm $form The form to validate against.
     * @param array $data The data to validate.
     * @param string $group The name of the field group to validate.
     *
     * @return  array|boolean  Array of filtered data if valid, false otherwise.
     *
     * @see     JFormRule
     * @see     JFilterInput
     * @since   3.7.0
     */
    public function validate($form, $data, $group = null)
    {
        // Don't allow to change the users if not allowed to access com_users.
        if (JFactory::getApplication()->isClient('administrator') && !JFactory::getUser()->authorise('core.manage', 'com_users')) {
            if (isset($data['created_by'])) {
                unset($data['created_by']);
            }

            if (isset($data['modified_by'])) {
                unset($data['modified_by']);
            }
        }
        if (isset($data['create_user']) && $data['create_user']) {
            unset($data['email']);
            unset($data['password']);
            $form->removeField('email');
            $form->removeField('password');
        }


        return parent::validate($form, $data, $group);
    }

    /*
     * Parent save of joomla
     */
    public function parentSave($data)
    {
        return parent::save($data);

    }

    /**
     * Method to save the form data.
     *
     * @param array $data The form data.
     *
     * @return  boolean  True on success.
     *
     * @since   1.6
     */
    public function save($data)
    {

        JLoader::register('JoomschoolHelperUser', JPATH_COMPONENT_ADMINISTRATOR . '/helpers/user.php');

        $post = JFactory::getApplication()->input->getArray();

        $data['name'] = $post['name'];

        unset($post['jform']);

        $app = JFactory::getApplication();
        if ($app->isClient('site')) {
            $data['id'] = $app->input->getInt('id');
        }
        $filter = JFilterInput::getInstance();
        if (isset($data['created_by_alias'])) {
            $data['created_by_alias'] = $filter->clean($data['created_by_alias'], 'TRIM');
        }
        if (!$data['id'] || empty($data['created'])) {
            $data['created'] = JFactory::getDate()->toSql();
            $data['created_by'] = JFactory::getUser()->id;
        }
        if (!empty($data['created'])) {
            $data['modified'] = JFactory::getDate()->toSql();
            $data['modified_by'] = JFactory::getUser()->id;
        }

        // update user data, and register/update him in joomla users table
        if (!$this->updateWithJoomlaUsers($data))
            return false;

        // upload photo and add filename to data
        if (!$this->uploadPhoto($data))
            return false;

        // continue saving student data ...
        if (parent::save($data)) {

            $this->saveStudentHistory($data);
            $this->saveCustomField($post);
            return true;
        }

        return false;
    }

    public function uploadPhoto(&$data)
    {

        $files = JFactory::getApplication()->input->files->get('jform');


        if (empty($files['photo']['name'])) // means no file uploaded
            return true;

        $data = array_merge($files, $data);
        $result = JoomschoolHelper::uploadFile($data['photo'], 'students');

        if (is_array($result) && $result['success'] == false) {
            $this->setError($result['message']);
            return false;
        }

        $data['photo'] = $result;

        return true;

    }


    public function updateWithJoomlaUsers(&$data)
    {
        // update user data, and register/update him in joomla users table
        $result = JoomschoolHelperUser::processUser($data, 'student');

        if (!$result) {

            $errors = JoomschoolHelperUser::$errors;

            if (count($errors) > 0) {
                foreach ($errors as $error) {
                    $this->setError('<br>' . $error);
                }
            }

            return false;

        }

        return true;

    }


    public function saveCustomField($data)
    {
        $id = $data['id'] > 0 ? $data['id'] : $this->getState($this->getName() . '.id');
        $db = JFactory::getDbo();
        //Setting Custom Field Data
        $sid = JoomschoolHelper::getFieldSectionID('student');
        $fields = JoomschoolHelper::getFieldList($sid);
        $total_field = count($fields);

        $f = 0;
        foreach ($fields as $field) {
            $f++;
            $fid = $field->id;
            $sid = $sid;
            $field_input_name = 'field_' . $fid;
            $field_data = $data[$field_input_name];
            $student_id = $id;
            $type = $field->type;

            $query_check_id = "SELECT id FROM `#__joomschool_fields_data` WHERE fid = '" . $fid . "' AND sid = '" . $sid . "' AND panel_id = '" . $student_id . "'";
            $db->setQuery($query_check_id);
            $old_id = $db->loadResult();
            JoomschoolHelper::saveFields($fid, $type, $sid, $field_data, $student_id, $old_id);
        }
    }

    protected function getUserId()
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select('id')
            ->from($db->quoteName('#__users'))
            ->order('id DESC');
        $db->setQuery($query);
        return $db->loadObject();
    }

    public function getTeacher($class_id)
    {

        $db = JFactory::getDBO();
        $query = $db->getQuery(true);

        $query->select('user_id')
            ->from($db->quoteName('#__joomschool_teachers'))
            ->where("FIND_IN_SET('$class_id', class)");
        $db->setQuery($query);

        return $db->loadObject();
    }


    protected function checktStudentYearHistory($student_id)

    {

        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query->select('year')
            ->from($db->quoteName('#__joomschool_student_year'))
            ->where("sid = $student_id")
            ->order('year DESC');
        $db->setQuery($query);
        return $db->loadObject();
    }

    public function saveStudentHistory($data)
    {

        // Insert new one
        $studentYear = new stdClass();
        $studentYear->sid = $data['id'] > 0 ? $data['id'] : $this->getState($this->getName() . '.id');
        $studentYear->class = $data['class_id'];
        $studentYear->roll = $data['roll'];
        $studentYear->section = $data['section_id'];
        $studentYear->division = $data['division_id'];
        $studentYear->year = $data['year'];
        if ($data['year'] != $this->checktStudentYearHistory($data['id'])->year) {
            return JFactory::getDbo()->insertObject('#__joomschool_student_year', $studentYear);
        } else {
            return JFactory::getDbo()->updateObject('#__joomschool_student_year', $studentYear, 'sid');
        }

    }

    function getComment($cid, $roll, $eid)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('comments')))
            ->from($db->quoteName('#__joomschool_result_comments'))
            ->where($db->quoteName('roll') . ' = ' . $roll)
            ->where($db->quoteName('eid') . ' = ' . $eid)
            ->where($db->quoteName('class') . ' = ' . $cid);
        $db->setQuery($query);

        $comment = $db->loadResult();
        return $comment;
    }

    function getGradeList($cid)
    {
        $db = JFactory::getDBO();

        $query = $db->getQuery(true);
        $query
            ->select('*')
            ->from($db->quoteName('#__joomschool_exams_grade'))
            ->where($db->quoteName('category') . ' = ' . $db->quote($cid))
            ->order('id ASC');
        $db->setQuery($query);
        $rows = $db->loadObjectList();
        return $rows;
    }

    function getGradeSystem($id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('grade_system')))
            ->from($db->quoteName('#__joomschool_class'))
            ->where($db->quoteName('id') . ' = ' . $db->quote($id));
        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }

    function getSubjectname($id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('subject_name')))
            ->from($db->quoteName('#__joomschool_subjects'))
            ->where($db->quoteName('id') . ' = ' . $db->quote($id));
        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }

    function getMark($field, $exam_id, $class_id, $subject_id, $roll)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array($field)))
            ->from($db->quoteName('#__joomschool_exams_mark'))
            ->where($db->quoteName('exam_id') . ' = ' . $db->quote($exam_id))
            ->where($db->quoteName('class_id') . ' = ' . $db->quote($class_id))
            ->where($db->quoteName('subject_id') . ' = ' . $db->quote($subject_id))
            ->where($db->quoteName('roll') . ' = ' . $db->quote($roll));

        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }


    public function getResultStudentExams($student_id)
    {

        $input = JFactory::getApplication()->input;
        $year = $input->getInt('year', 0);
        if (!$year) {
            $year = JoomschoolHelper::getStudentYear($student_id)->year;
        }
        $year_id = JoomschoolHelper::getYearId($year);

        $exam_id = $this->getState('filter.exam');

        $db = $this->getDbo();
        $query = $db->getQuery(true);
        $query->select('em.id,e.name as exam_name,s.subject_name,e.examdate,e.comment as exam_comment,em.marks,em.mark_total,em.comment as exam_marks_comment');
        $query->from('#__joomschool_exams_mark AS em');

        $query->join('Left', '#__joomschool_exams AS e ON e.id = em.exam_id');
        $query->join('Left', '#__joomschool_subjects AS s ON s.id = em.subject_id');

        $query->where("em.student_id = $student_id");
        $query->where("em.year = $year_id");
        if ($exam_id) {
            $query->where("em.exam_id = $exam_id");
        }
        $db->setQuery($query);

        return $db->loadObjectList();
    }

    public function getExamId($student_id)
    {
        $input = JFactory::getApplication()->input;
        $year = $input->getInt('year', 0);

        if (!$year) {
            $year = JoomschoolHelper::getStudentYear($student_id)->year;
        }

        $year_id = JoomschoolHelper::getYearId($year);

        $exam_id = $this->getState('filter.exam');


        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query->select('e.id');
        $query->from('#__joomschool_exams AS e');
        $query->join('LEFT', '#__joomschool_exams_mark AS em on em.exam_id = e.id');
        $query->where("em.student_id = $student_id");
        $query->where("em.year = $year_id");
        if ($exam_id) {
            $query->where("em.exam_id = $exam_id");
        }
        $db->setQuery($query);
        return $db->loadResult();
    }

    public function getGradeLists()
    {

        $db = $this->getDbo();
        $query = $db->getQuery(true);
        $query->select('*');
        $query->from('#__joomschool_exams_grade');
        $db->setQuery($query);
        return $db->loadObjectList();


    }

    public function getGradeName($mark)
    {

        foreach ($this->getGradeLists() as $list) {

            if ($mark >= $list->mark_from && $mark <= $list->mark_upto) {
                return $result = ['name' => $list->name, 'grade_point' => $list->grade_point];
            }

        }
    }

    public function getTotalMarksGpa($student_id)
    {
        $input = JFactory::getApplication()->input;
        $exam_id = $this->getState('filter.exam');
        $year = $input->getInt('year', 0);
        if (!$year) {
            $year = JoomschoolHelper::getStudentYear($student_id)->year;
        }
        $year_id = JoomschoolHelper::getYearId($year);
        $db = $this->getDbo();
        $query = $db->getQuery(true);
        $query->select('exam_id,sum(marks) AS student_total_marks,(sum(marks) / COUNT(*)) AS gpa');

        $query->from('#__joomschool_exams_mark');
        if ($exam_id) {
            $query->where("exam_id = $exam_id");
        }
        $query->where("student_id = {$student_id}");
        $query->where("year = {$year_id}");
        $db->setQuery($query);
        return $db->loadObject();
    }


    /**
     ** Save Comment
     **/
    function savecomment($cid, $roll, $eid, $tid, $comment)
    {
        $db = JFactory::getDBO();
        $query_check_comment = $db->getQuery(true);
        $user = JFactory::getUser();
        $query_check_comment
            ->select($db->quoteName(array('id')))
            ->from($db->quoteName('#__joomschool_result_comments'))
            ->where($db->quoteName('roll') . ' = ' . $db->quote($roll))
            ->where($db->quoteName('eid') . ' = ' . $db->quote($eid))
            ->where($db->quoteName('class') . ' = ' . $db->quote($cid));
        $db->setQuery($query_check_comment);
        $comment_id = $db->loadResult();

        $table = $this->getTable('comment');
        $data = JRequest::get('post');
        // Bind the data.
        if (!$table->bind($data)) {
            $this->setError($user->getError());
            return false;
        }
        // Store the data.
        if (!empty($comment_id)) {
            $table->id = $comment_id;
        }
        $table->roll = $roll;
        $table->class = $cid;
        $table->eid = $eid;
        $table->comments = $comment;
        $table->tid = $tid;
        if (!$table->store()) {
            $this->setError($user->getError());
            return false;
        }
        $id = $table->id;
        return $id;
    }

    public function getFiledData($fid, $sid, $student_id)
    {

        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select('data');
        $query->from($db->quoteName('#__joomschool_fields_data'));
        $query->where($db->quoteName('fid') . ' = ' . $fid);
        $query->where($db->quoteName('sid') . ' = ' . $sid);
        $query->where($db->quoteName('panel_id') . ' = ' . $student_id);

        $db->setQuery($query);

        return $db->loadResult();
    }

}
