<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;


class JoomschoolModelStudents extends JModelList
{


    public function __construct($config = array())
    {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                'id', 'a.id',
                'name', 'a.name',
                'username', 'a.username',
                'email', 'a.email',
                'class_id','st.class_id',
                'roll_id','st.roll',
                'division_id','st.division_id',
                'year','st.year',
                'section','st.section',
                'block', 'a.block',
                'registerDate', 'a.registerDate',
                'lastvisitDate', 'a.lastvisitDate',
                'activation', 'a.activation',
                'active',
                'group_id',
                'range',
                'lastvisitrange',
                'state',




            );
        }

        parent::__construct($config);
    }



    protected function populateState($ordering = 'a.name', $direction = 'asc')
    {

        $app = JFactory::getApplication('administrator');

        // Adjust the context to support modal layouts.
        if ($layout = $app->input->get('layout', 'default', 'cmd')) {
            $this->context .= '.' . $layout;
        }

        // Load the filter state.
        $this->setState('filter.gender', $this->getUserStateFromRequest($this->context . '.filter.gender', 'filter_gender', '', 'string'));
        $this->setState('filter.active', $this->getUserStateFromRequest($this->context . '.filter.active', 'filter_active', '', 'cmd'));
        $this->setState('filter.state', $this->getUserStateFromRequest($this->context . '.filter.state', 'filter_state', '', 'cmd'));
        $this->setState('filter.group_id', $this->getUserStateFromRequest($this->context . '.filter.group_id', 'filter_group_id', null, 'int'));
        $this->setState('filter.range', $this->getUserStateFromRequest($this->context . '.filter.range', 'filter_range', '', 'cmd'));
        $this->setState(
            'filter.lastvisitrange', $this->getUserStateFromRequest($this->context . '.filter.lastvisitrange', 'filter_lastvisitrange', '', 'cmd')
        );

        $groups = json_decode(base64_decode($app->input->get('groups', '', 'BASE64')));

        if (isset($groups)) {
            $groups = ArrayHelper::toInteger($groups);
        }

        $this->setState('filter.groups', $groups);

        $excluded = json_decode(base64_decode($app->input->get('excluded', '', 'BASE64')));

        if (isset($excluded)) {
            $excluded = ArrayHelper::toInteger($excluded);
        }

        $this->setState('filter.excluded', $excluded);

        // Load the parameters.
        $params = JComponentHelper::getParams('com_joomschool');
        $this->setState('params', $params);

        // List state information.
        parent::populateState($ordering, $direction);
    }



    /**
     * Get a list of titles.
     *
     * @return    array
     * @since    1.6
     */
    public function getItems()
    {
        // Get a storage key.
        $store = $this->getStoreId();

        // Try to load the data from internal storage.
        if (empty($this->cache[$store])) {
            $groups = $this->getState('filter.groups');
            $groupId = $this->getState('filter.group_id');

            if (isset($groups) && (empty($groups) || $groupId && !in_array($groupId, $groups))) {
                $items = array();
            } else {
                $items = parent::getItems();
            }

            // Bail out on an error or empty list.
            if (empty($items)) {
                $this->cache[$store] = $items;

                return $items;
            }

            // Joining the groups with the main query is a performance hog.
            // Find the information only on the result set.

            // First pass: get list of the user id's and reset the counts.
            $userIds = array();

            foreach ($items as $item) {
                $userIds[] = (int)$item->id;
                $item->group_count = 0;
                $item->group_names = '';
                $item->note_count = 0;
            }

            // Get the counts from the database only for the users in the list.
            $db = $this->getDbo();
            $query = $db->getQuery(true);

            // Join over the group mapping table.
            $query->select('map.user_id, COUNT(map.group_id) AS group_count')
                ->from('#__user_usergroup_map AS map')
                ->where('map.user_id IN (' . implode(',', $userIds) . ')')
                ->group('map.user_id')
                // Join over the user groups table.
                ->join('LEFT', '#__usergroups AS g2 ON g2.id = map.group_id');

            $db->setQuery($query);

            // Load the counts into an array indexed on the user id field.
            try {
                $userGroups = $db->loadObjectList('user_id');
            } catch (RuntimeException $e) {
                $this->setError($e->getMessage());

                return false;
            }

            $query->clear()
                ->select('n.user_id, COUNT(n.id) As note_count')
                ->from('#__user_notes AS n')
                ->where('n.user_id IN (' . implode(',', $userIds) . ')')
                ->where('n.state >= 0')
                ->group('n.user_id');

            $db->setQuery($query);

            // Load the counts into an array indexed on the aro.value field (the user id).
            try {
                $userNotes = $db->loadObjectList('user_id');
            } catch (RuntimeException $e) {
                $this->setError($e->getMessage());

                return false;
            }

            // Second pass: collect the group counts into the master items array.
            foreach ($items as &$item) {
                if (isset($userGroups[$item->id])) {
                    $item->group_count = $userGroups[$item->id]->group_count;

                    // Group_concat in other databases is not supported
                    $item->group_names = $this->_getUserDisplayedGroups($item->id);
                }

                if (isset($userNotes[$item->id])) {
                    $item->note_count = $userNotes[$item->id]->note_count;
                }
            }

            // Add the items to the internal cache.
            $this->cache[$store] = $items;
        }

        return $this->cache[$store];
    }


    protected function getListQuery()
    {
        // Create a new query object.
        $db = $this->getDbo();
        $query = $db->getQuery(true);
        $user = JFactory::getUser();
        $input = JFactory::getApplication()->input;
        $isModal = $input->getWord('tmpl');
        // Filter the items over the group id if set.
        $groupId = $this->getState('filter.group_id');
        $groups = $this->getState('filter.groups');
        // Select the required fields from the table.
        $query->select(
            $this->getState(
                'list.select',
                'DISTINCT st.id, a.id AS user_id , a.name, a.username, a.email, a.block, a.registerDate, a.lastvisitDate, a.activation,d.division_name,c.class_name,s.section_name,t.number_of_vehicle,st.photo,st.year as year_id ,st.roll,st.state,y.year'
            )
        );
        $query->from('#__users AS a');
        $joint  = $isModal  ? 'LEFT' : 'INNER';
        $query->join($joint, '#__joomschool_students AS st ON st.user_id = a.id');

        $query->join('LEFT', '#__user_usergroup_map AS m ON m.user_id = a.id');
        $query->join('LEFT', '#__usergroups AS ug ON ug.id = m.group_id');
        $query->join('LEFT', '#__joomschool_transport AS t ON t.id = st.transport_id');
        $query->join('LEFT', '#__joomschool_sections AS s ON s.id = st.section_id');
        $query->join('LEFT', '#__joomschool_class AS c ON c.id = st.class_id');
        $query->join('LEFT', '#__joomschool_division AS d ON d.id = st.division_id');
      $query->join('LEFT', '#__joomschool_academic_year AS y ON y.id = st.year');
        $query->join('LEFT', '#__joomschool_parents AS p ON p.student_id = st.id');

        if($isModal){
            $query->where('a.id NOT IN (SELECT user_id FROM #__joomschool_students)');
            $query->where('a.id NOT IN (SELECT user_id FROM #__joomschool_teachers)');
            $query->where('a.id NOT IN (SELECT user_id FROM #__joomschool_parents)');
        }

        $query->group('a.id');

        if ($groupId || isset($groups)) {
            if ($groupId) {
                $query->where('m.group_id = ' . (int)$groupId);
            }

            if (isset($groups)) {
                $query->where('m.group_id IN (' . implode(',', $groups) . ')');
            }
        }
        // Filter by Gender.
        $gender = $this->getState('filter.gender');

        if ($gender) {
          
            $query->where('st.gender = ' . $db->quote($gender));
        }

        // Filter by Class.
        $classId = $this->getState('filter.class_id');
        if (is_numeric($classId)) {
            $query->where('st.class_id = ' . $db->quote($classId));
        }

        // Filter by Section.
        $sectionId = $this->getState('filter.section_id');
        if (is_numeric($sectionId)) {
            $query->where('st.section_id = ' . $db->quote($sectionId));
        }

        // Filter by Division.
        $divisionId = $this->getState('filter.division_id');
        if (is_numeric($divisionId)) {
            $query->where('st.division_id = ' . $db->quote($divisionId));
        }

        // If the model is set to check item state, add to the query.
        $state = $this->getState('filter.state');

        if (is_numeric($state)) {
            $query->where('a.block = ' . (int)$state);
        }

        // If the model is set to check the activated state, add to the query.
        $active = $this->getState('filter.active');

        if (is_numeric($active)) {
            if ($active == '0') {
                $query->where('a.activation IN (' . $db->quote('') . ', ' . $db->quote('0') . ')');
            } elseif ($active == '1') {
                $query->where($query->length('a.activation') . ' > 1');
            }
        }
// Filter the items over the search string if set.
        $search = $this->getState('filter.search');

        if (!empty($search)) {
            if (stripos($search, 'id:') === 0) {
                $query->where('a.id = ' . (int)substr($search, 3));
            } elseif (stripos($search, 'username:') === 0) {
                $search = $db->quote('%' . $db->escape(substr($search, 9), true) . '%');
                $query->where('a.username LIKE ' . $search);
            } else {
                // Escape the search token.
                $search = $db->quote('%' . str_replace(' ', '%', $db->escape(trim($search), true) . '%'));

                // Compile the different search clauses.
                $searches = array();
                $searches[] = 'a.name LIKE ' . $search;
                $searches[] = 'a.username LIKE ' . $search;
                $searches[] = 'a.email LIKE ' . $search;

                // Add the clauses to the query.
                $query->where('(' . implode(' OR ', $searches) . ')');
            }
        }

        // Add filter for registration ranges select list
        $range = $this->getState('filter.range');

        // Apply the range filter.
        if ($range) {
            $dates = $this->buildDateRange($range);

            if ($dates['dNow'] === false) {
                $query->where(
                    $db->qn('a.registerDate') . ' < ' . $db->quote($dates['dStart']->format('Y-m-d H:i:s'))
                );
            } else {
                $query->where(
                    $db->qn('a.registerDate') . ' >= ' . $db->quote($dates['dStart']->format('Y-m-d H:i:s')) .
                    ' AND ' . $db->qn('a.registerDate') . ' <= ' . $db->quote($dates['dNow']->format('Y-m-d H:i:s'))
                );
            }
        }

        // Add filter for registration ranges select list
        $lastvisitrange = $this->getState('filter.lastvisitrange');

        // Apply the range filter.
        if ($lastvisitrange) {
            $dates = $this->buildDateRange($lastvisitrange);

            if (is_string($dates['dStart'])) {
                $query->where(
                    $db->qn('a.lastvisitDate') . ' = ' . $db->quote($dates['dStart'])
                );
            } elseif ($dates['dNow'] === false) {
                $query->where(
                    $db->qn('a.lastvisitDate') . ' < ' . $db->quote($dates['dStart']->format('Y-m-d H:i:s'))
                );
            } else {
                $query->where(
                    $db->qn('a.lastvisitDate') . ' >= ' . $db->quote($dates['dStart']->format('Y-m-d H:i:s')) .
                    ' AND ' . $db->qn('a.lastvisitDate') . ' <= ' . $db->quote($dates['dNow']->format('Y-m-d H:i:s'))
                );
            }
        }

        // Filter by excluded users
        $excluded = $this->getState('filter.excluded');

        if (!empty($excluded)) {
            $query->where('id NOT IN (' . implode(',', $excluded) . ')');
        }

        // Add the list ordering clause.
        $query->order($db->qn($db->escape($this->getState('list.ordering', 'a.name'))) . ' ' . $db->escape($this->getState('list.direction', 'ASC')));

        return $query;

    }



    /**
     * Construct the date range to filter on.
     *
     * @param string $range The textual range to construct the filter for.
     *
     * @return  string  The date range to filter on.
     *
     * @since   3.6.0
     */
    private function buildDateRange($range)
    {
        // Get UTC for now.
        $dNow = new JDate;
        $dStart = clone $dNow;

        switch ($range) {
            case 'past_week':
                $dStart->modify('-7 day');
                break;

            case 'past_1month':
                $dStart->modify('-1 month');
                break;

            case 'past_3month':
                $dStart->modify('-3 month');
                break;

            case 'past_6month':
                $dStart->modify('-6 month');
                break;

            case 'post_year':
                $dNow = false;
            case 'past_year':
                $dStart->modify('-1 year');
                break;

            case 'today':
                // Ranges that need to align with local 'days' need special treatment.
                $app = JFactory::getApplication();
                $offset = $app->get('offset');

                // Reset the start time to be the beginning of today, local time.
                $dStart = new JDate('now', $offset);
                $dStart->setTime(0, 0, 0);

                // Now change the timezone back to UTC.
                $tz = new DateTimeZone('GMT');
                $dStart->setTimezone($tz);
                break;
            case 'never':
                $dNow = false;
                $dStart = $this->_db->getNullDate();
                break;
        }

        return array('dNow' => $dNow, 'dStart' => $dStart);
    }

    /**
     * SQL server change
     *
     * @param integer $user_id User identifier
     *
     * @return  string   Groups titles imploded :$
     */
    protected function _getUserDisplayedGroups($user_id)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true)
            ->select($db->qn('title'))
            ->from($db->qn('#__usergroups', 'ug'))
            ->join('LEFT', $db->qn('#__user_usergroup_map', 'map') . ' ON (ug.id = map.group_id)')
            ->where($db->qn('map.user_id') . ' = ' . (int)$user_id);

        try {
            $result = $db->setQuery($query)->loadColumn();
        } catch (RunTimeException $e) {
            $result = array();
        }

        return implode("\n", $result);
    }
    

    /**
     ** Transport List
     **/
    function gettransportList($value)
    {

        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('id', 'route_name', 'number_of_vehicle')))
            ->from($db->quoteName('#__joomschool_transport'))
            ->order('id ASC');
        $db->setQuery($query);
        $rows = $db->loadObjectList();
        if ($db->getErrorNum()) {
            echo $db->stderr();
            return false;
        }
        $transport_array = array();

        $transport_array[] = array('value' => '', 'text' => JText::_(' -- Select Transport (Number) -- '));
        foreach ($rows as $row) {
            $transport_array[] = array('value' => $row->id, 'text' => JText::_(' ' . $row->route_name . '(' . $row->number_of_vehicle . ')'));
        }

        $transports = JHTML::_('select.genericList', $transport_array, 'transport_id', ' class="  inputbox  "  ', 'value', 'text', $value);
        return $transports;
    }


    /**
     ** TOTAL New Students
     **/
    function totalNewstudent()
    {
        $db = JFactory::getDBO();
        $query = "SELECT * FROM `#__joomschool_students` WHERE roll = '' ";
        $db->setQuery($query);
        $rows = count($db->loadObjectList());
        return $rows;
    }


    function getGradeSystem($id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('grade_system')))
            ->from($db->quoteName('#__joomschool_class'))
            ->where($db->quoteName('id') . ' = ' . $db->quote($id));
        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }

    function getSubjectname($id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('subject_name')))
            ->from($db->quoteName('#__joomschool_subjects'))
            ->where($db->quoteName('id') . ' = ' . $db->quote($id));
        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }

    function getSubjectSNCode($id)
    {
        $db = JFactory::getDBO();

        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('subject_shot_name')))
            ->from($db->quoteName('#__joomschool_subjects'))
            ->where($db->quoteName('id') . ' = ' . $db->quote($id));
        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }


    function getParentID($id)
    {
        $db = JFactory::getDBO();

        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('id')))
            ->from($db->quoteName('#__joomschool_parents'))
            ->where($db->quoteName('student_id') . ' = ' . $db->quote($id));
        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }


    function getMark($field, $exam_id, $class_id, $subject_id, $roll)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array($field)))
            ->from($db->quoteName('#__joomschool_exams_mark'))
            ->where($db->quoteName('exam_id') . ' = ' . $db->quote($exam_id))
            ->where($db->quoteName('class_id') . ' = ' . $db->quote($class_id))
            ->where($db->quoteName('subject_id') . ' = ' . $db->quote($subject_id))
            ->where($db->quoteName('roll') . ' = ' . $db->quote($roll));

        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }


    /**
     ** Exam List
     **/
    function getExamList($year)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select('*')
            ->from($db->quoteName('#__joomschool_exams'))
            ->where(' YEAR(examdate) = ' . $db->quote($year) . ' AND ' . $db->quoteName('published') . ' = ' . $db->quote('1'))
            ->order('id ASC');
        $db->setQuery($query);
        $rows = $db->loadObjectList();
        return $rows;
    }

    /**
     ** Exam ID
     **/
    function getExamID($year)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select('id')
            ->from($db->quoteName('#__joomschool_exams'))
            ->where(' YEAR(examdate) = ' . $db->quote($year) . ' AND ' . $db->quoteName('published') . ' = ' . $db->quote('1'));
        $db->setQuery($query);
        $rows = $db->loadResult();
        return $rows;
    }


    /**
     ** Grade List
     **/
    function getGradeList($cid)
    {
        $db = JFactory::getDBO();

        $query = $db->getQuery(true);
        $query
            ->select('*')
            ->from($db->quoteName('#__joomschool_exams_grade'))
            ->where($db->quoteName('category') . ' = ' . $db->quote($cid))
            ->order('id ASC');
        $db->setQuery($query);
        $rows = $db->loadObjectList();
        return $rows;
    }


    /**------------------------------------------------------------------------------------------------------------------
     ** ------------------------------- STUDENT SINGLE DATA ------------------------------------------------------------
     **-----------------------------------------------------------------------------------------------------------------*/
    function getStudents($id)
    {
        if ($id) {
            $this->_id = $id;
        }
        if (empty($this->_data)) {
            $this->_data = $this->getTable('students');
            $this->_data->load($this->_id);
        }
        return $this->_data;
    }

    /**------------------------------------------------------------------------------------------------------------------
     ** ------------------------------- STUDENT LIST --------------------------------------------------------------------
     **-----------------------------------------------------------------------------------------------------------------*/




    /**
     *   Publish Unpublish script
     */
    public function toggle($table_name, $cid_name, $field, $value)
    {

        $cids = JRequest::getVar('cid', array(0), 'post', 'array');

        $table = $this->getTable($table_name);
        if (count($cids)) {
            foreach ($cids as $cid) {
                if ($cid) {
                    $table->$cid_name = $cid;
                    $table->$field = $value;
                    if (!$table->store()) {
                        $this->setError($this->_db->getErrorMsg());
                        return false;
                    }
                }
            }
        }

        return true;
    }

    /*
     * Not used anymore
     */
    /**------------------------------------------------------------------------------------------------------------------
     ** ------------------------------- SAVE STUDENT -------------------------------------------------------------------
     **-----------------------------------------------------------------------------------------------------------------*/
    public function store()
    {

        $app = JFactory::getApplication();
        $viewtype = JFactory::getApplication()->input->get('viewtype','','word');

        $params = JComponentHelper::getParams('com_joomschool');
        $students_account = $params->get('students_account', 1);

        $data_student = JRequest::get('post');

        $data_student['chabima'] = isset($data_student['chabima']) ? $data_student['chabima'] : JFactory::getUser($data_student['userid'])->username;
        $data_student['churanita'] = isset($data_student['churanita']) ? $data_student['churanita'] : '';
        $data_student['email'] = isset($data_student['email']) ? $data_student['churanita'] : JFactory::getUser($data_student['userid'])->email;

        $chabima = str_replace(' ', '', $data_student['chabima']);
        $alias = str_replace(' ', '-', strtolower($data_student['name']));
        $churanita = $data_student['churanita'];
        $email = $data_student['email'];


        if (!empty($students_account) && $viewtype == 'newstudents') { // students account creation enabled

            if ((int)$data_student['add_or_select_user']) { // associate to joomla user
                $uid = $data_student['userid'];

            } elseif((int)$data_student['add_or_select_user'] == 0) { // create new account

                $user = new JUser;
                $data = JRequest::get('post');
                $data['block'] = 0;

                // Bind the data.
                if (!$user->bind($data)) {
                    $this->setError(JText::sprintf('COM_USERS_REGISTRATION_BIND_FAILED', $user->getError()));

                    return false;
                }

                // Store the data.
                $user->username = $chabima;
                $user->password = md5($churanita);
                $user->email = $email;
                if (!$user->save()) {
                    $this->setError(JText::sprintf('COM_USERS_REGISTRATION_SAVE_FAILED', $user->getError()));
                    return false;
                }


                //insert user group map
                $query_user_group = $db->getQuery(true);
                $columns_user_group = array('user_id', 'group_id');
                $values_user_group = array($uid, $usergroup_id);
                $query_user_group
                    ->insert($db->quoteName('#__user_usergroup_map'))
                    ->columns($db->quoteName($columns_user_group))
                    ->values(implode(',', $values_user_group));
                $db->setQuery($query_user_group);
                $db->execute();
            }

        }

        if(is_null($uid)){
            $uid = $data_student['userid'];
        }

        // GET NEXT ID
        $config = JFactory::getConfig();
        $database_name = $config->get('db');
        $dbprefix = $config->get('dbprefix');

        $db = JFactory::getDbo();
        $query = "SELECT AUTO_INCREMENT AS id FROM information_schema.tables WHERE table_schema = '" . $database_name . "' AND table_name = '" . $dbprefix . "joomschool_students'";
        $db->setQuery($query);
        $rows = $db->loadObjectList();
        $nextid = $rows[0]->id;
        $table = $this->getTable('students');

        //upload section data
        $file = JRequest::getVar('photo', null, 'files', 'array');
        jimport('joomla.filesystem.file');

        if (empty($data_student['student_id'])) {
            $nextid_final = $nextid;
        } else {
            $nextid_final = $data_student['student_id'];
        }

        $filename = JFile::makeSafe($nextid_final . '_' . $file['name']);
        $new_file = $_FILES['photo']['name'];

        // Bind the data.
        if (!$table->bind($data_student)) {
            $this->setError($user->getError());
            return false;
        }

        // Store the data.
        if ($data_student['chabima']) {
            $table->chabima = $chabima;
        }
        if ($data_student['churanita']) {
            $table->churanita = $churanita;
        }
        if ($data_student['student_id']) {
            $table->id = $data_student['student_id'];
        }

        //Save year
        if ($data_student['year']) {
            $table->year = $data_student['year'];
        }

        if ($new_file) {
            $table->photo = $filename;
        }
        if ($uid) {
            $table->user_id = $uid;
        }

        //store alias
        $table->alias = $alias;

        if (!$table->store()) {
            $this->setError($user->getError());
            return false;
        }
        $id = $table->id;


        //Setting Custom Field Data
        $sid = JoomschoolHelper::getFieldSectionID('student');
        $fields = JoomschoolHelper::getFieldList($sid);
        $total_field = count($fields);

        $f = 0;
        foreach ($fields as $field) {
            $f++;
            $fid = $field->id;
            $sid = $sid;
            $field_input_name = 'field_' . $fid;
            $field_data = $data_student[$field_input_name];
            $student_id = $id;
            $type = $field->type;

            $query_check_id = "SELECT id FROM `#__joomschool_fields_data` WHERE fid = '" . $fid . "' AND sid = '" . $sid . "' AND panel_id = '" . $student_id . "'";
            $db->setQuery($query_check_id);
            $old_id = $db->loadResult();
            JoomschoolHelper::saveFields($fid, $type, $sid, $field_data, $student_id, $old_id);
        }


        //PHOTO UPLOAD ######################################################################

        if ($new_file) {
            $old_file = $data_student['old_photo'];
            if ($old_file != "") {
                $path = "../components/com_joomschool/photo/students/";
                JFile::delete($path . $old_file);
            }

            $src = $file['tmp_name'];
            $dest = "../components/com_joomschool/photo/students/" . $filename;
            if (strtolower(JFile::getExt($filename)) == 'jpg' || 'png' || 'gif' || 'jpeg') {
                if (JFile::upload($src, $dest)) {

                } else {
                    $upload_error = "upload_error";
                    return $upload_error;
                }
            } else {
                //Redirect and notify user file is not right extension
                $upload_error_extension = "upload_error_extension";
                return $upload_error_extension;
            }
        }


        // Year Management
        $exit_id = $this->getExitData('id', $data_student['year'], $id);
        if (empty($exit_id)) {
            // Get insert
            $object_new = new stdClass();
            $object_new->sid = $id;
            $object_new->class = $data_student['class'];
            $object_new->roll = $data_student['roll'];
            $object_new->division = $data_student['division'];
            $object_new->section = $data_student['section'];
            $object_new->year = $data_student['year'];
            $result_insert = JFactory::getDbo()->insertObject('#__joomschool_student_year', $object_new);
        } else {
            // Get update
            $object = new stdClass();
            $object->id = $exit_id;
            $object->sid = $id;
            $object->class = $data_student['class'];
            $object->roll = $data_student['roll'];
            $object->division = $data_student['division'];
            $object->section = $data_student['section'];
            $object->year = $data_student['year'];
            $result_update = JFactory::getDbo()->updateObject('#__joomschool_student_year', $object, 'id');
        }


        return $id;


    }


    function getExitData($select_field, $year, $sid)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array($select_field)))
            ->from($db->quoteName('#__joomschool_student_year'))
            ->where($db->quoteName('sid') . ' = ' . $db->quote($sid))
            ->where($db->quoteName('year') . ' = ' . $db->quote($year));
        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }


    /**------------------------------------------------------------------------------------------------------------------
     ** ------------------------------- DELETE STUDENT ------------------------------------------------------------------
     **-----------------------------------------------------------------------------------------------------------------*/
    public function delete()
    {
        $cids = JRequest::getVar('cid', array(0), 'post', 'array');
        $table =& $this->getTable('students');

        $app = JFactory::getApplication();
        $params = JComponentHelper::getParams('com_joomschool');
        $students_account = $params->get('students_account', 1);

        if (count($cids)) {
            foreach ($cids as $cid) {

                $sid = $cid;
                //delete Student user and group
                $db = JFactory::getDBO();
                $query_user_id = "SELECT user_id FROM `#__joomschool_students` WHERE id = '" . $sid . "'";
                $db->setQuery($query_user_id);
                $user_id = $db->loadResult();
                if (!empty($students_account)) {
                    if (!empty($user_id)) {
                        //Delete user group map
                        $db->setQuery("DELETE FROM #__user_usergroup_map WHERE user_id=" . (int)$user_id . " ");
                        $delete_group_map = $db->query();
                        if ($delete_group_map) {
                            $db->setQuery("DELETE FROM #__users WHERE id=" . (int)$user_id . " ");
                            $db->query();
                        }
                    }
                }


                //Delete Student photo
                $query_user_photo = "SELECT photo FROM `#__joomschool_students` WHERE id = '" . $sid . "'";
                $db->setQuery($query_user_photo);
                $user_photo = $db->loadResult();
                if ($user_photo != "") {
                    $path = "../components/com_joomschool/photo/students/";
                    JFile::delete($path . $user_photo);
                }

                if (!$table->delete($cid)) {
                    $this->setError($this->_db->getErrorMsg());
                    return false;
                }
            }
        }
        return true;
    }


    /**
     ** Get Comment
     **/
    function getComment($cid, $roll, $eid, $tid)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('comments')))
            ->from($db->quoteName('#__joomschool_result_comments'))
            ->where($db->quoteName('roll') . ' = ' . $db->quote($roll))
            ->where($db->quoteName('eid') . ' = ' . $db->quote($eid))
            ->where($db->quoteName('class') . ' = ' . $db->quote($cid));
        $db->setQuery($query);
        $comment = $db->loadResult();
        return $comment;
    }






}
