<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;


class JoomschoolModelTeachers extends JModelList
{


    public function __construct($config = array())
    {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                'id', 't.id',
                'name', 'a.name',
                'username', 'a.username',
                'email', 'a.email',
                'class','t.class',
                'section','t.section',
                'subject','t.subject',
                'block', 'a.block',
                'registerDate', 'a.registerDate',
                'lastvisitDate', 'a.lastvisitDate',
                'activation', 'a.activation',
                'active',
                'group_id',
                'range',
                'lastvisitrange',
                'state',




            );
        }

        parent::__construct($config);
    }



    protected function populateState($ordering = 'a.name', $direction = 'asc')
    {
        $app = JFactory::getApplication('administrator');

        // Adjust the context to support modal layouts.
        if ($layout = $app->input->get('layout', 'default', 'cmd')) {
            $this->context .= '.' . $layout;
        }

        // Load the filter state.
        $this->setState('filter.section', $this->getUserStateFromRequest($this->context . '.filter.section', 'filter_section', '', 'string'));
        $this->setState('filter.class', $this->getUserStateFromRequest($this->context . '.filter.class', 'filter_class', '', 'string'));
        $this->setState('filter.subject', $this->getUserStateFromRequest($this->context . '.filter.subject', 'filter_subject', '', 'string'));
        $this->setState('filter.gender', $this->getUserStateFromRequest($this->context . '.filter.gender', 'filter_gender', '', 'string'));
        $this->setState('filter.search', $this->getUserStateFromRequest($this->context . '.filter.search', 'filter_search', '', 'string'));
        $this->setState('filter.active', $this->getUserStateFromRequest($this->context . '.filter.active', 'filter_active', '', 'cmd'));
        $this->setState('filter.state', $this->getUserStateFromRequest($this->context . '.filter.state', 'filter_state', '', 'cmd'));
        $this->setState('filter.group_id', $this->getUserStateFromRequest($this->context . '.filter.group_id', 'filter_group_id', null, 'int'));
        $this->setState('filter.range', $this->getUserStateFromRequest($this->context . '.filter.range', 'filter_range', '', 'cmd'));
        $this->setState(
            'filter.lastvisitrange', $this->getUserStateFromRequest($this->context . '.filter.lastvisitrange', 'filter_lastvisitrange', '', 'cmd')
        );

        $groups = json_decode(base64_decode($app->input->get('groups', '', 'BASE64')));

        if (isset($groups)) {
            $groups = ArrayHelper::toInteger($groups);
        }

        $this->setState('filter.groups', $groups);

        $excluded = json_decode(base64_decode($app->input->get('excluded', '', 'BASE64')));

        if (isset($excluded)) {
            $excluded = ArrayHelper::toInteger($excluded);
        }

        $this->setState('filter.excluded', $excluded);

        // Load the parameters.
        $params = JComponentHelper::getParams('com_joomschool');
        $this->setState('params', $params);

        // List state information.
        parent::populateState($ordering, $direction);
    }



    /**
     * Get a list of titles.
     *
     * @return    array
     * @since    1.6
     */
    public function getItems()
    {
        // Get a storage key.
        $store = $this->getStoreId();

        // Try to load the data from internal storage.
        if (empty($this->cache[$store])) {
            $groups = $this->getState('filter.groups');
            $groupId = $this->getState('filter.group_id');

            if (isset($groups) && (empty($groups) || $groupId && !in_array($groupId, $groups))) {
                $items = array();
            } else {
                $items = parent::getItems();
            }

            // Bail out on an error or empty list.
            if (empty($items)) {
                $this->cache[$store] = $items;

                return $items;
            }

            // Joining the groups with the main query is a performance hog.
            // Find the information only on the result set.

            // First pass: get list of the user id's and reset the counts.
            $userIds = array();

            foreach ($items as $item) {
                $userIds[] = (int)$item->id;
                $item->group_count = 0;
                $item->group_names = '';
                $item->note_count = 0;
            }

            // Get the counts from the database only for the users in the list.
            $db = $this->getDbo();
            $query = $db->getQuery(true);

            // Join over the group mapping table.
            $query->select('map.user_id, COUNT(map.group_id) AS group_count')
                ->from('#__user_usergroup_map AS map')
                ->where('map.user_id IN (' . implode(',', $userIds) . ')')
                ->group('map.user_id')
                // Join over the user groups table.
                ->join('LEFT', '#__usergroups AS g2 ON g2.id = map.group_id');

            $db->setQuery($query);

            // Load the counts into an array indexed on the user id field.
            try {
                $userGroups = $db->loadObjectList('user_id');
            } catch (RuntimeException $e) {
                $this->setError($e->getMessage());

                return false;
            }

            $query->clear()
                ->select('n.user_id, COUNT(n.id) As note_count')
                ->from('#__user_notes AS n')
                ->where('n.user_id IN (' . implode(',', $userIds) . ')')
                ->where('n.state >= 0')
                ->group('n.user_id');

            $db->setQuery($query);

            // Load the counts into an array indexed on the aro.value field (the user id).
            try {
                $userNotes = $db->loadObjectList('user_id');
            } catch (RuntimeException $e) {
                $this->setError($e->getMessage());

                return false;
            }

            // Second pass: collect the group counts into the master items array.
            foreach ($items as &$item) {
                if (isset($userGroups[$item->id])) {
                    $item->group_count = $userGroups[$item->id]->group_count;

                    // Group_concat in other databases is not supported
                    $item->group_names = $this->_getUserDisplayedGroups($item->id);
                }

                if (isset($userNotes[$item->id])) {
                    $item->note_count = $userNotes[$item->id]->note_count;
                }
            }

            // Add the items to the internal cache.
            $this->cache[$store] = $items;
        }

        return $this->cache[$store];
    }


    protected function getListQuery()
    {
        // Create a new query object.
        $db = $this->getDbo();
        $query = $db->getQuery(true);
        $user = JFactory::getUser();
        $input = JFactory::getApplication()->input;
        $isModal = $input->getWord('tmpl');
        // Filter the items over the group id if set.
        $groupId = $this->getState('filter.group_id');
        $groups = $this->getState('filter.groups');
        // Select the required fields from the table.
        $query->select(
            $this->getState(
                'list.select',
                'DISTINCT t.id, t.user_id , a.name, a.username, a.email, a.block, a.registerDate, a.lastvisitDate, a.activation, t.class, t.section, t.subject, t.photo,t.state'
            )
        );
        $query->from('#__users AS a');
        $joint  = $isModal  ? 'LEFT' : 'INNER';
        $query->join($joint, '#__joomschool_teachers AS t ON t.user_id = a.id');
        $query->join('LEFT', '#__user_usergroup_map AS m ON m.user_id = a.id');
        $query->join('LEFT', '#__usergroups AS ug ON ug.id = m.group_id');


        if($isModal){
            $query->where('a.id NOT IN (SELECT user_id FROM #__joomschool_students)');
            $query->where('a.id NOT IN (SELECT user_id FROM #__joomschool_teachers)');
            $query->where('a.id NOT IN (SELECT user_id FROM #__joomschool_parents)');
        }

        $query->group('a.id');

        if ($groupId || isset($groups)) {
            if ($groupId) {
                $query->where('m.group_id = ' . (int)$groupId);
            }

            if (isset($groups)) {
                $query->where('m.group_id IN (' . implode(',', $groups) . ')');
            }
        }
        // Filter by Gender.
        $gender = $this->getState('filter.gender');
        if ($gender) {
            $query->where('t.gender = ' . $db->quote($gender));
        }

        // Filter by Class.
        $classId = $this->getState('filter.class');
        if (is_numeric($classId)) {
            $query->where("FIND_IN_SET('$classId', t.class)");

// $query->where("JSON_CONTAINS(t.class,'$classId')");
            /*
             $classId = '"'.$classId.'"';
           $query->where('t.class = ' . $db->quote($classId));
            */
        }

        // Filter by Section.
        $sectionId = $this->getState('filter.section');
        if (is_numeric($sectionId)) {
            $query->where("FIND_IN_SET('$sectionId', t.section)");

        }

        // Filter by Subject.
        $subjectId = $this->getState('filter.subject');
        if (is_numeric($subjectId)) {
            $query->where("FIND_IN_SET('$subjectId', t.subject)");
        }


        // If the model is set to check item state, add to the query.
        $state = $this->getState('filter.state');

        if (is_numeric($state)) {
            $query->where('a.block = ' . (int)$state);
        }

        // If the model is set to check the activated state, add to the query.
        $active = $this->getState('filter.active');

        if (is_numeric($active)) {
            if ($active == '0') {
                $query->where('a.activation IN (' . $db->quote('') . ', ' . $db->quote('0') . ')');
            } elseif ($active == '1') {
                $query->where($query->length('a.activation') . ' > 1');
            }
        }
// Filter the items over the search string if set.
        $search = $this->getState('filter.search');

        if (!empty($search)) {
            if (stripos($search, 'id:') === 0) {
                $query->where('a.id = ' . (int)substr($search, 3));
            } elseif (stripos($search, 'username:') === 0) {
                $search = $db->quote('%' . $db->escape(substr($search, 9), true) . '%');
                $query->where('a.username LIKE ' . $search);
            } else {
                // Escape the search token.
                $search = $db->quote('%' . str_replace(' ', '%', $db->escape(trim($search), true) . '%'));

                // Compile the different search clauses.
                $searches = array();
                $searches[] = 'a.name LIKE ' . $search;
                $searches[] = 'a.username LIKE ' . $search;
                $searches[] = 'a.email LIKE ' . $search;

                // Add the clauses to the query.
                $query->where('(' . implode(' OR ', $searches) . ')');
            }
        }

        // Add filter for registration ranges select list
        $range = $this->getState('filter.range');

        // Apply the range filter.
        if ($range) {
            $dates = $this->buildDateRange($range);

            if ($dates['dNow'] === false) {
                $query->where(
                    $db->qn('a.registerDate') . ' < ' . $db->quote($dates['dStart']->format('Y-m-d H:i:s'))
                );
            } else {
                $query->where(
                    $db->qn('a.registerDate') . ' >= ' . $db->quote($dates['dStart']->format('Y-m-d H:i:s')) .
                    ' AND ' . $db->qn('a.registerDate') . ' <= ' . $db->quote($dates['dNow']->format('Y-m-d H:i:s'))
                );
            }
        }

        // Add filter for registration ranges select list
        $lastvisitrange = $this->getState('filter.lastvisitrange');

        // Apply the range filter.
        if ($lastvisitrange) {
            $dates = $this->buildDateRange($lastvisitrange);

            if (is_string($dates['dStart'])) {
                $query->where(
                    $db->qn('a.lastvisitDate') . ' = ' . $db->quote($dates['dStart'])
                );
            } elseif ($dates['dNow'] === false) {
                $query->where(
                    $db->qn('a.lastvisitDate') . ' < ' . $db->quote($dates['dStart']->format('Y-m-d H:i:s'))
                );
            } else {
                $query->where(
                    $db->qn('a.lastvisitDate') . ' >= ' . $db->quote($dates['dStart']->format('Y-m-d H:i:s')) .
                    ' AND ' . $db->qn('a.lastvisitDate') . ' <= ' . $db->quote($dates['dNow']->format('Y-m-d H:i:s'))
                );
            }
        }

        // Filter by excluded users
        $excluded = $this->getState('filter.excluded');

        if (!empty($excluded)) {
            $query->where('id NOT IN (' . implode(',', $excluded) . ')');
        }

        // Add the list ordering clause.
        $query->order($db->qn($db->escape($this->getState('list.ordering', 'a.name'))) . ' ' . $db->escape($this->getState('list.direction', 'ASC')));


        return $query;

    }



    /**
     * Construct the date range to filter on.
     *
     * @param string $range The textual range to construct the filter for.
     *
     * @return  string  The date range to filter on.
     *
     * @since   3.6.0
     */
    private function buildDateRange($range)
    {
        // Get UTC for now.
        $dNow = new JDate;
        $dStart = clone $dNow;

        switch ($range) {
            case 'past_week':
                $dStart->modify('-7 day');
                break;

            case 'past_1month':
                $dStart->modify('-1 month');
                break;

            case 'past_3month':
                $dStart->modify('-3 month');
                break;

            case 'past_6month':
                $dStart->modify('-6 month');
                break;

            case 'post_year':
                $dNow = false;
            case 'past_year':
                $dStart->modify('-1 year');
                break;

            case 'today':
                // Ranges that need to align with local 'days' need special treatment.
                $app = JFactory::getApplication();
                $offset = $app->get('offset');

                // Reset the start time to be the beginning of today, local time.
                $dStart = new JDate('now', $offset);
                $dStart->setTime(0, 0, 0);

                // Now change the timezone back to UTC.
                $tz = new DateTimeZone('GMT');
                $dStart->setTimezone($tz);
                break;
            case 'never':
                $dNow = false;
                $dStart = $this->_db->getNullDate();
                break;
        }

        return array('dNow' => $dNow, 'dStart' => $dStart);
    }

    /**
     * SQL server change
     *
     * @param integer $user_id User identifier
     *
     * @return  string   Groups titles imploded :$
     */
    protected function _getUserDisplayedGroups($user_id)
    {
        $db = $this->getDbo();
        $query = $db->getQuery(true)
            ->select($db->qn('title'))
            ->from($db->qn('#__usergroups', 'ug'))
            ->join('LEFT', $db->qn('#__user_usergroup_map', 'map') . ' ON (ug.id = map.group_id)')
            ->where($db->qn('map.user_id') . ' = ' . (int)$user_id);

        try {
            $result = $db->setQuery($query)->loadColumn();
        } catch (RunTimeException $e) {
            $result = array();
        }

        return implode("\n", $result);
    }


}
