<?php
/**
 * @package	JoomSchool !
 * @version	1.0.0
 * @author	joomboost.com
 * @copyright	(C) 2013-2019 JoomBoost. All rights reserved.
 * @license	GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
// No direct access
use Joomla\CMS\Access\Rules;
use Joomla\Registry\Registry;

defined( '_JEXEC' ) or die( 'Restricted access' );


class TableAnnouncements extends JTable
{
	/**
	 * Primary Key
	 *
	 * @var int
	 */
	var $id = null;

	
	/**
	 * Constructor
	 *
	 * @param object Database connector object
	 */
	function __construct(& $db) {
        parent::__construct('#__joomschool_announcements', 'id', $db);
        $this->setColumnAlias('published', 'state');

    }
    public function bind($array, $ignore = '')
    {
        // Search for the {readmore} tag and split the text up accordingly.
        if (isset($array['articletext']))
        {
            $pattern = '#<hr\s+id=("|\')system-readmore("|\')\s*\/*>#i';
            $tagPos = preg_match($pattern, $array['articletext']);

            if ($tagPos == 0)
            {
                $this->introtext = $array['articletext'];
                $this->fulltext = '';
            }
            else
            {
                list ($this->introtext, $this->fulltext) = preg_split($pattern, $array['articletext'], 2);
            }
        }


        return parent::bind($array, $ignore);
    }


    /**
     * Stores a contact.
     *
     * @param   boolean  $updateNulls  True to update fields even if they are null.
     *
     * @return  boolean  True on success, false on failure.
     *
     * @since   1.6
     */
    public function store($updateNulls = false)
    {

        $date   = JFactory::getDate()->toSql();
        $userId = JFactory::getUser()->id;

        $this->modified = $date;

        if ($this->id)
        {
            // Existing item
            $this->modified_by = $userId;
        }
        else
        {
            // New contact. A contact created and created_by field can be set by the user,
            // so we don't touch either of these if they are set.
            if (!(int) $this->created)
            {
                $this->created = $date;
            }

            if (empty($this->created_by))
            {
                $this->created_by = $userId;
            }
        }


        // Set xreference to empty string if not set
        if (!$this->xreference)
        {
            $this->xreference = '';
        }



        // Verify that the alias is unique
        $table = JTable::getInstance('Announcements', 'Table', array('dbo' => $this->_db));

        if ($table->load(array('alias' => $this->alias)) && ($table->id != $this->id || $this->id == 0))
        {
            $this->setError(JText::_('COM_JOOMSCHOOL_ERROR_UNIQUE_ALIAS'));

            return false;
        }

        return parent::store($updateNulls);
    }

    /**
     * Overloaded check function
     *
     * @return  boolean  True on success, false on failure
     *
     * @see     JTable::check
     * @since   1.5
     */
    public function check()
    {



        // Check for valid name
        if (trim($this->title) == '')
        {
            $this->setError(JText::_('COM_JOOMSCHOOL_WARNING_PROVIDE_VALID_TITLE'));

            return false;
        }

        // Generate a valid alias
        $this->generateAlias();

       


        /*
         * Clean up keywords -- eliminate extra spaces between phrases
         * and cr (\r) and lf (\n) characters from string.
         * Only process if not empty.
         */
        if (!empty($this->metakey))
        {
            // Array of characters to remove.
            $badCharacters = array("\n", "\r", "\"", '<', '>');

            // Remove bad characters.
            $afterClean = StringHelper::str_ireplace($badCharacters, '', $this->metakey);

            // Create array using commas as delimiter.
            $keys = explode(',', $afterClean);
            $cleanKeys = array();

            foreach ($keys as $key)
            {
                // Ignore blank keywords.
                if (trim($key))
                {
                    $cleanKeys[] = trim($key);
                }
            }

            // Put array back together delimited by ", "
            $this->metakey = implode(', ', $cleanKeys);
        }

        // Clean up description -- eliminate quotes and <> brackets
        if (!empty($this->metadesc))
        {
            // Only process if not empty
            $badCharacters = array("\"", '<', '>');
            $this->metadesc = StringHelper::str_ireplace($badCharacters, '', $this->metadesc);
        }

        return true;
    }

    /**
     * Generate a valid alias from title / date.
     * Remains public to be able to check for duplicated alias before saving
     *
     * @return  string
     */
    public function generateAlias()
    {
        if (empty($this->alias))
        {
            $this->alias = $this->title;
        }

        $this->alias = JApplicationHelper::stringURLSafe($this->alias, $this->language);

        if (trim(str_replace('-', '', $this->alias)) == '')
        {
            $this->alias = JFactory::getDate()->format('Y-m-d-H-i-s');
        }

        return $this->alias;
    }
}