<?php
/**
 * @package     Joomla.Administrator
 * @subpackage  com_content
 *
 * @copyright   Copyright (C) 2005 - 2020 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

use Joomla\Registry\Registry;

// Include the component HTML helpers.
JHtml::addIncludePath(JPATH_COMPONENT . '/helpers/html');

JHtml::_('behavior.formvalidator');
JHtml::_('behavior.keepalive');
JHtml::_('formbehavior.chosen', 'select');

$this->configFieldsets  = array('editorConfig');
$this->hiddenFieldsets  = array('basic-limited');
$this->ignore_fieldsets = array('jmetadata', 'item_associations');

// Create shortcut to parameters.
$params = clone $this->state->get('params');
//$params->merge(new Registry($this->item->attribs));

$app = JFactory::getApplication();
$input = $app->input;

$assoc = JLanguageAssociations::isEnabled();

JFactory::getDocument()->addScriptDeclaration('
	Joomla.submitbutton = function(task)
	{
		if (task == "student.cancel" || document.formvalidator.isValid(document.getElementById("item-form")))
		{
			jQuery("#permissions-sliders select").attr("disabled", "disabled");
		
			Joomla.submitform(task, document.getElementById("item-form"));

			// @deprecated 4.0  The following js is not needed since 3.7.0.
			if (task !== "student.apply")
			{
				window.parent.jQuery("#studentEdit' . (int) $this->item->id . 'Modal").modal("hide");
			}
		}
	};
');

// In case of modal
$isModal = $input->get('layout') == 'modal' ? true : false;
$layout  = $isModal ? 'modal' : 'edit';
$tmpl    = $isModal || $input->get('tmpl', '', 'cmd') === 'component' ? '&tmpl=component' : '';
$id = $input->getInt('id',0);
$user_id = $id ? JoomSchoolHelper::getStudentNameByID($id)->user_id : '';
$name =  $id ? JFactory::getUser($user_id)->name : '';


$field_name = JoomschoolHelper::buildField(JText::_('LABEL_STUDENT_NAME'),'input', 'name',$name , '','','required');

?>

    <form action="<?php echo JRoute::_('index.php?option=com_joomschool&layout=' . $layout . $tmpl . '&id=' . (int) $this->item->id); ?>" method="post" name="adminForm" id="item-form" class="form-validate" enctype="multipart/form-data">
        <div class="form-horizontal">
            <?php echo JHtml::_('bootstrap.startTabSet', 'myTab', array('active' => 'profile')); ?>


            <?php echo JHtml::_('bootstrap.addTab', 'myTab', 'account', JText::_('TAB_STUDENT_ACCOUNT_DETAILS')); ?>
            <?php  echo  $this->form->renderFieldset('account') ?>
            <?php echo JHtml::_('bootstrap.endTab'); ?>


            <?php // Do not show the images and links options if the edit form is configured not to. ?>
                <?php echo JHtml::_('bootstrap.addTab', 'myTab', 'profile', JText::_('TAB_STUDENT_PROFILE')); ?>
            <div class="row-fluid">
                <div class="span9">
                    <fieldset class="adminform">
                        <?php  echo  $this->form->renderFieldset('profile') ?>
                        <?php echo $field_name; ?>
                        <?php
				                      //Field Builder
				                      $sid = JoomschoolHelper::getFieldSectionID('student');
				                      $fields = JoomschoolHelper::getFieldList($sid);
				                      $total_field = count($fields);
				                      $f=0;
				                      foreach($fields as $field){
				                      $f++;
				                      $fid = $field->id;
				                      $sid = $sid;
				                      $panel_id = $this->item->id;
				                      echo JoomschoolHelper::fieldshow($fid, $sid, $panel_id, $field->field_name,$field->type ,$field->required);
				                      }
                        ?>

                    </fieldset>
                </div>
                <div class="span3">
                    <?php echo JLayoutHelper::render('joomla.edit.global', $this); ?>
                </div>
            </div>
                <?php echo JHtml::_('bootstrap.endTab'); ?>

            <?php echo JHtml::_('bootstrap.addTab', 'myTab', 'academic', JText::_('TAB_STUDENT_ACADEMIC_INFO')); ?>
            <?php  echo  $this->form->renderFieldset('academic') ?>
            <?php echo JHtml::_('bootstrap.endTab'); ?>

            <?php echo JHtml::_('bootstrap.addTab', 'myTab', 'photo', JText::_('TAB_STUDENT_PHOTO')); ?>
            <?php  echo  $this->form->renderFieldset('photo') ?>
            <div class="thumbnail" style="max-width: 200px">
                <img alt="<?php echo $this->item->photo ?>" src="<?php echo $this->item->photo ;?>" />
            </div>
            <?php echo JHtml::_('bootstrap.endTab'); ?>
            <?php // echo JLayoutHelper::render('joomla.edit.params', $this); ?>


                <?php echo JHtml::_('bootstrap.addTab', 'myTab', 'publishing', JText::_('COM_JOOMSCHOOL_FIELDSET_PUBLISHING')); ?>
                <div class="row-fluid form-horizontal-desktop">
                    <div class="span6">
                        <?php echo JLayoutHelper::render('joomla.edit.publishingdata', $this); ?>
                    </div>
                    <div class="span6">
                        <?php echo JLayoutHelper::render('joomla.edit.metadata', $this); ?>
                    </div>
                </div>
                <?php echo JHtml::_('bootstrap.endTab'); ?>

            <?php echo JHtml::_('bootstrap.endTabSet'); ?>

            <input type="hidden" name="task" value="" />
            <input type="hidden" name="return" value="<?php echo $input->get('return', null, 'BASE64'); ?>" />
            <input type="hidden" name="forcedLanguage" value="<?php echo $input->get('forcedLanguage', '', 'cmd'); ?>" />
            <?php echo JHtml::_('form.token'); ?>
        </div>
    </form>


<script>
    jQuery(document).ready(function ($) {
        $("#jform_user_id_name").removeAttr('required aria-required aria-invalid').removeClass('required');
        $("input[name='jform[create_user]']").click(function () {
            if ($(this).val() == 1) {
                $(".requiredFieldUser").removeAttr('required aria-required aria-invalid').removeClass('required  validate-email');

                $("#jform_password-lbl").removeClass('required');
                $("#jform_email-lbl").removeClass('required');
                $("#jform_user_id_name").attr('required', 'required').attr('aria-required', 'true').attr('aria-invalid', 'true').addClass('required');
            } else {
                $(".requiredFieldUser").attr('required', 'required').attr('aria-required', 'true').attr('aria-invalid', 'true').addClass('required');
                $("#jform_password-lbl").addClass('required');
                $("#jform_email-lbl").addClass('required');

                $("#jform_user_id_name").removeAttr('required aria-required aria-invalid').removeClass('required');

            }
        });
    });
</script>
