<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;

JLoader::register('JoomschoolControllerAnnouncement', JPATH_ADMINISTRATOR . '/components/com_joomschool/controllers/announcement.php');

class JoomschoolControllerAnnounce extends JControllerForm
{

    /**
     * Gets the URL arguments to append to an item redirect.
     *
     * @param integer $recordId The primary key id for the item.
     * @param string $urlVar The name of the URL variable for the id.
     *
     * @return  string    The arguments to append to the redirect URL.
     *
     * @since   1.6
     */

    /**
     * The URL view item variable.
     *
     * @var    string
     * @since  1.6
     */
    protected $view_item = 'announce';

    /**
     * The URL view list variable.
     *
     * @var    string
     * @since  1.6
     */
    protected $view_list = 'announcements';


    public function sendNotification()
    {

        // tocken check
        $this->checkToken('get');

        // some inits
        $app = JFactory::getApplication();
        $announceId = $app->input->get('id', 0, 'int');
        $itemId = $app->input->get('Itemid',0,'int');


        // if announce id doesn't exist don't continue
        if (!$announceId) {
            $app->enqueueMessage('Invalid announce ID', 'warning');
            $redirect_link = JRoute::_('index.php?option=com_joomschool&iew=announcements&Itemid='.$itemId);
            $app->redirect($redirect_link);
        }

        // check if teacher logged, and is teacher , if not don't continue !
        if (!in_array(JoomschoolHelperFrontend::checkGroup(JFactory::getUser()->id), ['Teachers'])) {
            $mge = JText::_('COM_JOOMSCHOOL_MESSAGE_AREA_NOT_ALOW');
            $app->enqueueMessage($mge, 'warning');
            $redirect_link = JRoute::_('index.php?option=com_users&amp;view=login&Itemid='.$itemId);
            $app->redirect($redirect_link);
        }

        // get announce item , and make sure announce exist in database
        $announceModel = $this->getModel('Announce', 'JoomschoolModel');
        $announceModel->setState('announce.id', $announceId);
        $announce = $announceModel->getItem();


        // make sure current announce is published
        if ($announce->state != 1) {
            $app->enqueueMessage('Invalid announce state', 'warning');
            $redirect_link = JRoute::_('index.php?option=com_joomschool&view=announcements&Itemid='.$itemId);
            $app->redirect($redirect_link);
        }

        // check current teacher is owner of this announce
        $announceUserId = JoomschoolHelperUser::getUserId($announce->teacher_id, 'teachers');
        if ($announceUserId != JFactory::getUser()->id) {
            $app->enqueueMessage('Invalid announce owner', 'warning');
            $redirect_link = JRoute::_('index.php?option=com_joomschool&view=announcements&Itemid='.$itemId);
            $app->redirect($redirect_link);
        }

        // get students in selected classes
        $students = JoomschoolHelperUser::getStudentsInClasses($announce->class_id);

        // if class has no students no need to continue;
        if (count($students) == 0) {
            $app->enqueueMessage('Classes has no students', 'warning');
            $redirect_link = JRoute::_('index.php?option=com_joomschool&view=announcements&Itemid='.$itemId);
            $app->redirect($redirect_link);
        }


        foreach ($students as $student) {

            // prepare data for notification
            $data = [
                'fromUser' => JFactory::getUser()->id,
                'toUser' => $student->user_id,
                'announceLink' => JUri::root().'index.php?option=com_joomschool&view=announce&id='.$announce->id.'&Itemid='.$itemId,
                'announceTitle' => $announce->title
            ];

            // send mail notification
            JoomschoolHelperNotification::newAnnouncement($data);
        }


        $app->enqueueMessage(JText::_('COM_JOOMSCHOOL_NOTIFICATION_SENT_SUCCESSFULLY_TO_STUDENTS'), 'success');
        $redirect_link = JRoute::_('index.php?option=com_joomschool&view=announcements&Itemid='.$itemId);
        $app->redirect($redirect_link);

        return true;


    }


}
