<?php
/**
 * @package	JoomSchool !
 * @version	1.0.0
 * @author	joomboost.com
 * @copyright	(C) 2013-2019 JoomBoost. All rights reserved.
 * @license	GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;

JLoader::register('JoomschoolControllerAnnouncement', JPATH_ADMINISTRATOR . '/components/com_joomschool/controllers/announcement.php');

class JoomschoolControllerAnnouncementform extends JoomschoolControllerAnnouncement
{

    /**
     * Gets the URL arguments to append to an item redirect.
     *
     * @param   integer  $recordId  The primary key id for the item.
     * @param   string   $urlVar    The name of the URL variable for the id.
     *
     * @return  string	The arguments to append to the redirect URL.
     *
     * @since   1.6
     */

    /**
     * The URL view item variable.
     *
     * @var    string
     * @since  1.6
     */
    protected $view_item = 'announcementform';

    /**
     * The URL view list variable.
     *
     * @var    string
     * @since  1.6
     */
    protected $view_list = 'announcements';


    /**
     * Method to add a new record.
     *
     * @return  mixed  True if the record can be added, an error object if not.
     *
     * @since   1.6
     */

    public function __construct($config = array(), MVCFactoryInterface $factory = null)
    {

        // clear return for logged users
        if(!JFactory::getUser()->guest){
            JFactory::getApplication()->input->set('return',null);
        }


        parent::__construct($config, $factory);
    }

    protected function allowAdd($data = array())
    {

        $group  = JoomschoolHelperFrontend::checkGroup(JFactory::getUser()->id);

        return $group != 'Teachers' ? false : true;


    }


    protected function allowEdit($data = array(), $key = 'id')
    {
        $group  = JoomschoolHelperFrontend::checkGroup(JFactory::getUser()->id);
        return $group != 'Teachers' ? false : true;
    }


    public function add()
    {
        if (!parent::add())
        {
            // Redirect to the return page.
            $this->setRedirect($this->getReturnPage());

            return;
        }


        // Redirect to the edit screen.
        $this->setRedirect(
            JRoute::_(
                'index.php?option=' . $this->option . '&view=' . $this->view_item . '&layout=edit&id=0'
                . $this->getRedirectToItemAppend(), false
            )
        );

        return true;
    }



    protected function getRedirectToItemAppend($recordId = null, $urlVar = 'id')
    {

        // Need to override the parent method completely.
        $tmpl   = $this->input->get('tmpl');


        $append = '';

        // Setup redirect info.
        if ($tmpl)
        {
            $append .= '&tmpl=' . $tmpl;
        }

        // TODO This is a bandaid, not a long term solution.


        $append .= '&layout=edit';

        if ($recordId)
        {
            $append .= '&' . $urlVar . '=' . $recordId;
        }

        $itemId = $this->input->getInt('Itemid');
        $return = $this->getReturnPage();


        if ($itemId)
        {
            $append .= '&Itemid=' . $itemId;
        }


        if ($return)
        {
            $append .= '&return=' . base64_encode($return);
        }

        return $append;
    }

    /**
     * Get the return URL.
     *
     * If a "return" variable has been passed in the request
     *
     * @return  string	The return URL.
     *
     * @since   1.6
     */
    protected function getReturnPage()
    {
        $return = $this->input->get('return', null, 'base64');


        if (empty($return) || !JUri::isInternal(base64_decode($return)))
        {
            return JUri::base();
        }
        else
        {
            return base64_decode($return);
        }
    }

    /**
     * Method to edit an existing record.
     *
     * @param   string  $key     The name of the primary key of the URL variable.
     * @param   string  $urlVar  The name of the URL variable if different from the primary key
     * (sometimes required to avoid router collisions).
     *
     * @return  boolean  True if access level check and checkout passes, false otherwise.
     *
     * @since   1.6
     */
    public function edit($key = null, $urlVar = 'id')
    {
        $result = parent::edit($key, $urlVar);

        if (!$result)
        {
            $this->setRedirect(JRoute::_($this->getReturnPage(), false));
        }

        return $result;
    }

    public function allowSave($data, $key = 'id')
    {
        // cuz is teacher always allowed to edit his own attendance
        return true;
    }




}
