<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;

use Joomla\Registry\Registry;
use Joomla\Utilities\IpHelper;

/**
 * Content Component Article Model
 *
 * @since  1.5
 */
class JoomschoolModelAnnounce extends JModelItem
{
	/**
	 * Model context string.
	 *
	 * @var        string
	 */
	protected $_context = 'com_joomschool.announce';

	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @since   1.6
	 *
	 * @return void
	 */
	protected function populateState()
	{
		$app = JFactory::getApplication('site');

		// Load state from the request.
		$pk = $app->input->getInt('id');
		$this->setState('announce.id', $pk);

		$offset = $app->input->getUInt('limitstart');
		$this->setState('list.offset', $offset);

		// Load the parameters.
		$params = $app->getParams();
		$this->setState('params', $params);

		$user = JFactory::getUser();

		// If $pk is set then authorise on complete asset, else on component only
		$asset = empty($pk) ? 'com_joomschool' : 'com_joomschool.announce.' . $pk;

		if ((!$user->authorise('core.edit.state', $asset)) && (!$user->authorise('core.edit', $asset)))
		{
			$this->setState('filter.published', 1);
			$this->setState('filter.archived', 2);
		}

		$this->setState('filter.language', JLanguageMultilang::isEnabled());
	}

	/**
	 * Method to get article data.
	 *
	 * @param   integer  $pk  The id of the article.
	 *
	 * @return  object|boolean|JException  Menu item data object on success, boolean false or JException instance on error
	 */
	public function getItem($pk = null)
	{
		$user = JFactory::getUser();

		$pk = (!empty($pk)) ? $pk : (int) $this->getState('announce.id');



		if ($this->_item === null)
		{
			$this->_item = array();
		}

		if (!isset($this->_item[$pk]))
		{
			try
			{


				$db = $this->getDbo();
				$query = $db->getQuery(true)
					->select(
                        $this->getState(
                            'list.select',
                            'a.id, a.title, a.alias, a.image, a.checked_out, a.checked_out_time, a.introtext, a.fulltext, a.teacher_id, a.class_id' .
                            ', a.state,a.metadata, a.access, a.created, a.created_by, a.created_by_alias, a.modified, a.ordering'
                        )
                    );
                // Join over the announcementsr.
                $query->from('#__joomschool_announcements AS a');

                // Join over the users for the checked out user.
                $query->select('uc.name AS editor')
                    ->join('LEFT', '#__users AS uc ON uc.id=a.checked_out');

                // Join over the asset groups.
                $query->select('ag.title AS access_level')
                    ->join('LEFT', '#__viewlevels AS ag ON ag.id = a.access');


                // Join over the users for the author.
                $query->select('ua.name AS author_name')
                    ->join('LEFT', '#__users AS ua ON ua.id = a.created_by');



                // Filter by access level.
                $access = $this->getState('filter.access');

                if (is_numeric($access))
                {
                    $query->where('a.access = ' . (int) $access);
                }
                elseif (is_array($access))
                {
                    $access = ArrayHelper::toInteger($access);
                    $access = implode(',', $access);
                    $query->where('a.access IN (' . $access . ')');
                }


                $query->where('a.state = 1');

                $query->where('a.id = '.$pk);

				$db->setQuery($query);

				$data = $db->loadObject();

				if (empty($data))
				{
					return JError::raiseError(404, JText::_('COM_JOOMSCHOOL_ERROR_ANNOUNCE_NOT_FOUND'));
				}


				//$data->params = clone $this->getState('params',[]);

				$data->metadata = new Registry($data->metadata);

                $this->_item[$pk] = $data;
			}
			catch (Exception $e)
			{
				if ($e->getCode() == 404)
				{
					// Need to go thru the error handler to allow Redirect to work.
					JError::raiseError(404, $e->getMessage());
				}
				else
				{
					$this->setError($e);
					$this->_item[$pk] = false;
				}
			}
		}


		return $this->_item[$pk];
	}


	/**
	 * Cleans the cache of com_joomschool and content modules
	 *
	 * @param   string   $group     The cache group
	 * @param   integer  $clientId  The ID of the client
	 *
	 * @return  void
	 *
	 * @since   3.9.9
	 */
	protected function cleanCache($group = null, $clientId = 0)
	{
		parent::cleanCache('com_joomschool');

	}
}
