<?php
/**
 * @package	JoomSchool !
 * @version	1.0.0
 * @author	joomboost.com
 * @copyright	(C) 2013-2019 JoomBoost. All rights reserved.
 * @license	GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;

// import the Joomla modellist library
jimport('joomla.application.component.modellist');

class JoomschoolModelAttendances extends JModelList
{

    public function __construct($config = array())
    {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                'id','a.id',
                'attendance_date', 'a.attendance_date',
                'class', 'a.class',
                'section',' a.section',
                'total_student',' a.total_student',
                'teacher', 'a.teacher',
                'create_date', 'a.create_date',
                'update_date', 'a.update_date'

            );
        }

        parent::__construct($config);
    }



    protected function populateState($ordering = 'a.id', $direction = 'asc')
    {
        $app = JFactory::getApplication('administrator');

        // Adjust the context to support modal layouts.
        if ($layout = $app->input->get('layout', 'default', 'cmd')) {
            $this->context .= '.' . $layout;
        }

        // Load the filter state.
        $this->setState('filter.section', $this->getUserStateFromRequest($this->context . '.filter.section', 'filter_section', '', 'string'));
        $this->setState('filter.class', $this->getUserStateFromRequest($this->context . '.filter.class', 'filter_class', '', 'string'));

        $this->setState('filter.search', $this->getUserStateFromRequest($this->context . '.filter.search', 'filter_search', '', 'string'));
        $this->setState('filter.active', $this->getUserStateFromRequest($this->context . '.filter.active', 'filter_active', '', 'cmd'));
        $this->setState('filter.state', $this->getUserStateFromRequest($this->context . '.filter.state', 'filter_state', '', 'cmd'));
        $this->setState('filter.group_id', $this->getUserStateFromRequest($this->context . '.filter.group_id', 'filter_group_id', null, 'int'));
        $this->setState('filter.range', $this->getUserStateFromRequest($this->context . '.filter.range', 'filter_range', '', 'cmd'));
        $this->setState(
            'filter.lastvisitrange', $this->getUserStateFromRequest($this->context . '.filter.lastvisitrange', 'filter_lastvisitrange', '', 'cmd')
        );

        $groups = json_decode(base64_decode($app->input->get('groups', '', 'BASE64')));

        if (isset($groups)) {
            $groups = ArrayHelper::toInteger($groups);
        }

        $this->setState('filter.groups', $groups);

        $excluded = json_decode(base64_decode($app->input->get('excluded', '', 'BASE64')));

        if (isset($excluded)) {
            $excluded = ArrayHelper::toInteger($excluded);
        }

        $this->setState('filter.excluded', $excluded);

        // Load the parameters.
        $params = JComponentHelper::getParams('com_joomschool');
        $this->setState('params', $params);

        // List state information.
        parent::populateState($ordering, $direction);
    }

    /**
     ** Attantdance List
     **/

    protected function getListQuery()
    {
        // Inits
        $db = $this->getDbo();
        $query = $db->getQuery(true);
        $input = JFactory::getApplication()->input;
        $userid = \Joomla\CMS\Factory::getUser()->id;


        // Select the required fields from the table.
        $query->select(
            $this->getState(
                'list.select',
                'DISTINCT a.id, a.attendance_date, a.class, a.section, a.total_student, a.teacher, a.create_date, a.update_date'
            )
        );
        $query->from('#__joomschool_attendance AS a');

        $query->where('a.teacher = ' . $db->quote($userid));


        // Filter by Class.
        $classId = $this->getState('filter.class_id');
        if (is_numeric($classId)) {
            $query->where('a.class = ' . $db->quote($classId));
        }

        // Filter by Section.
        $sectionId = $this->getState('filter.section_id');
        if (is_numeric($sectionId)) {
            $query->where('a.section = ' . $db->quote($sectionId));
        }

        // Filter by search in title.
        $search = $this->getState('filter.search');

        if (!empty($search)) {

            $search = $db->quote('%' . str_replace(' ', '%', $db->escape(trim($search), true) . '%'));
            $query->where('(a.attendance_date LIKE ' . $search . ' )');

        }



        // Add the list ordering clause.
        $query->order($db->qn($db->escape($this->getState('list.ordering', 'a.id'))) . ' ' . $db->escape($this->getState('list.direction', 'ASC')));

        return $query;

    }


    /**
	** Get Class Name
	**/
	function getClassname($id){
		$data = JoomschoolHelperFrontend::selectSingleData('class_name', 'joomschool_class', 'id', $id);
	    return $data;
	}
	
	
	
	/**
	** Get Teacher Name
	**/
	function getTeachername($id){
		$data = JoomschoolHelperFrontend::selectSingleData('name', 'users', 'id', $id);
	    return $data;
	}
	
	/**
	** Get Section Name
	**/
	function getSectionname($id){
		$data = JoomschoolHelperFrontend::selectSingleData('section_name', 'joomschool_sections', 'id', $id);
	    return $data;
	}
	
	/**
	** Get Old Attendance Info Data
	**/
	function getOldatt($aid, $student_id){
	    $db = JFactory::getDBO();
		$query = $db->getQuery(true);
		$query
            ->select($db->quoteName(array('attend')))
            ->from($db->quoteName('#__joomschool_attendance_info'))
            ->where($db->quoteName('attendance_id') . ' = '. $db->quote($aid))
			->where($db->quoteName('student_id') . ' = '. $db->quote($student_id));
		$db->setQuery($query);
		$data = $db->loadResult();
		return $data;
	}
	
	
	/**
	** Student  List
	**/
	function getStudentList($class, $section){
	    $db = JFactory::getDBO();
	    $query = $db->getQuery(true);
		$query
            ->select('*')
            ->from($db->quoteName('#__joomschool_students'))
            ->where($db->quoteName('class') . ' = '. $db->quote($class))
			->where($db->quoteName('section') . ' = '. $db->quote($section))
            ->order('roll ASC');
        $db->setQuery($query);
        $rows = $db->loadObjectList();
       return $rows;
	}
	
	/**
	** Get Total Present
	**/
	function totalPresent($aid){
	     $db = JFactory::getDBO();
			 $query = $db->getQuery(true);
				$query
             ->select('*')
             ->from($db->quoteName('#__joomschool_attendance_info'))
             ->where($db->quoteName('attendance_id') . ' = '. $db->quote($aid))
						 ->where($db->quoteName('attend') . ' = '. $db->quote('1'))
             ->order('id ASC');
        $db->setQuery($query);
        $rows = $db->loadObjectList();
       return $rows;
	}
	
	/**
	** Get Total Absent
	**/
	function totalAbsent($aid){
	     $db = JFactory::getDBO();
			 $query = $db->getQuery(true);
				$query
             ->select('*')
             ->from($db->quoteName('#__joomschool_attendance_info'))
             ->where($db->quoteName('attendance_id') . ' = '. $db->quote($aid))
						 ->where($db->quoteName('attend') . ' = '. $db->quote('0'))
             ->order('id ASC');
			 
        $db->setQuery($query);
        $rows = $db->loadObjectList();
       return $rows;
	}
	
	/**
	** Class List
	**/
	function getclassList($id){
	    $db = JFactory::getDBO();
		$query = $db->getQuery(true);
		$query
             ->select($db->quoteName(array('id', 'class_name')))
             ->from($db->quoteName('#__joomschool_class'))
             ->where($db->quoteName('published') . ' = '. $db->quote('1'))
             ->order('id ASC');
				
        $db->setQuery($query);
        $rows = $db->loadObjectList();
        if ($db->getErrorNum()) {
            echo $db->stderr();
            return false;
        }



        // get user
        $user		= JFactory::getUser();
        $userid = $user->get( 'id' ); 
        $class_data = JoomschoolHelperFrontend::selectSingleData('class', 'joomschool_teachers', 'user_id', $userid);
        $class = explode(",", $class_data);


        $class_array = array();
        $class_array[] = array('value' => '', 'text' => JText::_(' -- Select Class -- '));
        foreach ($rows as $key=>$row) {
            if(in_array($row->id, $class))
            {
            $class_array[] = array('value' => $row->id, 'text' => JText::_(' '.$row->class_name));
            }else{
               	unset( $rows[ $key ] ); 
            }
        }
	    $class =  JHTML::_('select.genericList', $class_array, 'class', ' class="required  inputbox  "   ', 'value', 'text', $id);
        return $class;
	}
	
	/**
	** Section List
	**/
	function getsectionList($id){
	    $db = JFactory::getDBO();
		$query = $db->getQuery(true);
		$query
             ->select($db->quoteName(array('id', 'section_name')))
             ->from($db->quoteName('#__joomschool_sections'))
             ->where($db->quoteName('published') . ' = '. $db->quote('1'))
             ->order('id ASC');
			 
        $db->setQuery($query);
        $rows = $db->loadObjectList();
        if ($db->getErrorNum()) {
            echo $db->stderr();
            return false;
        }

        // get user
        $user		= JFactory::getUser();
        $userid = $user->get( 'id' ); 
        $section_data = JoomschoolHelperFrontend::selectSingleData('section', 'joomschool_teachers', 'user_id', $userid);
        $section = explode(",", $section_data);


        $sections = array();
        $sections[] = array('value' => '', 'text' => JText::_(' -- Select Section -- '));
        foreach ($rows as $key=>$row) {
            if(in_array($row->id, $section))
            {
            $sections[] = array('value' => $row->id, 'text' => JText::_(' '.$row->section_name));
            }else{
               	unset( $rows[ $key ] ); 
            }
        }
		$section =  JHTML::_('select.genericList', $sections, 'section', 'class=" required inputbox  " required="required" ', 'value', 'text', $id);
        return $section;
	}
	
	/**
	** Get Attendance 
	**/
	function getAttendance($id){
	    if ($id) {
			$this->_id = $id;
		}
		if (empty($this->_data)) {
		    $this->_data = $this->getTable ('attendance');
		    $this->_data->load ($this->_id);
		}
		return $this->_data;
	}

	/**
	** Save Attendance
	**/
	function saveattend($aid, $user_id, $date, $class, $section){
	    $db    = JFactory::getDbo();
		    

		$user		= JFactory::getUser();
	    $user_id = $user->id;
				
		// Student List
		$query_students = $db->getQuery(true);
	    $query_students
            ->select('*')
            ->from($db->quoteName('#__joomschool_students'))
            ->where($db->quoteName('class') . ' = '. $db->quote($class))
			->where($db->quoteName('section') . ' = '. $db->quote($section))
            ->order('roll ASC');
        $db->setQuery($query_students);
        $student_rows = $db->loadObjectList();
		$total_student = count($student_rows);
		
	    $table = $this->getTable('attendance');
		$data = JRequest::get( 'post' );
		// Bind the data.
		if (!$table->bind($data))
		{
			$this->setError($user->getError());
			return false;
		}
		// Store the data.
		if($aid){ // existing item
            $table->id = $aid;
            $table->update_date = JFactory::getDate()->toSql();
        }else{ // new item
            $table->create_date = JFactory::getDate()->toSql();
        }
		$table->teacher = $user_id;
		$table->attendance_date = $date;
		$table->class = $class;
		$table->section = $section;
		$table->total_student = $total_student;


		if (!$table->store())
		{
			$this->setError($user->getError());
			return false;
		}
		$id = $table->id;
		
		    //Save to attendance info
			if(!empty($total_student) && empty($aid)){
		        foreach($student_rows as $student){
				    $table_info = $this->getTable('attendanceinfo');
					$table_info->attendance_id = $id;
		            $table_info->student_id = $student->id;
		            $table_info->attend = 0;
					$table_info->entry_by = $user_id;
					$table_info->create_date = JFactory::getDate()->toSql();
		            if (!$table_info->store()){
			            $this->setError($user->getError());
			            return false;
		            }
				}//end foreach
			}
		
		return $id;
	 }
  
	/**
	** Save Attendance info
	**/
	function savestatus($aid, $sid, $status){

	 
	    $user		= JFactory::getUser();
	    $user_id = $user->id;

	    $table = $this->getTable('attendanceinfo');
	    
		$db = JFactory::getDBO();
	    $query_result = "SELECT id FROM `#__joomschool_attendance_info` WHERE attendance_id = '".$aid."' AND student_id = '".$sid."'";
		$db->setQuery($query_result);
		$id = $db->loadResult();
		
		$data = JRequest::get( 'post' );
		// Bind the data.
		if (!$table->bind($data))
		{
			$this->setError($user->getError());
			return false;
		}
		// Store the data.
		if(!empty($id)){$table->id = $id;}
		$table->attendance_id = $aid;
		$table->student_id = $sid;
		$table->attend = $status;
		$table->update_date = JFactory::getDate()->toSql();
		$table->entry_by = $user_id;
		if (!$table->store())
		{
			$this->setError($user->getError());
			return false;
		}
		$id = $table->id;
		return $id;
	 }
  
	

	
	
}
