<?php
/**
 * @package	JoomSchool !
 * @version	1.0.0
 * @author	joomboost.com
 * @copyright	(C) 2013-2019 JoomBoost. All rights reserved.
 * @license	GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;

// import the Joomla modellist library
jimport('joomla.application.component.modellist');
use Joomla\Registry\Registry;
use Joomla\Utilities\ArrayHelper;

// Base this model on the backend version.
JLoader::register('JoomschoolModelPayment', JPATH_ADMINISTRATOR . '/components/com_joomschool/models/payment.php');
class JoomschoolModelPaymentedit extends JoomschoolModelPayment
{
    /**
     * Model typeAlias string. Used for version history.
     *
     * @var        string
     */
    public $typeAlias = 'com_joomschool.paymentedit';

    /**
     * Method to auto-populate the model state.
     *
     * Note. Calling getState in this method will result in recursion.
     *
     * @return  void
     *
     * @since   1.6
     */
    public function populateState()
    {
        $app = JFactory::getApplication();

        // Load state from the request.
        $pk = $app->input->getInt('id');
        $this->setState('payment.id', $pk);


        $return = $app->input->get('return', null, 'base64');
        $this->setState('return_page', base64_decode($return));

        // Load the parameters.
        $params = $app->getParams();
        $this->setState('params', $params);

        $this->setState('layout', $app->input->getString('layout'));
    }

    public function getItem($pk = null)
    {

        $user = JFactory::getUser();
        $pk = $pk ? $pk : JFactory::getApplication()->input->getInt('id',0);
        $item = parent::getItem($pk);

        if(JoomschoolHelperFrontend::checkGroup($user->id) == 'Students'){
           $item->student_id = JoomschoolHelper::getStudentIDByUserID($user->id);
           $item->student_class = JoomschoolHelper::getStudentInfoUserID($user->id)->class_id;
           $item->student_section = JoomschoolHelper::getStudentInfoUserID($user->id)->section_id;
           $item->student_roll = JoomschoolHelper::getStudentInfoUserID($user->id)->roll;

       }

        return $item; // TODO: Change the autogenerated stub
    }

    /**
     * Get the return URL.
     *
     * @return  string	The return URL.
     *
     * @since   1.6
     */
    public function getReturnPage()
    {
        return base64_encode($this->getState('return_page'));
    }

    /**
     ** Get Details of history
     **/
    function history($details,$student,$year){

        //Collect Student data
        if(!empty($student->id)){$id = $student->id;}else {$id="";}
        if(!empty($student->name)){$name = $student->name;}else {$name="";}
        if(!empty($student->class)){$class = JoomschoolHelperFrontend::getClassname($student->class);}else {$class="";}
        if(!empty($student->section)){$section = JoomschoolHelperFrontend::getSectionname($student->section);}else {$section="";}
        if(!empty($student->division)){$division = JoomschoolHelperFrontend::getDivisionname($student->division);}else {$division="";}
        if(!empty($student->roll)){$roll = $student->roll;}else {$roll="";}

        //GET SCHOOLS DATA
        $app = JFactory::getApplication();
        $params = JComponentHelper::getParams('com_joomschool');
        $schools_name = $params->get('schools_name','Schools/Collage Name');
        $schools_address = $params->get('schools_address','12345 Vincent Place');
        $schools_phone = $params->get('schools_phone',123456789);
        $schools_email = $params->get('schools_email','support@joomboost.com');
        $schools_website = $params->get('schools_web','www.joomboost.com');

        $details_show = $schools_name;

        //Display Header Information
        $onclick_link ="'printableArea'";
        $header_con ='<p style="text-align: center;"><input type="button" id="print" onclick="printDiv('.$onclick_link.')" class="btn btn-small btn-sm btn-primary"  style="border: none;margin-left: 10px;" value="Print" /> </p>';
        $details_show  = '<h4 class="" style="text-align: center;margin-bottom: 3px;" >'.$schools_name.'</h4>';
        $details_show .='<p style="text-align: center;"><b>'.JText::_('LABEL_PAYMENT_HISTORY_TITLE').' - '.$year.'</b></p>';
        $details_show .= $header_con;

        //Display Student info
        $details_show .='<table  align="center"   class="" id="admin-table" style="margin-bottom: 0px;margin-top: 10px;width: 95%;border: none;" >';
        $details_show .='<tr>';
        $details_show .='<td align="left" style="border: 0px;"><b> '.JText::_('LABEL_STUDENT_NAME').': </b>'.$name.'</td>';
        $details_show .='<td align="left" style="border: 0px;"><b> '.JText::_('LABEL_STUDENT_ROLL').':</b> '.$roll.'</td>';
        $details_show .='<td align="center" style="border: 0px;"><b> '.JText::_('LABEL_STUDENT_CLASS').': </b>'.$class.'</td>';
        $details_show .='<td align="right" style="border: 0px;"><b> '.JText::_('LABEL_STUDENT_SECTION').':</b> '.$section.'</td>';
        $details_show .='<td align="right" style="border: 0px;" ><b>'.JText::_('LABEL_STUDENT_DIVISION').':</b> '.$division.'</td>';
        $details_show .='</tr>';
        $details_show .='</table>';

        $details_show .= '<table class="admin-table table table-striped" align="center"  id="admin-table" style="width: 95%;margin-top: 10px;" align="center">';
        $details_show .= '<thead>';
        $details_show .= '<tr>';
        $details_show .='<th>#</th>';
        $details_show .='<th>'.JText::_('LABEL_PAYMENT_HISTORY_MONTH').'</th>';
        $details_show .='<th>'.JText::_('LABEL_PAYMENT_HISTORY_PAYMENT_TYPE').'</th>';
        $details_show .='<th>'.JText::_('LABEL_PAYMENT_HISTORY_TOTAL_PAYMENT').'</th>';
        $details_show .='<th>'.JText::_('LABEL_PAYMENT_HISTORY_PAID_AMMOUNT').'</th>';
        $details_show .='<th>'.JText::_('LABEL_PAYMENT_HISTORY_DUE_AMMOUNT').'</th>';
        $details_show .='<th>'.JText::_('LABEL_PAYMENT_HISTORY_PAID_BY').'</th>';
        $details_show .='<th>'.JText::_('LABEL_PAYMENT_STATUS').'</th>';
        $details_show .='<th>'.JText::_('LABEL_PAYMENT_HISTORY_SUBMIT_DATE').'</th>';
        $details_show .='<th>#</th>';
        $details_show .='</tr>';
        $details_show .='</thead>';
        $details_show .='<tbody>';
        //$details_show .='</table>';
        $i=0;
        if(!empty($details)){
            //$details_show .= '<table class="admin-table" align="center"  id="admin-table" style="width: 95%;margin-top: 0px;" align="center">';
            foreach ($details as $item){
                $i++;
                $monthName = date("F", mktime(null, null, null, $item->month));
                $year = $item->year;
                $payment_type = $this->getPayammount($item->pay_for_id,'name');

                $paidby = $this->getPaidBy($item->payment_method);
                $link_invoice 		= JRoute::_( 'index.php?option=com_joomschool&view=paymentedit&layout=invoice&pdf=1&id='. $item->id );
                $status = $item->status;
                if($status=="0"){$st = '<span style="color: orange;font-weight: bold;" >'.JText::_('COM_JOOMSCHOOL_LABEL_STATUS_PENDING').'</span>';}
                if($status=="1"){$st = '<span style="color: green;font-weight: bold;" >'.JText::_('COM_JOOMSCHOOL_LABEL_STATUS_PAID').'</span>';}
                if($status=="2"){$st = '<span style="color: red;font-weight: bold;" >'.JText::_('COM_JOOMSCHOOL_LABEL_STATUS_UN_PAID').'</span>';}
                if($status=="3"){$st = '<span style="color: magenta;font-weight: bold;" >'.JText::_('COM_JOOMSCHOOL_LABEL_STATUS_CANCEL').'</span>';}
                if($status=="4"){$st = '<span style="color: mediumblue;font-weight: bold;" >'.JText::_('COM_JOOMSCHOOL_LABEL_STATUS_UNDER_REVIEW').'</span>';}

                $submit_date = date( 'Y-m-d g:i A', strtotime($item->create_date));

                $details_show .='<tr>';
                $details_show .='<td align="center">'.$i.'</td>';
                $details_show .='<td style="text-align: left;" >'.$monthName.' - '.$year.'</td>';
                $details_show .='<td style="text-align: left;" >'.$payment_type.'</td>';
                $details_show .='<td align="right">'.number_format($item->total_bill, 2).'</td>';
                $details_show .='<td align="right">'.number_format($item->paid_ammount, 2).'</td>';
                $details_show .='<td align="right">'.number_format((float) $item->due_ammount, 2).'</td>';
                $details_show .='<td align="center">'.$paidby.'</td>';
                $details_show .='<td align="center">'.$st.'</td>';
                $details_show .='<td align="center">'.$submit_date.'</td>';
                $details_show .='<td align="center"><a href="'.$link_invoice.'" class="btn btn-sm btn-primary">'.JText::_('BTN_PAYMENT_VIEW_INVOICE').'</a></td>';
                $details_show .='</tr>';
            }
        }
        $details_show .='</tbody>';
        $details_show .='</table>';
        if(empty($details)){
            $details_show .= "<p style='color: #ff0000;text-align: center;padding: 10px;'>No record found. </p>";
        }

        return  $details_show;
    }


 public function getForm($data = array(), $loadData = true)
 {

    /*
     * The front end calls this model and uses a_id to avoid id clashes so we need to check for that first.
     * The back end uses id so we use that the rest of the time and set it to 0 by default.
     */

    // Determine correct permissions to check.

    // Check for existing article.
    // Modify the form based on Edit State access controls.

     $form = parent::getForm($data, $loadData); // TODO: Change the autogenerated stub
    if (JoomschoolHelperFrontend::checkGroup(JFactory::getUser()->id) == "Students"){
        // Disable fields for display.
        $form->setFieldAttribute('student_class', 'disabled', 'true');
        $form->setFieldAttribute('student_section', 'disabled', 'true');
        $form->setFieldAttribute('student_roll', 'disabled', 'true');
        $form->setFieldAttribute('student_roll', 'required', 'false');

    }

        // Disable fields while saving.
        // The controller has already verified this is an article you can edit.
        $form->setFieldAttribute('ordering', 'filter', 'unset');
        $form->setFieldAttribute('published', 'filter', 'unset');

    return $form;



 }

}
