<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;


class JoomschoolModelPayments extends JModelList
{
    public function __construct($config = array())
    {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                'id', 'a.id',
                'mounth_id', 'a.mounth_id',
                'year', 'a.year',
                'status', 'a.status',



            );
        }

        parent::__construct($config);
    }

    /**
     * Method to auto-populate the model state.
     *
     * This method should only be called once per instantiation and is designed
     * to be called on the first call to the getState() method unless the model
     * configuration flag to ignore the request is set.
     *
     * Note. Calling getState in this method will result in recursion.
     *
     * @param string $ordering An optional ordering field.
     * @param string $direction An optional direction (asc|desc).
     *
     * @return  void
     *
     * @since   3.0.1
     */
    protected function populateState($ordering = 'a.id', $direction = 'ASC')
    {
        $app = JFactory::getApplication();


        $list = new JInput($app->input->get('list', '', 'ARRAY'));


        $month_id = $list->get('list.month_id', $app->get('list_month_id', 0), 'uint');
        $this->setState('list.month_id', $month_id);

        $children_id = $list->get('list.children_id', $app->get('list_children_id', 0), 'uint');
        $this->setState('list.children_id', $children_id);

        $year = $list->get('year', $app->get('list_year', 0), 'uint');
        $this->setState('list.year', $year);

        $status = $list->get('status', $app->get('list_status', 0), 'uint');
        $this->setState('list.status', $status);


        // List state information
        $value = $app->input->get('limit', $app->get('list_limit', 0), 'uint');
        $this->setState('list.limit', $value);

        $value = $app->input->get('limitstart', 0, 'uint');
        $this->setState('list.start', $value);


        $orderCol = $app->input->get('filter_order', 'a.id');
        $this->setState('list.ordering', $orderCol);

        $listOrder = $app->input->get('filter_order_Dir', 'ASC');

        if (!in_array(strtoupper($listOrder), array('ASC', 'DESC', ''))) {
            $listOrder = 'ASC';
        }

        $this->setState('list.direction', $listOrder);
        // Load the parameters.
        $params = JComponentHelper::getParams('com_joomschool');
        $this->setState('params', $params);

        // List state information.
        parent::populateState($ordering, $direction);


    }

    public function preprocessForm(\JForm $form, $data, $group = 'content')
    {
        //['fields'][1]['field']
        parent::preprocessForm($form, $data, $group); // TODO: Change the autogenerated stub
    }

    /**
     ** Payment List
     ***/
    protected function getListQuery()
    {
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select(
            $this->getState(
                'list.select',
                'DISTINCT a.id,a.student_id,a.student_roll, u.name,c.class_name,s.section_name,a.month, a.year, p.name as payment_method,a.pay_for_id,a.total_bill,a.paid_ammount,a.due_ammount,a.status,a.create_date'
            )
        );
        $query->from('#__joomschool_payments AS a');
        $query->join('LEFT', '#__joomschool_students AS st ON st.id = a.student_id');

        $query->join('LEFT', '#__users AS u ON u.id = st.user_id');
        $query->join('LEFT', '#__joomschool_sections AS s ON s.id = a.student_section');
        $query->join('LEFT', '#__joomschool_class AS c ON c.id = a.student_class');

        $query->join('LEFT', '#__joomschool_pay_method AS p ON p.id = a.payment_method');


        if (JoomschoolHelperFrontend::checkGroup(JFactory::getUser()->id) == 'Students') {
            $query->where('a.student_id = ' . JoomschoolHelper::getStudentIDByUserID(JFactory::getUser()->id));
        }
        $children_id = $this->getState('list.children_id');


        if (JoomschoolHelperFrontend::checkGroup(JFactory::getUser()->id) == 'Parents') {
            if ($children_id){
                $query->where('a.student_id = ' . $children_id);
            }else{
                $childrens = $this->getChildrens();
            $query->where('a.student_id IN (' . $childrens . ')');
            }
        }


        // Filter by Status.
        $status = $this->getState('list.status');

        if (!empty($status) && is_numeric($status)) {
            $query->where('a.status = ' . $db->quote($status));
        }

        $year = $this->getState('list.year');

        if (!empty($year) && is_numeric($year) ) {
            $query->where('a.year = ' . $db->quote(JoomschoolHelper::getYearById($year)));
        }

        // Filter by Month.
        $monthId = $this->getState('list.month_id');

        if (!empty($monthId) && is_numeric($monthId)) {
            $query->where('a.month = ' . $db->quote($monthId));
        }


        $query->order($this->getState('list.ordering', 'a.id') . ' ' . $this->getState('list.direction', 'ASC'));

        return $query;
    }

    public function getChildrens(){
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $user = JFactory::getUser();

        $query->select('p.student_id');
        $query->from('`#__joomschool_parents` AS p');
        $query->where("p.user_id = $user->id");

        $db->setQuery($query);

        return $db->loadResult();
    }

    /**
     ** Parent student List
     **/
    function getStudentList($pid)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('id', 'roll', 'user_id')))
            ->from($db->quoteName('#__joomschool_students'))
            ->order('id ASC');

        $db->setQuery($query);
        $rows = $db->loadObjectList();
        if ($db->getErrorNum()) {
            echo $db->stderr();
            return false;
        }


        // get
        $student_data = JoomschoolHelperFrontend::selectSingleData('student_id', 'joomschool_parents', 'id', $pid);
        $student_ids = explode(",", $student_data);


        $student_array = array();
        $student_array[] = array('value' => '', 'text' => JText::_(' -- Select Student -- '));
        foreach ($rows as $key => $row) {
            if (in_array($row->id, $student_ids)) {
                $student_array[] = array('value' => $row->roll, 'text' => JText::_(' ' . JFactory::getUser($row->user_id)->name));
            } else {
                unset($rows[$key]);
            }
        }
        $student_list = JHTML::_('select.genericList', $student_array, 'student_roll', ' class="required  inputbox  "   ', 'value', 'text', '');
        return $student_list;
    }


    function getStudentID($id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('id')))
            ->from($db->quoteName('#__joomschool_students'))
            ->where($db->quoteName('user_id') . ' = ' . $db->quote($id));
        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }

    function getDivisionname($id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('division_name')))
            ->from($db->quoteName('#__joomschool_division'))
            ->where($db->quoteName('id') . ' = ' . $db->quote($id));
        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }

    function getClassname($id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('class_name')))
            ->from($db->quoteName('#__joomschool_class'))
            ->where($db->quoteName('id') . ' = ' . $db->quote($id));

        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }

    function getSectionIDS($id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('section')))
            ->from($db->quoteName('#__joomschool_class'))
            ->where($db->quoteName('id') . ' = ' . $db->quote($id));

        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }

    function getuserID($roll, $student_class, $student_section)
    {
        $db = JFactory::getDBO();

        $query_result = $db->getQuery(true);
        $query_result
            ->select($db->quoteName(array('id')))
            ->from($db->quoteName('#__joomschool_students'))
            ->where($db->quoteName('class_id') . ' = ' . $db->quote($student_class))
            ->where($db->quoteName('section_id') . ' = ' . $db->quote($student_section))
            ->where($db->quoteName('roll') . ' = ' . $db->quote($roll));

        $db->setQuery($query_result);
        $data = $db->loadResult();
        return $data;
    }


    function getStudentname($roll)
    {
        $db = JFactory::getDBO();

        $query_result = $db->getQuery(true);
        $query_result
            ->select($db->quoteName(array('user_id')))
            ->from($db->quoteName('#__joomschool_students'))
            ->where($db->quoteName('roll') . ' = ' . $db->quote($roll));

        $db->setQuery($query_result);
        $data = $db->loadResult();
        return $data;
    }

    function getSectionname($id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('section_name')))
            ->from($db->quoteName('#__joomschool_sections'))
            ->where($db->quoteName('id') . ' = ' . $db->quote($id));
        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }

    // Pay Ammount
    function getPayammount($id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('fee')))
            ->from($db->quoteName('#__joomschool_pay_type'))
            ->where($db->quoteName('id') . ' = ' . $db->quote($id));
        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }

    // Paid By
    function getPaidBy($id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('name')))
            ->from($db->quoteName('#__joomschool_pay_method'))
            ->where($db->quoteName('id') . ' = ' . $db->quote($id));
        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }

    /**
     **  TEACHERE ID
     ***/
    function getTeacherClass($id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('class')))
            ->from($db->quoteName('#__joomschool_teachers'))
            ->where($db->quoteName('user_id') . ' = ' . $db->quote($id));
        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }


    /**
     **  STUDENT ID
     ***/
    function getStudent($id)
    {
        $student = $this->getTable('students');
        $student->load($id);
        return $student;
    }

    /**
     ** Parent Student ID
     **/
    function getParentStudentID($id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('student_id')))
            ->from($db->quoteName('#__joomschool_parents'))
            ->where($db->quoteName('user_id') . ' = ' . $db->quote($id));
        $db->setQuery($query);
        $data = $db->loadResult();
        return $data;
    }

    /**
     ** Display Payment List
     **/
    function paymentList($item_id, $status_filter, $month_filter, $year_filter, $section_filter, $roll_filder)
    {
        // Get user info
        $user = JFactory::getUser();
        $uid = $user->get('id');
        $group_title = JoomschoolHelperFrontend::checkGroup($uid);

        // Condition of teacher , student & Parent
        if (in_array(JComponentHelper::getParams('com_joomschool')->get('teachers_group', 140002), JAccess::getGroupsByUser($uid))) {
            $items = $this->getPaymentDetailsByClass($item_id, $status_filter, $month_filter, $year_filter, $section_filter, $roll_filder);
        } elseif (in_array(JComponentHelper::getParams('com_joomschool')->get('parents_group', 140003), JAccess::getGroupsByUser($uid))) {

            $items = $this->getPaymentDetails($item_id, $status_filter, $month_filter, $year_filter);


        } else {
            $items = $this->getPaymentDetails($item_id, $status_filter, $month_filter, $year_filter);
        }

        // empty message show
        if (empty($items)) {
            $payment_data = '<div class="alert alert-no-items">';
            $payment_data .= JText::_('JGLOBAL_NO_MATCHING_RESULTS');
            $payment_data .= '</div>';
        } else {

            $payment_data = '<table class="admin-table" id="admin-table" style="width: 100%;margin-top: 20px;" align="center">';
            $payment_data .= '<tr>';
            $payment_data .= '<th>#</th>';
            if (in_array(JComponentHelper::getParams('com_joomschool')->get('teachers_group', 140002), JAccess::getGroupsByUser($uid))) {
                $payment_data .= '<th>' . JText::_('LABEL_STUDENT_NAME') . '</th>';
                $payment_data .= '<th>' . JText::_('LABEL_STUDENT_ROLL') . '</th>';
            }
            $payment_data .= '<th>' . JText::_('LABEL_PAYMENT_PAY_MONTH_YEAR') . '</th>';
            $payment_data .= '<th>' . JText::_('LABEL_PAYMENT_PAY_AMMOUNT') . '</th>';
            $payment_data .= '<th>' . JText::_('LABEL_PAYMENT_PAY_BY') . '</th>';
            $payment_data .= '<th>' . JText::_('LABEL_PAYMENT_STATUS') . '</th>';
            $payment_data .= '<th>Date & Time</th>';
            $payment_data .= '<th></th>';
            $payment_data .= '<th></th>';
            $payment_data .= '</tr>';


            $i = 0;
            foreach ($items as $item) {
                $i++;
                $monthName = date("F", mktime(null, null, null, $item->month));
                $year = $item->year;
                $ammount = $this->getPayammount($item->pay_for_id);
                $uid = $item->uid;
                $student_name = $this->getStudentname($item->student_roll);
                $paidby = $this->getPaidBy($item->payment_method_id);

                $status = $item->status;
                if ($status == "0") {
                    $st = '<span style="color: orange;font-weight: bold;" >' . JText::_('COM_JOOMSCHOOL_LABEL_STATUS_PENDING') . '</span>';
                }
                if ($status == "1") {
                    $st = '<span style="color: green;font-weight: bold;" >' . JText::_('COM_JOOMSCHOOL_LABEL_STATUS_PAID') . '</span>';
                }
                if ($status == "2") {
                    $st = '<span style="color: red;font-weight: bold;" >' . JText::_('COM_JOOMSCHOOL_LABEL_STATUS_UN_PAID') . '</span>';
                }
                if ($status == "3") {
                    $st = '<span style="color: magenta;font-weight: bold;" >' . JText::_('COM_JOOMSCHOOL_LABEL_STATUS_CANCEL') . '</span>';
                }
                if ($status == "4") {
                    $st = '<span style="color: mediumblue;font-weight: bold;" >' . JText::_('COM_JOOMSCHOOL_LABEL_STATUS_UNDER_REVIEW') . '</span>';
                }

                $submit_date = date('Y-m-d g:i A', strtotime($item->create_date));
                $link_invoice = JRoute::_('index.php?option=com_joomschool&view=payments&task=invoice&cid=' . $item->id);
                $link_PDF = JRoute::_('index.php?option=com_joomschool&view=payments&task=invoicepdf&cid=' . $item->id . '');

                $payment_data .= '<tr>';
                $payment_data .= '<td>' . $i . '</td>';
                if (in_array(JComponentHelper::getParams('com_joomschool')->get('teachers_group', 140002), JAccess::getGroupsByUser($uid))) {
                    $payment_data .= '<td style="text-align: left;" >' . $student_name . '</td>';
                    $payment_data .= '<td  >' . $item->student_roll . '</td>';
                }
                $payment_data .= '<td style="text-align: left;" >' . $monthName . ' - ' . $year . '</td>';
                $payment_data .= '<td>' . $ammount . '</td>';
                $payment_data .= '<td>' . $paidby . '</td>';
                $payment_data .= '<td>' . $st . '</td>';
                $payment_data .= '<td>' . $submit_date . '</td>';
                $payment_data .= '<td><a href="' . $link_invoice . '" class="btn">' . JText::_('BTN_PAYMENT_VIEW_INVOICE') . '</a></td>';
                $payment_data .= '<td><a href="' . $link_PDF . '" class="btn">' . JText::_('DEFAULT_PDF') . '</a></td>';
                $payment_data .= '</tr>';
            }


            $payment_data .= '</table>';

        }

        return $payment_data;
    }


    /**
     **  Students & Parent payment list (Query By Student ID)
     ***/
    function getPaymentDetails($id, $status_filter, $month_filter, $year_filter)
    {

        $user = JFactory::getUser();
        $uid = $user->get('id');
        $group_title = JoomschoolHelperFrontend::checkGroup($uid);


        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select('*')
            ->from($db->quoteName('#__joomschool_payments'))
            ->order('month ASC');

        if (in_array(JComponentHelper::getParams('com_joomschool')->get('parents_group', 140003), JAccess::getGroupsByUser($uid))) {
            $student_ids = JoomschoolHelperFrontend::selectSingleData('student_id', 'joomschool_parents', 'id', $id);
            $query->where('student_id IN(' . $student_ids . ')');


        } else {
            $query->where($db->quoteName('student_id') . ' = ' . $db->quote($id));
        }


        // Filter by Status.
        if ($status_filter) {
            if ($status_filter == '12') {
                $status_filter = 0;
            }
            if (is_numeric($status_filter)) {
                $query->where('status = ' . $db->quote($status_filter));
            }
        }

        // Filter by Month.
        if (!empty($month_filter)) {
            $query->where('month = ' . $db->quote($month_filter));
        }

        // Filter by Year.
        if (!empty($year_filter)) {
            $query->where('year = ' . $db->quote($year_filter));
        }

        $db->setQuery($query);

        $rows = $db->loadObjectList();
        return $rows;
    }


    /**
     ** Teachers Payment list (Query by teacher class ID)
     **/
    function getPaymentDetailsByClass($id, $status_filter, $month_filter, $year_filter, $section_filter, $roll_filder)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select('*')
            ->from($db->quoteName('#__joomschool_payments'))
            ->where($db->quoteName('student_class') . ' = ' . $db->quote($id))
            ->order('month ASC');

        // Filter by Status.
        if ($status_filter) {
            if ($status_filter == '12') {
                $status_filter = 0;
            }
            if (is_numeric($status_filter)) {
                $query->where('status = ' . $db->quote($status_filter));
            }
        }

        // Filter by Month.
        if (!empty($month_filter)) {
            $query->where('month = ' . $db->quote($month_filter));
        }

        // Filter by Year.
        if (!empty($year_filter)) {
            $query->where('year = ' . $db->quote($year_filter));
        }

        // Filter by Section.
        if (!empty($section_filter)) {
            $query->where('student_section = ' . $db->quote($section_filter));
        }

        // Filter by Roll.
        if (!empty($roll_filder)) {
            $query->where('student_roll = ' . $db->quote($roll_filder));
        }

        $orderCol = $this->state->get('list.ordering', 'id');
        $orderDirn = $this->state->get('list.direction', 'desc');
        $query->order($db->escape($orderCol) . ' ' . $db->escape($orderDirn));

        $db->setQuery($query);
        $rows = $db->loadObjectList();
        return $rows;
    }

    function getPayments($id)
    {
        if ($id) {
            $this->_id = $id;
        }
        if (empty($this->_data)) {
            $this->_data = $this->getTable('payments');
            $this->_data->load($this->_id);
        }
        return $this->_data;
    }


    /**
     ** Class List
     **/
    function getclassList($id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('id', 'class_name')))
            ->from($db->quoteName('#__joomschool_class'))
            ->where($db->quoteName('published') . ' = ' . $db->quote('1'))
            ->order('id ASC');


        $db->setQuery($query);
        $rows = $db->loadObjectList();
        if ($db->getErrorNum()) {
            echo $db->stderr();
            return false;
        }
        $class_array = array();

        $onclick_manage_subject = "javascript: formget(this.form, 'index.php?option=com_joomschool&controller=payments&task=getsectionlist&format=raw');";

        $class_array[] = array('value' => '', 'text' => JText::_('COM_JOOMSCHOOL_SELECT_CLASS'));
        foreach ($rows as $row) {
            $class_array[] = array('value' => $row->id, 'text' => JText::_(' ' . $row->class_name));
        }
        $class = JHTML::_('select.genericList', $class_array, 'student_class', ' class="required  inputbox  "  required="required"   ', 'value', 'text', $id);
        return $class;
    }

    /**
     ** Section List
     **/

    function sectionList($class_id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('section_id')))
            ->from($db->quoteName('#__joomschool_class'))
            ->where($db->quoteName('id') . ' = ' . $db->quote($class_id));

        $db->setQuery($query);
        $data = $db->loadResult();
        $section_value = explode(",", $data);
        return $section_value;
    }

    function getsectionList($id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('id', 'section_name')))
            ->from($db->quoteName('#__joomschool_sections'))
            ->where($db->quoteName('published') . ' = ' . $db->quote('1'))
            ->order('id ASC');


        $db->setQuery($query);
        $rows = $db->loadObjectList();
        if ($db->getErrorNum()) {
            echo $db->stderr();
            return false;
        }
        $sections = array();


        $sections[] = array('value' => '', 'text' => JText::_('COM_JOOMSCHOOL_SELECT_SECTION'));
        foreach ($rows as $row) {
            $sections[] = array('value' => $row->id, 'text' => JText::_(' ' . $row->section_name));
        }
        $section = JHTML::_('select.genericList', $sections, 'student_section', 'class=" required inputbox  " required="required" ', 'value', 'text', $id);
        return $section;
    }

    public function getPaymentName($id){

        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select('name');
        $query->from('#__joomschool_pay_method');
        $query->where('id ='. $id);

        $db->setQuery($query);
        $result = $db->loadResult();


        return is_null($result) ? '' : $result;

    }

    /**
     ** Payment Method List
     **/
    function getPaymentMethodList($id)
    {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('id', 'name')))
            ->from($db->quoteName('#__joomschool_pay_method'))
            ->where($db->quoteName('published') . ' = ' . $db->quote('1'))
            ->order('id ASC');

        $db->setQuery($query);
        $rows = $db->loadObjectList();
        if ($db->getErrorNum()) {
            echo $db->stderr();
            return false;
        }
        $class_array = array();

        $onclick_manage_subject = "javascript: formget(this.form, 'index.php?option=com_joomschool&controller=marks&task=getsubjectlist&format=raw');";

        $class_array[] = array('value' => '', 'text' => JText::_('LABEL_SELECT_PAY_MRTHOD'));
        foreach ($rows as $row) {
            $class_array[] = array('value' => $row->id, 'text' => JText::_(' ' . $row->name));
        }
        $class = JHTML::_('select.genericList', $class_array, 'payment_method_id', ' class="required  inputbox  " required="required"   ', 'value', 'text', $id);
        return $class;
    }


    /**
     ** Pay For  List
     **/
    function getPayForList($id)
    {
        $db = JFactory::getDBO();
        $app = JFactory::getApplication();
        $params = JComponentHelper::getParams('com_joomschool');
        $currency = $params->get('currency', '$');

        $query = $db->getQuery(true);
        $query
            ->select($db->quoteName(array('id', 'name', 'fee')))
            ->from($db->quoteName('#__joomschool_pay_type'))
            ->order('id ASC');
        $db->setQuery($query);
        $rows = $db->loadObjectList();
        if ($db->getErrorNum()) {
            echo $db->stderr();
            return false;
        }
        $class_array = array();

        if ($id) {
            $query_result = $db->getQuery(true);
            $query_result
                ->select($db->quoteName(array('pay_for_id')))
                ->from($db->quoteName('#__joomschool_payments'))
                ->where($db->quoteName('id') . ' = ' . $db->quote($id));
            $db->setQuery($query_result);
            $select_data = $db->loadResult();

            $select_value = explode(",", $select_data);
        } else {
            $select_value = "";
        }

        foreach ($rows as $row) {
            $class_array[] = array('value' => $row->id, 'text' => JText::_(' ' . $row->name . ' (' . $currency . ':' . $row->fee . ')'));
        }
        $class = JHTML::_('select.genericList', $class_array, 'pay_for_id[]', 'multiple="multiple" class="payment_type required  inputbox  " required="required"   ', 'value', 'text', $select_value);
        return $class;
    }


    /**
     ** Get Bill
     ***/
    function getBill($bill_arry)
    {
        $db = JFactory::getDBO();

        $total_fee = 0;
        if ($bill_arry) {
            foreach ($bill_arry as $bills) {
                $bill_id = $bills;
                $query_result = $db->getQuery(true);
                $query_result
                    ->select($db->quoteName(array('fee')))
                    ->from($db->quoteName('#__joomschool_pay_type'))
                    ->where($db->quoteName('id') . ' = ' . $db->quote($bill_id));
                $db->setQuery($query_result);
                $fee = $db->loadResult();
                $total_fee += $fee;
            }
        }

        return $total_fee;
    }


}
