<?php
/**
 * @package	JoomSchool !
 * @version	1.0.0
 * @author	joomboost.com
 * @copyright	(C) 2013-2019 JoomBoost. All rights reserved.
 * @license	GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;

// import the Joomla modellist library
jimport('joomla.application.component.modellist');
use Joomla\Registry\Registry;
use Joomla\Utilities\ArrayHelper;

// Base this model on the backend version.
JLoader::register('JoomschoolModelTeacher', JPATH_ADMINISTRATOR . '/components/com_joomschool/models/teacher.php');
class JoomschoolModelTeacheredit extends JoomschoolModelTeacher
{
    /**
     * Model typeAlias string. Used for version history.
     *
     * @var        string
     */
    public $typeAlias = 'com_joomschool.teacheredit';

    /**
     * Method to auto-populate the model state.
     *
     * Note. Calling getState in this method will result in recursion.
     *
     * @return  void
     *
     * @since   1.6
     */
    public function populateState()
    {
        $app = JFactory::getApplication();

        // Load state from the request.
        $pk = JoomSchoolHelper::getTeacherIDbyUserid(JFactory::getUser()->id);
        $this->setState('teacher.id', $pk);


        $return = $app->input->get('return', null, 'base64');
        $this->setState('return_page', base64_decode($return));

        // Load the parameters.
        $params = $app->getParams();
        $this->setState('params', $params);

        $this->setState('layout', $app->input->getString('layout'));
    }

    public function getItem($pk = null)
    {
        $pk = $pk ? $pk : JoomschoolHelper::getTeacherIDbyUserid(JFactory::getUser()->id);
        return parent::getItem($pk); // TODO: Change the autogenerated stub
    }

    /**
     * Get the return URL.
     *
     * @return  string	The return URL.
     *
     * @since   1.6
     */
    public function getReturnPage()
    {
        return base64_encode($this->getState('return_page'));
    }

    public function getForm($data = array(), $loadData = true)
    {

        /*
         * The front end calls this model and uses a_id to avoid id clashes so we need to check for that first.
         * The back end uses id so we use that the rest of the time and set it to 0 by default.
         */

        // Determine correct permissions to check.

        // Check for existing article.
        // Modify the form based on Edit State access controls.

        $form = parent::getForm($data, $loadData); // TODO: Change the autogenerated stub

        if (JoomschoolHelperFrontend::checkGroup(JFactory::getUser()->id) == "Teachers"){
            // Disable fields for display.
            $form->setFieldAttribute('class', 'disabled', 'true');
            $form->setFieldAttribute('section', 'disabled', 'true');
            $form->setFieldAttribute('subject', 'disabled', 'true');


        }

        return $form;



    }

    public function save($data)
    {

        JLoader::register('JoomschoolHelperUser', JPATH_COMPONENT_ADMINISTRATOR . '/helpers/user.php');

        // update some data
        $post = JFactory::getApplication()->input->getArray();
        $data['name'] = $post['name'];
        $data['email'] = JFactory::getUser()->email;
        $data['username'] = JFactory::getUser()->email;
        $data['user_id'] = JFactory::getUser()->id;
        unset($post['jform']);

        if (!empty($data['created'])) {
            $data['modified'] = JFactory::getDate()->toSql();
            $data['modified_by'] = JFactory::getUser()->id;
        }

        // update user data, and register/update him in joomla users table
        if(!$this->updateWithJoomlaUsers($data))
            return false;

        // upload photo and add filename to data
        if(!$this->uploadPhoto($data))
            return false;

        // continue saving student data ...
        if ($this->parentSave($data)) {
            $this->saveCustomField($post);
            return true;
        }

        return false;
    }

	
}
