<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;

$model = $this->getModel();
$user = JFactory::getUser();
$user_id = $user->id;
$link_new = JRoute::_('index.php?option=com_joomschool&view=message&task=newmessage');
$title = (isset(JFactory::getApplication()->getMenu()->getActive()->title) ? JFactory::getApplication()->getMenu()->getActive()->title : JText::_('MENU_MESSAGES'));

JHtml::_('bootstrap.tooltip');
JHtml::_('behavior.multiselect');
JHtml::_('formbehavior.chosen', 'select');

JLoader::register('JHtmlActionsDropdownFront', JPATH_SITE . '/components/com_joomschool/helpers/html/actionsdropdownfront.php');

$messageModel = JModelLegacy::getInstance('message', 'JoomschoolModel', array('ignore_request' => true));

?>
<div id="com_joomschool">
    <div id="jb-template">
        <?php
        if ($this->params->get('show_menu', 1)) {
            echo JLayoutHelper::render('common.menu');
        }
        ?>
        <?php echo JLayoutHelper::render('common.header', ['params' => $this->params, 'title' => 'MENU_MESSAGES']) ?>

        <form action="<?php echo JRoute::_('index.php?option=com_joomschool&view=message'); ?>" method="post"
              name="adminForm" id="adminForm">

            <?php if (JoomschoolHelperUser::hasRole('teacher')): ?>
                <div class="bg-light rounded p-3 mb-4 shadow-sm border" id="jv-toolbar">
                    <?php echo JLayoutHelper::render('joomla.searchtools.default', array('view' => $this)); ?>
                </div>
            <?php endif; ?>

            <div class="card shadow-sm">
                <div class="px-3 card-header d-flex justify-content-between align-items-center align-content-center">
                    <div>
                        <label>
                            <?php echo JHtml::_('grid.checkall'); ?>
                            <span class="ml-3"><?php echo JText::_('COM_JOOMSCHOOL_CHECK_ALL') ?></span>
                        </label>
                    </div>
                    <div id="jb-template-font">
                        <a href="<?php echo $link_new; ?>" class="btn btn-sm btn-success">
                            <i class="fas fa-plus"></i> <?php echo JText::_('BTN_NEW_MESSAGE'); ?>
                        </a>
                        <button class="btn btn-sm btn-danger" type="submit" id="delete_message">
                            <i class="fas fa-trash"></i> <?php echo JText::_('BTN_DELETE_MESSAGE'); ?>
                        </button>
                    </div>
                </div>

                <div class="card-body p-0">
                    <?php if (empty($this->items)) : ?>
                        <div class="alert alert-warning m-0 rounded-0">
                            <?php echo JText::_('JGLOBAL_NO_MATCHING_RESULTS'); ?>
                        </div>
                    <?php else : ?>
                        <table class="table m-0 joomschool-pms">
                            <tbody>
                            <?php

                            foreach ($this->items as $i => $item) :

                                // get unread replies
                                $repliesCount = $messageModel->unreadReplies($item->id);
                                $messageUnread = $messageModel->unreadMessage($item->id);
                                $unread = '';

                                if ($messageUnread) {
                                    $unread = '<small class="badge badge-danger"><i class="fas fa-exclamation-triangle"></i> ' . JText::_('COM_JOOMSCHOOL_UNREAD_MESSAGE') . '</small>';
                                }

                                if ($repliesCount > 0) {

                                    $unread = '<span class="badge badge-danger"><i class="fas fa-exclamation-triangle"></i> ' . $repliesCount . ' ' . JText::_('COM_JOOMSCHOOL_UNREAD_' . ($repliesCount == 1 ? 'REPLY' : 'REPLIES')) . '</span>';
                                }

                                $checked = JHTML::_('grid.id', $i, $item->id);
                                $link = JRoute::_('index.php?option=com_joomschool&view=message&task=messagedetails&mid=' . $item->id);


                                if ($item->recever_id == $user_id) {
                                    $from_name = '<b><i class="fas fa-sign-out-alt text-muted"></i> ' . JText::_('DEFAULT_FORM') . '</b><br> ' . $model->senderName($item->sender_id);
                                    $owner_id = $item->sender_id;
                                } else {
                                    $from_name = '<b><i class="fas fa-sign-in-alt text-muted"></i> ' . JText::_('DEFAULT_TO') . '</b><br> ' . $model->senderName($item->recever_id);
                                    $owner_id = $item->recever_id;
                                }

                                ?>
                                <tr class="row<?php echo $i % 2; ?>">
                                    <td width="15px"><?php echo $checked; ?></td>
                                    <td width="80px">
                                        <img src="<?php echo $model->avator($owner_id); ?>" alt="" style=""
                                             class="img-thumbnail">
                                    </td>
                                    <td width="180px" style="font-style: italic;">
                                        <?php echo $from_name; ?>
                                    </td>
                                    <td class="40%">
                                        <a href="<?php echo $link; ?>">
                                            <strong><?php echo $item->subject; ?></strong><br>
                                            <span><?php echo substr($item->message, 0, 70); ?>...<br><?php echo $unread; ?></span>
                                        </a>
                                    </td>
                                    <td>
                                        <?php


                                        if (!empty($item->class_subjects) && count($item->class_subjects) > 0) {

                                            foreach ($item->class_subjects as $subject) {
                                                echo '<span class="shadow-sm  badge bg-light border text-dark">' . $subject . '</span> ';
                                            }

                                        }

                                        ?>
                                    </td>
                                    <td>
                                        <?php echo JLayoutHelper::render('joomla.form.field.assignedstatus', ['item' => $item]) ?>
                                    </td>
                                    <td class="text-right">
                                        <small class="d-block">
                                            <strong><?php echo date('g:i A', strtotime($item->date_time)); ?></strong>
                                            <br>
                                            <span class="text-muted"><?php echo date('Y-m-d', strtotime($item->date_time)); ?></span>
                                        </small>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                            </tbody>


                        </table>
                    <?php endif; ?>
                    <input type="hidden" id="task" name="task" value=""/>
                    <input type="hidden" name="boxchecked" value="0"/>
                    <?php echo JHtml::_('form.token'); ?>
                </div>


                <?php echo JLayoutHelper::render('common.pagination', ['current' => $this, 'class' => 'card-footer bg-light']) ?>


            </div>


        </form>
    </div>
</div>
<script type="text/javascript">
    jQuery("#delete_message").click(function () {
        jQuery("#task").val('delete');
    });
</script>
