<?php 
/**
 * @package	JoomSchool !
 * @version	1.0.0
 * @author	joomboost.com
 * @copyright	(C) 2013-2019 JoomBoost. All rights reserved.
 * @license	GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */


defined('_JEXEC') or die;

use Joomla\Registry\Registry;

// Include the component HTML helpers.
JHtml::addIncludePath(JPATH_COMPONENT . '/helpers/html');

JHtml::_('behavior.formvalidator');
JHtml::_('behavior.keepalive');
JHtml::_('formbehavior.chosen', 'select');

$this->configFieldsets  = array('editorConfig');
$this->hiddenFieldsets  = array('basic-limited');
$this->ignore_fieldsets = array('jmetadata', 'item_associations');

// Create shortcut to parameters.
$params = clone $this->state->get('params');
//$params->merge(new Registry($this->item->attribs));

$app = JFactory::getApplication();
$input = $app->input;

$assoc = JLanguageAssociations::isEnabled();

JFactory::getDocument()->addScriptDeclaration('
	Joomla.submitbutton = function(task)
	{
		if (task == "teacheredit.cancel" || document.formvalidator.isValid(document.getElementById("item-form")))
		{
			jQuery("#permissions-sliders select").attr("disabled", "disabled");
		
			Joomla.submitform(task, document.getElementById("item-form"));

			// @deprecated 4.0  The following js is not needed since 3.7.0.
			if (task !== "teacheredit.apply")
			{
				window.parent.jQuery("#teacherEdit' . (int) $this->item->id . 'Modal").modal("hide");
			}
		}
	};
');

// In case of modal
$isModal = $input->get('layout') == 'modal' ? true : false;
$layout  = $isModal ? 'modal' : 'edit';
$tmpl    = $isModal || $input->get('tmpl', '', 'cmd') === 'component' ? '&tmpl=component' : '';
$title = (isset(JFactory::getApplication()->getMenu()->getActive()->title) ? JFactory::getApplication()->getMenu()->getActive()->title :JText::_('COM_JOOMSCHOOL_VIEW_PROFILE'));
$user =JFactory::getUser();
$name =  $user->name;

$field_name = JoomschoolHelper::buildField(JText::_('LABEL_TEACHER_NAME'),'input', 'name',$name , '','','required');
?>
<div id="jb-template">
    <?php
    if($this->params->get('show_menu',1)){
        echo JLayoutHelper::render('common.menu');
    }
    ?>
    <?php if ($this->params->get('show_page_heading')) : ?>
        <div class="page-header border-bottom my-4">
            <h1 class="mb-0">
                <?php echo !empty($this->escape($this->params->get('page_heading'))) ? $this->escape($this->params->get('page_heading')) : $title ?>
            </h1>
        </div>
    <?php else :?>
        <div class="page-header border-bottom my-4">
            <h1 class="mb-0">
                <?php echo JText::_('COM_JOOMSCHOOL_EDIT_PROFILE') ?>
            </h1>
        </div>
    <?php endif;?>
    <form action="<?php echo JRoute::_('index.php?option=com_joomschool&layout=' . $layout . $tmpl . '&id=' . (int) $this->item->id); ?>" method="post" name="adminForm" id="item-form" class="form-validate" enctype="multipart/form-data">
        <div class="bg-light rounded p-3 mb-4 shadow-sm border" id="jv-toolbar">
            <button class="btn btn-success" onclick="Joomla.submitbutton('teacheredit.apply')"><span class="fas fa-edit"></span> <?php echo JText::_('JSAVE'); ?></button>
            <button class="btn btn-danger float-right" onclick="Joomla.submitbutton('teacheredit.cancel')"><span class="fas fa-times"></span> <?php echo JText::_('JCANCEL'); ?></button>
        </div>
        <div class="form-horizontal">
            <?php echo JHtml::_('bootstrap.startTabSet', 'myTab', array('active' => 'profile')); ?>
            <?php // Do not show the images and links options if the edit form is configured not to. ?>
                <?php echo JHtml::_('bootstrap.addTab', 'myTab', 'profile', JText::_('TAB_TEACHER_PROFILE')); ?>

            <div class="row">
                <div class="col-md-9">
                    <fieldset>
                        <?php echo $this->form->renderFieldset('profile') ?>
                        <?php echo $field_name; ?>
                        <?php
                        //Field Builder
                        $sid = JoomschoolHelper::getFieldSectionID('teacher');
                        $fields = JoomschoolHelper::getFieldList($sid);
                        $total_field = count($fields);
                        $f=0;
                        foreach($fields as $field){
                            $f++;
                            $fid = $field->id;
                            $sid = $sid;
                            $panel_id = $this->item->id;
                            echo JoomschoolHelper::fieldshow($fid, $sid, $panel_id, $field->field_name,$field->type ,$field->required);
                        }
                        ?>
                    </fieldset>
                </div>
                <div class="col-md-3">
                    <?php echo JLayoutHelper::render('joomla.edit.global', $this); ?>
                </div>
            </div>
            <?php echo JHtml::_('bootstrap.endTab'); ?>

            <?php echo JHtml::_('bootstrap.addTab', 'myTab', 'academic', JText::_('TAB_TEACHER_ACADEMIC_INFO')); ?>
                <?php  echo  $this->form->renderFieldset('academic') ?>
            <?php echo JHtml::_('bootstrap.endTab'); ?>

            <?php echo JHtml::_('bootstrap.addTab', 'myTab', 'account', JText::_('TAB_TEACHER_ACCOUNT_DETAILS')); ?>
                <?php echo $this->form->renderFieldset('account'); ?>
            <?php echo JHtml::_('bootstrap.endTab'); ?>

            <?php echo JHtml::_('bootstrap.addTab', 'myTab', 'photo', JText::_('TAB_TEACHER_PHOTO')); ?>
                <?php  echo  $this->form->renderFieldset('photo') ?>
                <img class="d-inline img-thumbnail" style="max-width: 200px" src="<?php echo $this->item->photo ;?>" />
            <?php echo JHtml::_('bootstrap.endTab'); ?>

            <?php echo JHtml::_('bootstrap.endTabSet'); ?>

            <input type="hidden" name="task" value="" />
            <input type="hidden" name="return" value="<?php echo $input->get('return', null, 'BASE64'); ?>" />
            <input type="hidden" name="forcedLanguage" value="<?php echo $input->get('forcedLanguage', '', 'cmd'); ?>" />
            <?php echo JHtml::_('form.token'); ?>
        </div>
    </form>
</div>




