<?php
/**
 * @package    JoomSchool !
 * @version    1.0.0
 * @author    joomboost.com
 * @copyright    (C) 2013-2019 JoomBoost. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;

use Joomla\CMS\Form\Form;
use Joomla\CMS\Factory;

class JoomschoolViewTeacheredit extends JViewLegacy
{
    /*
* The JForm object
*
* @var  JForm
	 */
    protected $form;

    /**
     * The active item
     *
     * @var  object
     */
    protected $item;

    /**
     * The model state
     *
     * @var  object
     */
    protected $state;

    /**
     * The actions the user is authorised to perform
     *
     * @var  JObject
     */
    protected $canDo;

    /**
     * Execute and display a template script.
     *
     * @param string $tpl The name of the template file to parse; automatically searches through the template paths.
     *
     * @return  mixed  A string if successful, otherwise an Error object.
     *
     * @since   1.6
     */
    public function display($tpl = null)
    {
        $app        = JFactory::getApplication();
        $user       = JFactory::getUser();
        $globalParams =  $app->getParams();
        $menu = $app->getMenu();
        $active = $menu->getActive();
        $itemId = $active->id;
        $menuParams         = $menu->getParams($itemId);


        $groups = ['Teachers'];

        if(!$user->id) {
            $mge = JText::_('COM_JOOMSCHOOL_MESSAGE_AREA_NOT_ALOW');
            $app->enqueueMessage($mge, 'warning');
            $redirect_link = JRoute::_('index.php?option=com_users&amp;view=login');
            $app->redirect($redirect_link);
        }
        if(!in_array(JoomschoolHelperFrontend::checkGroup($user->id),$groups)) {
            $mge = JText::_('COM_JOOMSCHOOL_MESSAGE_TEACHER_LOGIN_REQUIRED');
            $app->enqueueMessage($mge, 'warning');
            $redirect_link = JRoute::_(JoomSchoolHelperRoute::getDashboardRoute());
            $app->redirect($redirect_link);
        }

            $this->form = $this->get('Form');
            $this->item = $this->get('Item');
            $this->state = $this->get('State');
            $this->params = $this->state->get('params');

            $globalParams->merge($menuParams);

            $globalParams->merge($this->params);
            $this->params = $globalParams;

        if ($this->item->id != JoomschoolHelper::getTeacherIDbyUserid(JFactory::getUser()->id)) {
            $redirect_link = JRoute::_(JoomSchoolHelperRoute::getDashboardRoute());
            $app->redirect($redirect_link);
        }

        if ($this->getLayout() == 'details') {

            $classes = [];
            $sections = [];
            $subjects = [];

            foreach ($this->item->class as $j => $class) {
                $classes[$class] = JoomschoolHelper::getClassNameByID($class)->class_name;
                $this->item->class = $classes;
            }
            foreach ($this->item->section as $j => $section) {
                $sections[$section] = JoomschoolHelper::getSectionsNameByID($section)->section_name;
                $this->item->section = $sections;
            }
            foreach ($this->item->subject as $j => $subject) {
                $subjects[$subject] = JoomschoolHelper::getSubjectNameByID($subject)->subject_name;
                $this->item->subject = $subjects;
            }

        }


        $this->canDo = JHelperContent::getActions('com_joomschool', 'teacher', $this->item->id);
        // for pdf mode
        JoomschoolHelperDownload::getPDF('info.container', $this->item, [
            'type' => 'teacher',
            'id' => $this->item->id,
            'name' => JFactory::getUser($this->item->user_id)->name
        ]);
        $this->addToolbar();

        return parent::display($tpl);

    }

    protected function addToolbar()
    {
        JFactory::getApplication()->input->set('hidemainmenu', true);
        $user = JFactory::getUser();
        $userId = $user->id;
        $isNew = ($this->item->id == 0);

        // Built the actions for new and existing records.
        $canDo = $this->canDo;

        switch ($this->getLayout()) {
            case "edit":
                JToolbarHelper::title(
                    JText::_('LABEL_TEACHER_' . ($isNew ? 'NEW' : 'EDIT')),
                    'user'
                );
                // Can't save the record if it's checked out and editable
                if ($canDo->get('core.create')) {
                    JToolbarHelper::apply('teacher.apply');
                    JToolbarHelper::save('teacher.save');
                }
                break;
            case "details":
                JoomschoolHelperToolbar::printInfo('icon-print', 'COM_JOOMSCHOOL_PRINT');
                JToolbarHelper::title(JText::_('LABEL_TEACHER_BIODATA'), 'user');
                break;


            default:
                JToolbarHelper::title(
                    JText::_('LABEL_TEACHER_' . ($isNew ? 'NEW' : 'EDIT')),
                    'user'
                );
                // Can't save the record if it's checked out and editable
                if ($canDo->get('core.create')) {
                    JToolbarHelper::apply('teacher.apply');
                    JToolbarHelper::save('teacher.save');
                }
        }


        JToolbarHelper::cancel('teacher.cancel', 'JTOOLBAR_CLOSE');
        JToolbarHelper::divider();
    }

}
